package com.ruoyi.api.labour.controller;

import com.ruoyi.api.base.PubTokenReqVo;
import com.ruoyi.api.labour.domain.AiBoxApiReqVo;
import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.annotation.RateLimiter;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.*;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.framework.web.service.SysLoginService;
import com.ruoyi.system.domain.SysApplyConfig;
import com.ruoyi.system.service.ISysUserService;
import com.yanzhu.jh.video.domain.DevAiProjectData;
import com.yanzhu.jh.video.service.IDevAiProjectDataService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * Ai预警APIController
 *
 * @author JiangYuQi
 * @date 2024-01-13
 */
@Slf4j
@RestController
@RequestMapping("/api/aiboxs")
public class AiBoxApiController extends BaseController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private ISysUserService userService;

    @Autowired
    private SysLoginService loginService;

    @Autowired
    private IDevAiProjectDataService devAiProjectDataService;

    /**
     * 获取系统token
     * 限流规则[60秒内最多请求10次，限流策略IP]
     * @param req 请求信息
     * @author JiangYuQi
     * @date 2024-01-13
     */
    @Anonymous
    @ApiOperation(value = "获取TOKEN")
    @RateLimiter(count = 10, limitType = LimitType.IP)
    @PostMapping("/v1/getToken")
    public AjaxResult getToken(@Validated @RequestBody PubTokenReqVo req) {
        SysApplyConfig sysApplyConfig = redisCache.getCacheObject(CacheConstants.YANZHU_SYSTEM_CONFIG+req.getAppId());
        if(sysApplyConfig==null){
            throw new ServiceException(HttpStatusEnum.ERROR.getInfo(),HttpStatusEnum.ERROR.getCode());
        }
        if(StringUtils.equals(ShiFouEnum.SHI.getCode(),sysApplyConfig.getIsDel())){
            throw new ServiceException(HttpStatusEnum.DISABLE.getInfo(),HttpStatusEnum.DISABLE.getCode());
        }
        if(!Objects.equals(ApplyCfgTypeEnum.AIBOXS.getCode(),sysApplyConfig.getCfgType())){
            throw new ServiceException(HttpStatusEnum.ERROR.getInfo(),HttpStatusEnum.ERROR.getCode());
        }
        if(!req.checkTimestamp()){
            throw new ServiceException(HttpStatusEnum.SINGET_TIMEOUT.getInfo(),HttpStatusEnum.SINGET_TIMEOUT.getCode());
        }
        AjaxResult ajax = AjaxResult.success();
        String Authorization = "";
        if (req.getLoginSign(sysApplyConfig.getPublicKey())) {
            String key = "api.aiboxs.getToken:"+req.getAppId();
            String obj = redisCache.getCacheObject(key);
            if(StringUtils.isNotEmpty(obj)){
                ajax.put("Authorization", obj);
            }else{
                Authorization = this.getAppIdLoginToken(req.getAppId(),sysApplyConfig);
                ajax.put("Authorization", Authorization);
                redisCache.setCacheObject(key,Authorization,30, TimeUnit.MINUTES);
            }
        } else {
            throw new ServiceException(HttpStatusEnum.SINGET_ERROR.getInfo(),HttpStatusEnum.SINGET_ERROR.getCode());
        }
        return ajax;
    }

    /**
     * appId登录创建用户并模拟登录
     *
     * @param appId 用户账号
     * @return token
     */
    private String getAppIdLoginToken(String appId,SysApplyConfig sysApplyConfig) {
        // 查询用户是否存在，不存在则保存
        SysUser sysUser = userService.selectUserByUserName(appId);
        String password = Convert.toStr(System.currentTimeMillis());
        if (sysUser == null) {
            sysUser = new SysUser();
            sysUser.setDeptId(sysApplyConfig.getDeptId());
            sysUser.setUserName(Convert.toStr(sysApplyConfig.getAppId()));
            sysUser.setNickName(Convert.toStr(sysApplyConfig.getAppId()));
            sysUser.setUserType(UserTypeEnum.APPLY.getCode());
            sysUser.setStatus("0");
            sysUser.setCreateBy("AppId登录创建用户");
            sysUser.setPassword(SecurityUtils.encryptPassword(password));
            userService.insertUser(sysUser);
        } else {
            sysUser.setPassword(SecurityUtils.encryptPassword(password));
            sysUser.setUpdateBy("AppId登录更新用户密码");
            userService.updateUser(sysUser);
        }
        return loginService.unifiedLogin(appId, password);
    }

    /**
     * 获取视频预警信息
     * 限流规则[60秒内最多请求10次，限流策略IP]
     * @param req 请求信息
     * @author JiangYuQi
     * @date 2024-01-13
     */
    @ApiOperation(value = "获取视频预警信息")
    @RateLimiter(time = 10, limitType = LimitType.IP)
    @GetMapping("/v1/list")
    public TableDataInfo list(AiBoxApiReqVo req) {
        SysApplyConfig sysApplyConfig = redisCache.getCacheObject(CacheConstants.YANZHU_SYSTEM_CONFIG+super.getUsername());
        if(StringUtils.equals(ShiFouEnum.SHI.getCode(),sysApplyConfig.getIsDel())){
            throw new ServiceException(HttpStatusEnum.DISABLE.getInfo(),HttpStatusEnum.DISABLE.getCode());
        }
        if(!Objects.equals(ApplyCfgTypeEnum.AIBOXS.getCode(),sysApplyConfig.getCfgType())){
            throw new ServiceException(HttpStatusEnum.ERROR.getInfo(),HttpStatusEnum.ERROR.getCode());
        }
        DevAiProjectData query = new DevAiProjectData();
        query.setDeptId(sysApplyConfig.getDeptId());
        query.setProjectId(sysApplyConfig.getProjectId());
        Map<String, Object> params = new HashMap<>();
        if(Objects.nonNull(req.getBeginTimestamp()) && Objects.nonNull(req.getEndTimestamp())){
            Date beginTime = new Date(req.getBeginTimestamp());
            params.put("beginTime",beginTime);
            Date endTime = new Date(req.getEndTimestamp());
            params.put("endTime",endTime);
        }else{
            if(Objects.nonNull(req.getBeginTimestamp())){
                Date beginTime = new Date(req.getBeginTimestamp());
                params.put("beginDate",beginTime);
            }
            if(Objects.nonNull(req.getEndTimestamp())){
                Date endTime = new Date(req.getEndTimestamp());
                params.put("endDate",endTime);
            }
        }
        query.setParams(params);
        startPage();
        List<DevAiProjectData> list = devAiProjectDataService.selectDevAiProjectDataList(query);
        for(DevAiProjectData item:list){
            item.setImageUrl(RuoYiConfig.getProjectUrl()+item.getImageUrl());
            item.setMinImage(item.getImageUrl()+".min.jpg");
        }
        return getDataTable(list);
    }
}
