package com.ruoyi.flowable.service.impl;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.flowable.service.IFlowBusinessKeyService;
import com.ruoyi.system.domain.FlowTaskEntity;
import com.ruoyi.system.mapper.FlowBusinessKeyMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * 业务工作流程自定义
 *
 * @author Tony
 * @date 2021-04-03
 */
@Service
@Slf4j
public class FlowBusinessKeyServiceImpl implements IFlowBusinessKeyService {

    @Resource
    private FlowBusinessKeyMapper flowBusinessKeyMapper;
    /**
     * 根据条件查询所有流任务
     * @param flowTaskEntity
     * @return
     */
    @Override
    public List<FlowTaskEntity> selectAllFlowTaskByParams(FlowTaskEntity flowTaskEntity) {
        return flowBusinessKeyMapper.selectAllFlowTaskByParams(flowTaskEntity);
    }

    /**
     * 根据条件查询流程任务
     * @param procInsId
     * @return
     */
    @Override
    public FlowTaskEntity findFlowTaskByProcInsId(String procInsId) {
        return flowBusinessKeyMapper.findFlowTaskByProcInsId(procInsId);
    }

    /**
     * 查询项目信息
     * @param proId
     * @return
     */
    @Override
    public Map<String,Object> selectSurProjectById(Long proId) {
        return flowBusinessKeyMapper.selectSurProjectById(proId);
    }

    /**
     * 根据条件统计所有流任务
     * @param flowTaskEntity
     * @return
     */
    @Override
    public Map<String,Object> quueryCount(FlowTaskEntity flowTaskEntity) {
        flowTaskEntity.setActiveName("await");
        int awaitSize = flowBusinessKeyMapper.selectAllFlowTaskByParams(flowTaskEntity).size();
        flowTaskEntity.setActiveName("finished");
        int finishedSize = flowBusinessKeyMapper.selectAllFlowTaskByParams(flowTaskEntity).size();
        Map<String, Object> dataMap = new HashMap<>();
        dataMap.put("await",awaitSize);
        dataMap.put("finished",finishedSize);
        return dataMap;
    }

    /**
     * 根据条件流程Id查询操作日志
     * @param procInsId
     * @return
     */
    @Override
    public List<Map<String, Object>> selectCommentByProcInsId(String procInsId) {
        return flowBusinessKeyMapper.selectCommentByProcInsId(procInsId);
    }

    /**
     * 根据条件流程Id查询操作日志
     * @param procInsId
     * @return
     */
    @Override
    public Map<String, Object> selectLastCommentByProcInsId(String procInsId){
        return flowBusinessKeyMapper.selectLastCommentByProcInsId(procInsId);
    }

    /**
     * 根据流程Id查询表单数据
     * @param procInsId
     * @return
     */
    @Override
    public Map<String, Object> selectFormDatasByProcInsId(String procInsId) {
        Map<String, Object> dataMap = new HashMap<>();
        List<Map<String, Object>> list = flowBusinessKeyMapper.selectFormDatasByProcInsId(procInsId);
        Iterator<Map<String, Object>> it = list.iterator();
        while (it.hasNext()) {
            Map<String, Object> map = it.next();
            dataMap.put(Convert.toStr(map.get("name")), map.get("text"));
        }
        return dataMap;
    }

    /**
     * 查询我的代办任务
     * @param flowTaskEntity
     * @return
     */
    @Override
    public List<Map<String, Object>> selectMyAwaitFlowTask(FlowTaskEntity flowTaskEntity){
        return flowBusinessKeyMapper.selectMyAwaitFlowTask(flowTaskEntity);
    }

    /**
     * 根据条件查询我的代办分组数量统计
     * @param flowTaskEntity
     * @return
     */
    @Override
    public List<Map<String, Object>> findAwaitCountGroupByCategory(FlowTaskEntity flowTaskEntity){
        return flowBusinessKeyMapper.findAwaitCountGroupByCategory(flowTaskEntity);
    }

    /**
     * 查询我的已办任务
     * @param flowTaskEntity
     * @return
     */
    @Override
    public List<Map<String, Object>> selectMyFinishedFlowTask(FlowTaskEntity flowTaskEntity) {
        return flowBusinessKeyMapper.selectMyFinishedFlowTask(flowTaskEntity);
    }

    @Override
    public List<FlowTaskEntity> groupByCategory(FlowTaskEntity where) {
        return flowBusinessKeyMapper.groupByCategory(where);
    }

    @Override
    public List<FlowTaskEntity> groupByUnit(FlowTaskEntity where) {
        return  flowBusinessKeyMapper.groupByUnit(where);
    }

    @Override
    public List<FlowTaskEntity> listByUnit(FlowTaskEntity where) {
        return flowBusinessKeyMapper.listByUnit(where);
    }

    @Override
    public List<FlowTaskEntity> listByState(FlowTaskEntity where) {
        return flowBusinessKeyMapper.listByState(where);
    }

    @Override
    public List<FlowTaskEntity> groupByUnitTotal(FlowTaskEntity where) {
        return flowBusinessKeyMapper.groupByUnitTotal(where);
    }

    @Override
    public List<FlowTaskEntity> groupByUnitFinish(FlowTaskEntity where) {
        return flowBusinessKeyMapper.groupByUnitFinish(where);
    }

    @Override
    public List<FlowTaskEntity> groupByProject(long deptId,String proType) {
        return flowBusinessKeyMapper.groupByProject(deptId,proType);
    }

    /**
     * 根据条件查询安全类作业工作流列表
     * @param flowTaskEntity
     * @return
     */
    @Override
    public List<FlowTaskEntity> findSafetyWorkList(FlowTaskEntity flowTaskEntity) {
        return flowBusinessKeyMapper.findSafetyWorkList(flowTaskEntity);
    }

    @Override
    public List<FlowTaskEntity> listByCategory(FlowTaskEntity where) {
        return flowBusinessKeyMapper.listByCategory(where);
    }

    /**
     * 根据条件查询流程用户
     * @param businessKey 流程归属表单
     * @param candidateUsers 办理用户列表
     * @param candidateGroups 办理角色列表
     * @return
     */
    @Override
    public List<SysUser> findFlowTaskUsers(String businessKey, List<String> candidateUsers, List<String> candidateGroups){
        if(StringUtils.isNotEmpty(candidateGroups) && candidateGroups.contains("47")){
            return flowBusinessKeyMapper.findFlowTaskDeptUsers(businessKey,candidateUsers,candidateGroups);
        }else{
            return flowBusinessKeyMapper.findFlowTaskUsers(businessKey,candidateUsers,candidateGroups);
        }
    }
    /**
     *  工程管理-分包单位占比
     * @param where
     * @return
     */
    @Override
    public List<FlowTaskEntity> groupFlowBySubDeptType(FlowTaskEntity where) {
        return flowBusinessKeyMapper.groupFlowBySubDeptType(where);
    }
    /**
     *  工程管理-分包单位资质审批明细
     * @param where
     * @return
     */
    @Override
    public List<FlowTaskEntity> listFlowBySubDeptType(FlowTaskEntity where) {
        return flowBusinessKeyMapper.listFlowBySubDeptType(where);
    }

}
