package com.ruoyi.quartz.service.impl;

import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.enums.ApplyCfgTypeEnum;
import com.ruoyi.common.enums.ShiFouEnum;
import com.ruoyi.common.enums.VendorsCodeEnum;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.quartz.domain.QuartzProjectAttendanceCfg;
import com.ruoyi.quartz.mapper.QuartzProjectAttendanceCfgMapper;
import com.ruoyi.quartz.service.IQuartzProjectAttendanceCfgService;
import com.ruoyi.system.domain.SysApplyConfig;
import com.ruoyi.system.service.ISysApplyConfigService;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * 项目考勤配置Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-09-24
 */
@Service
public class QuartzProjectAttendanceCfgServiceImpl implements IQuartzProjectAttendanceCfgService
{

    @Autowired
    private ISysApplyConfigService sysApplyConfigService;

    @Autowired
    private QuartzProjectAttendanceCfgMapper quartzProjectAttendanceCfgMapper;

    /**
     * 查询项目考勤配置
     * 
     * @param id 项目考勤配置主键
     * @return 项目考勤配置
     */
    @Override
    public QuartzProjectAttendanceCfg selectSurProjectAttendanceCfgById(Long id)
    {
        return quartzProjectAttendanceCfgMapper.selectSurProjectAttendanceCfgById(id);
    }

    /**
     * 查询项目考勤配置列表
     * 
     * @param quartzProjectAttendanceCfg 项目考勤配置
     * @return 项目考勤配置
     */
    @Override
    public List<QuartzProjectAttendanceCfg> selectSurProjectAttendanceCfgList(QuartzProjectAttendanceCfg quartzProjectAttendanceCfg)
    {
        return quartzProjectAttendanceCfgMapper.selectSurProjectAttendanceCfgList(quartzProjectAttendanceCfg);
    }

    /**
     * 新增项目考勤配置
     * 
     * @param quartzProjectAttendanceCfg 项目考勤配置
     * @return 结果
     */
    @Override
    public int insertSurProjectAttendanceCfg(QuartzProjectAttendanceCfg quartzProjectAttendanceCfg)
    {
        String userName=SecurityUtils.getUsername();
        quartzProjectAttendanceCfg.setCreateBy(StrUtil.isEmpty(userName)?"task":userName);
        quartzProjectAttendanceCfg.setCreateTime(DateUtils.getNowDate());
        return quartzProjectAttendanceCfgMapper.insertSurProjectAttendanceCfg(quartzProjectAttendanceCfg);
    }

    /**
     * 修改项目考勤配置
     * 
     * @param quartzProjectAttendanceCfg 项目考勤配置
     * @return 结果
     */
    @Override
    public int updateSurProjectAttendanceCfg(QuartzProjectAttendanceCfg quartzProjectAttendanceCfg)
    {
        String userName=SecurityUtils.getUsername();
        quartzProjectAttendanceCfg.setUpdateBy(StrUtil.isEmpty(userName)?"task":userName);
        quartzProjectAttendanceCfg.setUpdateTime(DateUtils.getNowDate());
        if(VendorsCodeEnum.YANZHU.getCode().equals(quartzProjectAttendanceCfg.getVendorsCode())){
            SysApplyConfig sysApplyConfig = new SysApplyConfig();
            sysApplyConfig.setCfgType(ApplyCfgTypeEnum.LABOUR.getCode());
            sysApplyConfig.setCfgId(quartzProjectAttendanceCfg.getId());
            List<SysApplyConfig> list = sysApplyConfigService.selectSysApplyConfigList(sysApplyConfig);
            if(CollectionUtils.isNotEmpty(list)){
                sysApplyConfig = list.get(0);
                sysApplyConfig.setIsDel(quartzProjectAttendanceCfg.getEnabled().equals(ShiFouEnum.FOU.getLongCode())?ShiFouEnum.SHI.getCode():ShiFouEnum.FOU.getCode());
                sysApplyConfigService.updateSysApplyConfig(sysApplyConfig);
            }
        }
        return quartzProjectAttendanceCfgMapper.updateSurProjectAttendanceCfg(quartzProjectAttendanceCfg);
    }

    /**
     * 批量删除项目考勤配置
     * 
     * @param ids 需要删除的项目考勤配置主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceCfgByIds(Long[] ids)
    {
        List<Long> cfgIds = new ArrayList<>();
        for(Long id:ids){
            QuartzProjectAttendanceCfg quartzProjectAttendanceCfg = quartzProjectAttendanceCfgMapper.selectSurProjectAttendanceCfgById(id);
            if(VendorsCodeEnum.YANZHU.getCode().equals(quartzProjectAttendanceCfg.getVendorsCode())){
                SysApplyConfig sysApplyConfig = new SysApplyConfig();
                sysApplyConfig.setCfgType(ApplyCfgTypeEnum.LABOUR.getCode());
                sysApplyConfig.setCfgId(id);
                List<SysApplyConfig> list = sysApplyConfigService.selectSysApplyConfigList(sysApplyConfig);
                if(CollectionUtils.isNotEmpty(list)){
                    cfgIds.add(list.get(0).getId());
                }
            }
        }
        if(CollectionUtils.isNotEmpty(cfgIds)){
            sysApplyConfigService.deleteSysApplyConfigByIds(cfgIds.stream().toArray(Long[]::new));
        }
        return quartzProjectAttendanceCfgMapper.deleteSurProjectAttendanceCfgByIds(ids);
    }

    /**
     * 删除项目考勤配置信息
     * 
     * @param id 项目考勤配置主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceCfgById(Long id)
    {
        QuartzProjectAttendanceCfg quartzProjectAttendanceCfg = quartzProjectAttendanceCfgMapper.selectSurProjectAttendanceCfgById(id);
        if(VendorsCodeEnum.YANZHU.getCode().equals(quartzProjectAttendanceCfg.getVendorsCode())){
            SysApplyConfig sysApplyConfig = new SysApplyConfig();
            sysApplyConfig.setCfgType(ApplyCfgTypeEnum.LABOUR.getCode());
            sysApplyConfig.setCfgId(id);
            List<SysApplyConfig> list = sysApplyConfigService.selectSysApplyConfigList(sysApplyConfig);
            if(CollectionUtils.isNotEmpty(list)){
                sysApplyConfigService.deleteSysApplyConfigById(list.get(0).getId());
            }
        }
        return quartzProjectAttendanceCfgMapper.deleteSurProjectAttendanceCfgById(id);
    }
}
