package com.ruoyi.quartz.service.impl;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.quartz.domain.QuartzProjectAttendanceCfg;
import com.ruoyi.quartz.domain.QuartzProjectAttendanceData;
import com.ruoyi.quartz.domain.QuartzProjectAttendanceGroup;
import com.ruoyi.quartz.domain.QuartzProjectAttendanceUser;
import com.ruoyi.quartz.mapper.QuartzProjectAttendanceCfgMapper;
import com.ruoyi.quartz.mapper.QuartzProjectAttendanceDataMapper;
import com.ruoyi.quartz.mapper.QuartzProjectAttendanceGroupMapper;
import com.ruoyi.quartz.mapper.QuartzProjectAttendanceUserMapper;
import com.ruoyi.quartz.service.IQuartzProjectAttendanceDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * 劳务实名制管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-09-24
 */
@Service
public class QuartzProjectAttendanceDataServiceImpl implements IQuartzProjectAttendanceDataService
{
    @Autowired
    private QuartzProjectAttendanceDataMapper quartzProjectAttendanceDataMapper;

    @Autowired
    private QuartzProjectAttendanceUserMapper quartzProjectAttendanceUserMapper;

    @Autowired
    private QuartzProjectAttendanceGroupMapper quartzProjectAttendanceGroupMapper;

    @Autowired
    private QuartzProjectAttendanceCfgMapper quartzProjectAttendanceCfgMapper;


    /**
     * 查询劳务实名制管理
     * 
     * @param id 劳务实名制管理主键
     * @return 劳务实名制管理
     */
    @Override
    public QuartzProjectAttendanceData selectSurProjectAttendanceDataById(Long id)
    {
        return quartzProjectAttendanceDataMapper.selectSurProjectAttendanceDataById(id);
    }

    /**
     * 查询劳务实名制管理列表
     * 
     * @param quartzProjectAttendanceData 劳务实名制管理
     * @return 劳务实名制管理
     */
    @Override
    public List<QuartzProjectAttendanceData> selectSurProjectAttendanceDataList(QuartzProjectAttendanceData quartzProjectAttendanceData)
    {
        return quartzProjectAttendanceDataMapper.selectSurProjectAttendanceDataList(quartzProjectAttendanceData);
    }

    /**
     * 查询考勤信息
     *
     * @param quartzProjectAttendanceData 劳务实名制管理
     * @return 劳务实名制管理集合
     */
    @Override
    public QuartzProjectAttendanceData findCurrentAttendanceData(QuartzProjectAttendanceData quartzProjectAttendanceData){
        return quartzProjectAttendanceDataMapper.findCurrentAttendanceData(quartzProjectAttendanceData);
    }

    @Override
    public List<QuartzProjectAttendanceData> selectSurProjectAttendanceDataListEx(QuartzProjectAttendanceData quartzProjectAttendanceData)
    {
        return quartzProjectAttendanceDataMapper.selectSurProjectAttendanceDataListEx(quartzProjectAttendanceData);
    }

    /**
     * 新增劳务实名制管理
     * 
     * @param quartzProjectAttendanceData 劳务实名制管理
     * @return 结果
     */
    @Override
    public int insertSurProjectAttendanceData(QuartzProjectAttendanceData quartzProjectAttendanceData)
    {
        String userName= SecurityUtils.getUsername();
            quartzProjectAttendanceData.setCreateBy(StrUtil.isEmpty(userName)?"task":userName);
            quartzProjectAttendanceData.setCreateTime(DateUtils.getNowDate());

        return quartzProjectAttendanceDataMapper.insertSurProjectAttendanceData(quartzProjectAttendanceData);
    }

    /**
     * 修改劳务实名制管理
     * 
     * @param quartzProjectAttendanceData 劳务实名制管理
     * @return 结果
     */
    @Override
    public int updateSurProjectAttendanceData(QuartzProjectAttendanceData quartzProjectAttendanceData)
    {
        String userName=SecurityUtils.getUsername();
            quartzProjectAttendanceData.setUpdateBy(StrUtil.isEmpty(userName)?"task":userName);

        quartzProjectAttendanceData.setUpdateTime(DateUtils.getNowDate());
        return quartzProjectAttendanceDataMapper.updateSurProjectAttendanceData(quartzProjectAttendanceData);
    }

    /**
     * 批量删除劳务实名制管理
     * 
     * @param ids 需要删除的劳务实名制管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceDataByIds(Long[] ids)
    {
        return quartzProjectAttendanceDataMapper.deleteSurProjectAttendanceDataByIds(ids);
    }

    /**
     * 删除劳务实名制管理信息
     * 
     * @param id 劳务实名制管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceDataById(Long id)
    {
        return quartzProjectAttendanceDataMapper.deleteSurProjectAttendanceDataById(id);
    }

    /**
     * 批量删除劳务实名制管理
     *
     * @param list 需要删除的数据参数集合
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceDataByParams(List<String> list) {
        return quartzProjectAttendanceDataMapper.deleteSurProjectAttendanceDataByParams(list);
    }

    /**
     * 批量新增劳务实名制考勤管理
     *
     * @param quartzProjectAttendanceDataList 劳务实名制考勤管理列表
     * @return 结果
     */
    @Override
    public int batchSurProjectAttendanceData(List<QuartzProjectAttendanceData> quartzProjectAttendanceDataList) {
        return quartzProjectAttendanceDataMapper.batchSurProjectAttendanceData(quartzProjectAttendanceDataList,DateUtils.dateTimeNow(DateUtils.YYYY));
    }

    @Override
    public void add(QuartzProjectAttendanceData sdata) {
        if(StringUtils.isEmpty(sdata.getWorkerId()) || StringUtils.isEmpty(sdata.getAttendanceTime())){
            return;
        }
        QuartzProjectAttendanceData where=new QuartzProjectAttendanceData();
        where.setVendorsCode(sdata.getVendorsCode());
        where.setCfgid(sdata.getCfgid());
        where.setWorkerId(sdata.getWorkerId());
        where.setAttendanceTime(sdata.getAttendanceTime());
        List<QuartzProjectAttendanceData> list=selectSurProjectAttendanceDataListEx(where);
        if(list.size()==0){
            //设置考勤其它参数
            //查询人员信息
            QuartzProjectAttendanceUser userWhere=new QuartzProjectAttendanceUser();
            userWhere.setWorkerId(sdata.getWorkerId());
            List<QuartzProjectAttendanceUser> uList= quartzProjectAttendanceUserMapper.selectSurProjectAttendanceUserList(userWhere);
            if(uList.size()==0){
                return;
            }
            QuartzProjectAttendanceUser user=uList.get(0);
            sdata.setWorkerName(user.getName());
            String photo=user.getPhoto();
            if(StrUtil.isEmpty(photo)){
                photo=user.getRecentPhoto();
            }

            sdata.setWorkerPhoto(photo);
            sdata.setWorkerGender(user.getGender());;
            sdata.setGroupName(user.getGroupName());
            sdata.setWorkTypeName(user.getWorkTypeName());
            sdata.setEthnic(user.getEthnic());
            sdata.setNativePlace(user.getNativePlace());
            sdata.setPhone(user.getPhone());
            sdata.setSpecWorkType(user.getSpecWorkType());
            if("jgw".equals(sdata.getVendorsCode())) {
                sdata.setCompanyId(user.getCompanyId());
            }
            //查询分组信息
            QuartzProjectAttendanceGroup groupWhere=new QuartzProjectAttendanceGroup();
            groupWhere.setCfgid(sdata.getCfgid());
            groupWhere.setCompanyId(sdata.getCompanyId());
            List<QuartzProjectAttendanceGroup> gList= quartzProjectAttendanceGroupMapper.selectSurProjectAttendanceGroupList(groupWhere);
            if(gList.size()==0){
                return;
            }
            QuartzProjectAttendanceGroup group=gList.get(0);
            sdata.setCompanyName(group.getCompanyName());
            sdata.setCompanyTypeId(group.getCompanyTypeId());
            //查询华筑的分组信息
            if("huazhu".equals(sdata.getVendorsCode())){
                sdata.setWorkerGender(sdata.getWorkerGender());
                sdata.setCompanyTypeId(getHuazhuCompanyTypeId(group.getCompanyName()));//获取华筑的分包商类型
            }
            if("jgw".equals(sdata.getVendorsCode())){
                //sdata.setWorkTypeName(group.getCompanyCode());
                //sdata.setCompanyName(user.getCompanyName());
                sdata.setWorkTypeName(user.getWorkTypeName());
                sdata.setCompanyName(group.getCompanyName());
                sdata.setGroupName(group.getTeamName());
            }
            //查询项目部门信息
            QuartzProjectAttendanceCfg cfgWhere=new QuartzProjectAttendanceCfg();
            cfgWhere.setId(sdata.getCfgid());
            List<QuartzProjectAttendanceCfg> cfgList= quartzProjectAttendanceCfgMapper.selectSurProjectAttendanceCfgListForAllInfo(cfgWhere);
            if(cfgList.size()==0){
                return;
            }
            QuartzProjectAttendanceCfg cfg=cfgList.get(0);
            sdata.setProjectId(cfg.getProjectId());
            sdata.setDeptId(cfg.getSubDeptId());
            sdata.setProjectName(cfg.getProjectName());
            sdata.setDeptName(cfg.getDeptName());
            if(sdata.getCompanyTypeId()==null){
                sdata.setCompanyTypeId("0");
            }
            insertSurProjectAttendanceData(sdata);
        }else{
            sdata.setId(list.get(0).getId());
            QuartzProjectAttendanceData upData=list.get(0);
            String dt1=upData.getAttendanceTime(); //
            String dt2=upData.getAttendanceOutTime();
            String dt3=sdata.getAttendanceTime();
            if (StrUtil.isEmpty(dt3)) {
                return;
            }
            long time3=DateUtil.parse(dt3).getTime();
            if(StrUtil.isEmpty(dt2)){
                upData.setAttendanceOutTime(dt3);
                //比较 dt1,dt2 进行交换
                long time2=DateUtil.parse(dt3).getTime();
                long time1=DateUtil.parse(dt1).getTime();
                if(time1>time2){
                    upData.setAttendanceTime(dt3);
                    upData.setAttendanceOutTime(dt1);
                }
            }else{
                long time2=DateUtil.parse(dt2).getTime();
                long time1=DateUtil.parse(dt1).getTime();
                //比较 dt3<dt1 in->dt3
                if(time3<time1){
                    upData.setAttendanceTime(dt3);
                }
                //比较 dt3>dt2 out->dt3
                if(time3>time2){
                    upData.setAttendanceOutTime(dt3);
                }
            }
            //upData.setAttendanceOutTime(sdata.getAttendanceTime());
            if("jgw".equals(upData.getVendorsCode())){
                upData.setRemark(sdata.getRemark());
            }
            updateSurProjectAttendanceData(upData);
        }
    }

    private String getHuazhuCompanyTypeId(String groupName) {
        return quartzProjectAttendanceDataMapper.findHuaZhuCompanyType(groupName);
    }

    @Override
    public String getLastServerId(QuartzProjectAttendanceData where) {
        return ""+ quartzProjectAttendanceDataMapper.getLastServerId(where);
    }

    @Override
    public List<QuartzProjectAttendanceData> groupByComany(QuartzProjectAttendanceData where) {
        return quartzProjectAttendanceDataMapper.groupByComany(where);
    }

    @Override
    public Long getHuazhuPage( QuartzProjectAttendanceData attWhere) {
        return quartzProjectAttendanceDataMapper.getHuazhuPage(attWhere);
    }

    @Override
    public List<QuartzProjectAttendanceData> groupAllByComany(QuartzProjectAttendanceData where) {
        return quartzProjectAttendanceDataMapper.groupAllByComany(where);
    }

    @Override
    public List<Map<String,Object>> initOtherData(Map<String,Object> data) {
        List<Map<String,Object>> dataList = new ArrayList<>();
        List<Map<String,Object>> list = quartzProjectAttendanceDataMapper.initOtherData(data);
        if(StringUtils.isNotEmpty(list)){
            List<String> workerIds = list.stream().map(Map -> Map.get("workerId").toString()).collect(Collectors.toList());
            data.put("list",workerIds);
            List<QuartzProjectAttendanceUser> datas= quartzProjectAttendanceUserMapper.todayAttendanceOtherData(data);
            for (Map<String,Object> map:list) {
                for(QuartzProjectAttendanceUser sau:datas){
                    if(Objects.equals(map.get("workerId").toString(),sau.getWorkerId())){
                        map.put("inTime",DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,sau.getInTime()));
                        map.put("outTime",DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,sau.getOutTime()));
                        dataList.add(map);
                    }
                }
            }
        }
        return dataList;
    }

    @Override
    public List<Map<String,Object>> initHuaZhuData(Map<String,Object> data) {
        List<Map<String,Object>> dataList = new ArrayList<>();
        List<Map<String,Object>> list = quartzProjectAttendanceDataMapper.initHuaZhuData(data);
        if(StringUtils.isNotEmpty(list)){
            List<String> workerIds = list.stream().map(Map -> Map.get("workerId").toString()).collect(Collectors.toList());
            data.put("list",workerIds);
            List<QuartzProjectAttendanceUser> datas= quartzProjectAttendanceUserMapper.todayAttendanceOtherData(data);
            for (Map<String,Object> map:list) {
                for(QuartzProjectAttendanceUser sau:datas){
                    if(Objects.equals(map.get("workerId").toString(),sau.getWorkerId())){
                        map.put("inTime",DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,sau.getInTime()));
                        map.put("outTime",DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,sau.getOutTime()));
                        dataList.add(map);
                    }
                }
            }
        }
        return dataList;
    }

    @Override
    public List<QuartzProjectAttendanceData> todayAttendance(QuartzProjectAttendanceData where) {
        return quartzProjectAttendanceDataMapper.todayAttendance(where);
    }

    /**
     * 统计所有数据
     * @param where
     * @return
     */
    @Override
    public List<Map<String, Object>> groupAllByParams(QuartzProjectAttendanceData where) {
        return quartzProjectAttendanceDataMapper.findGroupAllByParams(where);
    }

    /**
     * 统计人员数据
     * @param where
     * @return
     */
    @Override
    public List<Map<String, Object>> findGroupAllByDays(QuartzProjectAttendanceData where){
        return quartzProjectAttendanceDataMapper.findGroupAllByDays(where);
    }

    /**
     * 统计考勤数据
     * @param where
     * @return
     */
    @Override
    public List<Map<String, Object>> groupDataByParams(QuartzProjectAttendanceData where){
        return quartzProjectAttendanceDataMapper.groupDataByParams(where);
    }

    /**
     * 考勤数据列表
     * @param where
     * @return
     */
    @Override
    public List<QuartzProjectAttendanceData> attendanceDataList(QuartzProjectAttendanceData where) {
        return quartzProjectAttendanceDataMapper.attendanceDataList(where);
    }

    @Override
    public List<QuartzProjectAttendanceData> groupTodayCompanyTypeId(QuartzProjectAttendanceData where) {
        return quartzProjectAttendanceDataMapper.groupTodayCompanyTypeId(where);
    }

    /**
     * 批量增加
     * @param addList
     */
    @Override
    public void addList(List<QuartzProjectAttendanceData> addList) {
        if(addList.size()==0){
            return;
        }
        QuartzProjectAttendanceData where=new QuartzProjectAttendanceData();
        where.setVendorsCode(addList.get(0).getVendorsCode());
        where.setCfgid(addList.get(0).getCfgid());
        where.setAttendanceTime(addList.get(0).getAttendanceTime());
        List<QuartzProjectAttendanceData> oldList=selectSurProjectAttendanceDataListEx(where);
        for(QuartzProjectAttendanceData sdata:addList){
            List<QuartzProjectAttendanceData> list=oldList.stream().filter(d->d.getWorkerId().equals(sdata.getWorkerId())).collect(Collectors.toList());
            if(list.size()==0){
                //设置考勤其它参数
                //查询人员信息
                QuartzProjectAttendanceUser userWhere=new QuartzProjectAttendanceUser();
                userWhere.setWorkerId(sdata.getWorkerId());
                List<QuartzProjectAttendanceUser> uList= quartzProjectAttendanceUserMapper.selectSurProjectAttendanceUserList(userWhere);
                if(uList.size()==0){
                    return;
                }
                QuartzProjectAttendanceUser user=uList.get(0);
                sdata.setWorkerName(user.getName());
                String photo=user.getPhoto();
                if(StrUtil.isEmpty(photo)){
                    photo=user.getRecentPhoto();
                }

                sdata.setWorkerPhoto(photo);
                sdata.setWorkerGender(user.getGender());;
                sdata.setGroupName(user.getGroupName());
                sdata.setWorkTypeName(user.getWorkTypeName());
                sdata.setEthnic(user.getEthnic());
                sdata.setNativePlace(user.getNativePlace());
                sdata.setPhone(user.getPhone());
                sdata.setSpecWorkType(user.getSpecWorkType());
                if("jgw".equals(sdata.getVendorsCode())) {
                    sdata.setCompanyId(user.getCompanyId());
                }
                //查询分组信息
                QuartzProjectAttendanceGroup groupWhere=new QuartzProjectAttendanceGroup();
                groupWhere.setCfgid(sdata.getCfgid());
                groupWhere.setCompanyId(sdata.getCompanyId());
                List<QuartzProjectAttendanceGroup> gList= quartzProjectAttendanceGroupMapper.selectSurProjectAttendanceGroupList(groupWhere);
                if(gList.size()==0){
                    return;
                }
                QuartzProjectAttendanceGroup group=gList.get(0);
                sdata.setCompanyName(group.getCompanyName());
                sdata.setCompanyTypeId(group.getCompanyTypeId());
                //查询华筑的分组信息
                if("huazhu".equals(sdata.getVendorsCode())){
                    sdata.setWorkerGender(sdata.getWorkerGender());
                    sdata.setCompanyTypeId(getHuazhuCompanyTypeId(group.getCompanyName()));//获取华筑的分包商类型
                }
                if("jgw".equals(sdata.getVendorsCode())){
                    //sdata.setWorkTypeName(group.getCompanyCode());
                    //sdata.setCompanyName(user.getCompanyName());
                    sdata.setWorkTypeName(user.getWorkTypeName());
                    sdata.setCompanyName(group.getCompanyName());
                    sdata.setGroupName(group.getTeamName());
                }
                //查询项目部门信息
                QuartzProjectAttendanceCfg cfgWhere=new QuartzProjectAttendanceCfg();
                cfgWhere.setId(sdata.getCfgid());
                List<QuartzProjectAttendanceCfg> cfgList= quartzProjectAttendanceCfgMapper.selectSurProjectAttendanceCfgListForAllInfo(cfgWhere);
                if(cfgList.size()==0){
                    return;
                }
                QuartzProjectAttendanceCfg cfg=cfgList.get(0);
                sdata.setProjectId(cfg.getProjectId());
                sdata.setDeptId(cfg.getSubDeptId());
                sdata.setProjectName(cfg.getProjectName());
                sdata.setDeptName(cfg.getDeptName());
                if(sdata.getCompanyTypeId()==null){
                    sdata.setCompanyTypeId("0");
                }
                insertSurProjectAttendanceData(sdata);
            }else{
                sdata.setId(list.get(0).getId());
                QuartzProjectAttendanceData upData=list.get(0);
                String dt1=upData.getAttendanceTime(); //
                String dt2=upData.getAttendanceOutTime();
                String dt3=sdata.getAttendanceTime();
                if (StrUtil.isEmpty(dt3)) {
                    return;
                }
                long time3=DateUtil.parse(dt3).getTime();
                if(StrUtil.isEmpty(dt2)){
                    upData.setAttendanceOutTime(dt3);
                    //比较 dt1,dt2 进行交换
                    long time2=DateUtil.parse(dt3).getTime();
                    long time1=DateUtil.parse(dt1).getTime();
                    if(time1>time2){
                        upData.setAttendanceTime(dt3);
                        upData.setAttendanceOutTime(dt1);
                    }
                }else{
                    long time2=DateUtil.parse(dt2).getTime();
                    long time1=DateUtil.parse(dt1).getTime();
                    //比较 dt3<dt1 in->dt3
                    if(time3<time1){
                        upData.setAttendanceTime(dt3);
                    }
                    //比较 dt3>dt2 out->dt3
                    if(time3>time2){
                        upData.setAttendanceOutTime(dt3);
                    }
                }
                //upData.setAttendanceOutTime(sdata.getAttendanceTime());
                if("jgw".equals(upData.getVendorsCode())){
                    upData.setRemark(sdata.getRemark());
                }
                updateSurProjectAttendanceData(upData);
            }
        }
    }

}
