package com.ruoyi.quartz.service.impl;

import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.quartz.domain.QuartzProjectAttendanceGroup;
import com.ruoyi.quartz.mapper.QuartzProjectAttendanceGroupMapper;
import com.ruoyi.quartz.service.IQuartzProjectAttendanceGroupService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 广联达班组信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-09-26
 */
@Service
public class QuartzProjectAttendanceGroupServiceImpl implements IQuartzProjectAttendanceGroupService
{
    @Autowired
    private QuartzProjectAttendanceGroupMapper quartzProjectAttendanceGroupMapper;

    /**
     * 查询广联达班组信息
     * 
     * @param id 广联达班组信息主键
     * @return 广联达班组信息
     */
    @Override
    public QuartzProjectAttendanceGroup selectSurProjectAttendanceGroupById(Long id)
    {
        return quartzProjectAttendanceGroupMapper.selectSurProjectAttendanceGroupById(id);
    }

    /**
     * 查询广联达班组信息列表
     * 
     * @param quartzProjectAttendanceGroup 广联达班组信息
     * @return 广联达班组信息
     */
    @Override
    public List<QuartzProjectAttendanceGroup> selectSurProjectAttendanceGroupViewList(QuartzProjectAttendanceGroup quartzProjectAttendanceGroup)
    {
        return quartzProjectAttendanceGroupMapper.selectSurProjectAttendanceGroupViewList(quartzProjectAttendanceGroup);
    }

    /**
     * 查询广联达班组信息列表
     *
     * @param quartzProjectAttendanceGroup 广联达班组信息
     * @return 广联达班组信息集合
     */
    public List<QuartzProjectAttendanceGroup> selectSurProjectAttendanceGroupList(QuartzProjectAttendanceGroup quartzProjectAttendanceGroup) {
        return quartzProjectAttendanceGroupMapper.selectSurProjectAttendanceGroupList(quartzProjectAttendanceGroup);
    }
    /**
     * 新增广联达班组信息
     * 
     * @param quartzProjectAttendanceGroup 广联达班组信息
     * @return 结果
     */
    @Override
    public int insertSurProjectAttendanceGroup(QuartzProjectAttendanceGroup quartzProjectAttendanceGroup)
    {
        String userName= SecurityUtils.getUsername();
        quartzProjectAttendanceGroup.setCreateBy(StrUtil.isEmpty(userName)?"task":userName);
        quartzProjectAttendanceGroup.setCreateTime(DateUtils.getNowDate());
        return quartzProjectAttendanceGroupMapper.insertSurProjectAttendanceGroup(quartzProjectAttendanceGroup);
    }

    /**
     * 修改广联达班组信息
     * 
     * @param quartzProjectAttendanceGroup 广联达班组信息
     * @return 结果
     */
    @Override
    public int updateSurProjectAttendanceGroup(QuartzProjectAttendanceGroup quartzProjectAttendanceGroup)
    {
        String userName= SecurityUtils.getUsername();
            quartzProjectAttendanceGroup.setUpdateBy(StrUtil.isEmpty(userName)?"task":userName);

        quartzProjectAttendanceGroup.setUpdateTime(DateUtils.getNowDate());
        return quartzProjectAttendanceGroupMapper.updateSurProjectAttendanceGroup(quartzProjectAttendanceGroup);
    }

    /**
     * 批量删除广联达班组信息
     * 
     * @param ids 需要删除的广联达班组信息主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceGroupByIds(Long[] ids)
    {
        return quartzProjectAttendanceGroupMapper.deleteSurProjectAttendanceGroupByIds(ids);
    }

    /**
     * 删除广联达班组信息信息
     * 
     * @param id 广联达班组信息主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceGroupById(Long id)
    {
        return quartzProjectAttendanceGroupMapper.deleteSurProjectAttendanceGroupById(id);
    }

    /**
     * 批量删除广联达班组信息
     *
     * @param list 需要删除的数据参数集合
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceGroupByParams(List<String> list) {
        return quartzProjectAttendanceGroupMapper.deleteSurProjectAttendanceGroupByParams(list);
    }

    /**
     * 批量新增广联达班组信息
     *
     * @param quartzProjectAttendanceGroupList 广联达班组信息列表
     * @return 结果
     */
    @Override
    public int batchSurProjectAttendanceGroup(List<QuartzProjectAttendanceGroup> quartzProjectAttendanceGroupList) {
        return quartzProjectAttendanceGroupMapper.batchSurProjectAttendanceGroup(quartzProjectAttendanceGroupList);
    }

    @Override
    public void add(QuartzProjectAttendanceGroup group) {
        QuartzProjectAttendanceGroup where=new QuartzProjectAttendanceGroup();
        where.setServerid(group.getServerid());
        where.setCfgid(group.getCfgid());
        List<QuartzProjectAttendanceGroup> list=selectSurProjectAttendanceGroupList(where);
        if(list.size()==0){
            insertSurProjectAttendanceGroup(group);
        }else{
            group.setId(list.get(0).getId());
            updateSurProjectAttendanceGroup(group);
        }
    }

    /**
     * 更新济工网的分组类型
     * @param group
     */
    @Override
    public void updateJgw(QuartzProjectAttendanceGroup group) {
        QuartzProjectAttendanceGroup where=new QuartzProjectAttendanceGroup();
        where.setBizLicense(group.getBizLicense());
        List<QuartzProjectAttendanceGroup> list=selectSurProjectAttendanceGroupList(where);
        for(QuartzProjectAttendanceGroup g:list){
            g.setCompanyTypeId(group.getCompanyTypeId());
            updateSurProjectAttendanceGroup(g);
        }
    }
}
