package com.ruoyi.quartz.task;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.quartz.domain.*;
import com.ruoyi.quartz.service.*;
import okhttp3.HttpUrl;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Response;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.logging.log4j.util.Strings;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

@Component("attendanceTask")
public class AttendanceTask {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private ISysNativeService sysNativeService;

    @Autowired
    IQuartzProjectAttendanceUserService attendanceUserService;

    @Autowired
    IQuartzProjectAttendanceCfgService attendanceCfgService;

    @Autowired
    IQuartzProjectAttendanceDataService attendanceDataService;

    @Autowired
    IQuartzProjectAttendanceGroupService attendanceGroupService;

    private String getNative(long id){
        String ckey="attendance_jgw_native_"+id;
        Object obj=redisCache.getCacheObject(ckey);
        String tmp="";
        if(obj!=null){
            tmp=obj.toString();
            if(StrUtil.isNotEmpty(tmp)){
                return  tmp;
            }
        }
        List<SysNative> list=sysNativeService.selectSysNativeListById(id);
        if(list.size()==0){
            id=id/100*100;
            list=sysNativeService.selectSysNativeListById(id);
            if(list.size()==0){
                id=id/10000*10000;
                list=sysNativeService.selectSysNativeListById(id);
            }
        }
        if(list.size()==0){
            tmp="";
        }else{
            tmp= list.get(0).getAddress();
        }
        redisCache.setCacheObject(ckey, tmp, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.DAYS);
        return  tmp;
    }

    public  void syncWorker(){
        QuartzProjectAttendanceCfg where =new QuartzProjectAttendanceCfg();
        where.setEnabled(1l);
        where.setIsDel(0l);
        where.setVendorsCode("gld");
        List<QuartzProjectAttendanceCfg> list=attendanceCfgService.selectSurProjectAttendanceCfgList(where);
        for(QuartzProjectAttendanceCfg it :list){
            String param= it.getVendorsParameter();
            if(Strings.isNotEmpty(param)){
                try{
                    JSONObject jo=JSON.parseObject(param);
                    String appId=jo.getString("appId");
                    String secret=jo.getString("secret");
                    String projectId=jo.getString("projectId");
                    doSyncWorker(appId,secret,projectId,1,it);
                }catch (Exception ex){
                    ex.printStackTrace();
                }
            }
        }
    }

    public void syncGroup(){
        QuartzProjectAttendanceCfg where =new QuartzProjectAttendanceCfg();
        where.setEnabled(1l);
        where.setIsDel(0l);
        where.setVendorsCode("gld");
        List<QuartzProjectAttendanceCfg> list=attendanceCfgService.selectSurProjectAttendanceCfgList(where);
        for(QuartzProjectAttendanceCfg it :list){
            String param= it.getVendorsParameter();
            if(Strings.isNotEmpty(param)){
                try{
                    JSONObject jo=JSON.parseObject(param);
                    String appId=jo.getString("appId");
                    String secret=jo.getString("secret");
                    String projectId=jo.getString("projectId");
                    doSyncGroup(appId,secret,projectId,it);
                }catch (Exception ex){
                    ex.printStackTrace();
                }
            }
        }
    }

    private void doSyncGroup(String appId, String secret, String projectId, QuartzProjectAttendanceCfg it) {
        Map<String, Object> params = new HashMap<>();
        params.put("projectId", projectId);
        params.put("appid",appId);
        String sign = getSign(params,secret);
        String host="https://glm.glodon.com/api/open";
        params.put("sign",sign);
        String path="/worker/allGroup";
        HttpUrl.Builder urlBuilder = Objects.requireNonNull(HttpUrl.parse(host + path)).newBuilder();
        params.forEach((s, o) -> {
            urlBuilder.addQueryParameter(s, (String) o);
        });
        Request request = new Request.Builder()
                .url(urlBuilder.build())
                .build();
        String data=getResult(request);
        JSONObject jo= JSON.parseObject(data);
        JSONArray arr=jo.getJSONArray("data");
        if(arr!=null && arr.size()>0) {
            for (int i = 0; i < arr.size(); i++) {
                JSONObject json=arr.getJSONObject(i);
                QuartzProjectAttendanceGroup group= QuartzProjectAttendanceGroup.create(json);
                group.setAppId(appId);
                group.setCfgid(it.getId());
                attendanceGroupService.add(group);
            }
        }
    }

    private  void doSyncWorker(String appid, String secret, String projectld, int page, QuartzProjectAttendanceCfg it){
        Map<String, Object> params = new HashMap<>();
        params.put("projectId", projectld);
        params.put("start", "2000-01-01 00:00:00");
        params.put("end", "2099-01-01 00:00:00");
        params.put("pageNo",""+page);
        params.put("pageSize", "1000");
        params.put("appid",appid);
        String sign = getSign(params,secret);
        String host="https://glm.glodon.com/api/open";
        params.put("sign",sign);
        String path="/worker/new/allWorkerInfo";
        HttpUrl.Builder urlBuilder = Objects.requireNonNull(HttpUrl.parse(host + path)).newBuilder();
        params.forEach((s, o) -> {
            urlBuilder.addQueryParameter(s, (String) o);
        });
        Request request = new Request.Builder()
                .url(urlBuilder.build())
                .build();
        String data=getResult(request);
        JSONObject jo= JSON.parseObject(data);
        JSONArray arr=jo.getJSONArray("data");
        if(arr!=null && arr.size()>0){
          for(int i=0;i<arr.size();i++){
              JSONObject json=arr.getJSONObject(i);
              QuartzProjectAttendanceUser user= QuartzProjectAttendanceUser.create(json);
              String idNumber=json.getString("identification");//身份证
              if(StrUtil.isNotEmpty(idNumber) && idNumber.length()>6){
                  try {
                      long idStr = Long.parseLong(idNumber.substring(0, 6));
                      String natstr=getNative(idStr);
                      if(StrUtil.isNotEmpty(natstr)){
                          user.setNativePlace(natstr);
                      }
                  }catch (Exception ex){

                  }
              }
              user.setVendorsCode(it.getVendorsCode());
              user.setCfgid(it.getId());
              user.setAppId(appid);
              attendanceUserService.add(user);
          }
        }
        if(arr.size()==1000){
            doSyncWorker(appid,secret,projectld,page+1,it);
        }
    }

    public void  syncAttendanceData(){
        QuartzProjectAttendanceCfg where =new QuartzProjectAttendanceCfg();
        where.setEnabled(1l);
        where.setIsDel(0l);
        where.setVendorsCode("gld");
        List<QuartzProjectAttendanceCfg> list=attendanceCfgService.selectSurProjectAttendanceCfgList(where);
        for(QuartzProjectAttendanceCfg it :list){
            String param= it.getVendorsParameter();
            if(Strings.isNotEmpty(param)){
                try{
                    JSONObject jo=JSON.parseObject(param);
                    String appId=jo.getString("appId");
                    String secret=jo.getString("secret");
                    String projectId=jo.getString("projectId");
                    QuartzProjectAttendanceData dwhere=new QuartzProjectAttendanceData();
                    dwhere.setCfgid(it.getId());
                    String startId=attendanceDataService.getLastServerId(dwhere);
                    doSyncAttendanceData(appId,secret,projectId,startId,it);
                }catch (Exception ex){
                    ex.printStackTrace();
                }
            }
        }
    }

    private void doSyncAttendanceData(String appid, String secret, String projectId, String id, QuartzProjectAttendanceCfg it){
        Map<String, Object> params = new HashMap<>();
        params.put("projectId", projectId);
        params.put("startId",""+id);
        params.put("pageSize", "500");
        params.put("appid",appid);
        String sign = getSign(params,secret);
        String host="https://glm.glodon.com/api/open";
        params.put("sign",sign);
        String path="/attendance/card";
        HttpUrl.Builder urlBuilder = Objects.requireNonNull(HttpUrl.parse(host + path)).newBuilder();
        params.forEach((s, o) -> {
            urlBuilder.addQueryParameter(s, (String) o);
        });
        Request request = new Request.Builder()
                .url(urlBuilder.build())
                .build();
        String data=getResult(request);
        JSONObject jo= JSON.parseObject(data);
        JSONArray arr=jo.getJSONArray("data");
        String lastId= "0";
        if(arr!=null && arr.size()>0){
            for(int i=0;i<arr.size();i++){
                JSONObject json=arr.getJSONObject(i);
                QuartzProjectAttendanceData sdata= QuartzProjectAttendanceData.create(json);
                lastId=sdata.getServerid();
                sdata.setCfgid(it.getId());
                sdata.setAppId(appid);
                sdata.setVendorsCode(it.getVendorsCode());
               attendanceDataService.add(sdata);
            }
        }
        //System.out.println("-------->"+id+","+lastId);
        if(arr.size()==500){
            doSyncAttendanceData(appid,secret,projectId,lastId,it);
        }
    }
    public static void main(String[] args){

        System.out.println("-------1--------->AttendanceUserTask.syncWorker");
        Map<String, Object> params = new HashMap<>();
        params.put("projectId", "709599705953792");
        params.put("start", "2000-01-01 00:00:00");
        params.put("end", "2099-01-01 00:00:00");
        params.put("pageNo","1");
        params.put("pageSize", "1000");
        //params.put("pageNo", "1");
        params.put("startId", "0");
        params.put("appid","f24454233c5346fe82df6b8dd35e9d6d");
        String sign = getSign(params,"754619e2a33491b84a4d47838d2ffc0a");
        System.out.println("--->"+sign);
        params.put("sign",sign);
        String host="https://glm.glodon.com/api/open";
        String path="/worker/new/allWorkerInfo";
        HttpUrl.Builder urlBuilder = Objects.requireNonNull(HttpUrl.parse(host + path)).newBuilder();
        params.forEach((s, o) -> {
            urlBuilder.addQueryParameter(s, (String) o);
        });
        Request request = new Request.Builder()
                .url(urlBuilder.build())
                .build();
        String data=getResult(request);
        //System.out.println("data:"+data);
        JSONObject jo= JSON.parseObject(data);
        JSONArray jsonArray=jo.getJSONArray("data");
        for(int i=0;i<jsonArray.size();i++){
            JSONObject o=jsonArray.getJSONObject(i);
            //if(o.getLong("workerId")==7813018){
                System.out.println(o.getString("status"));
            //}
        }
    }

    public static String getResult(Request request) {
        OkHttpClient client = new OkHttpClient();
        Response response;
        try {
            response = client.newCall(request).execute();
            if (response.body() != null) {
                return response.body().string();
            } else {
                throw new RuntimeException();
            }
        } catch (IOException e) {
            e.printStackTrace();
            throw new RuntimeException();
        }
    }

    private static String getSign(Map<String,Object> paramsMap,String appSecret){
        List<String> paramsList = new ArrayList<>();
        paramsMap.forEach((s, o) -> {
            String stringBuilder = s + o;
            paramsList.add(stringBuilder);
        });
        StringBuilder beforeMd5 = new StringBuilder();
        beforeMd5.append(appSecret);
        paramsList.stream()
                .sorted(String::compareTo)
                .collect(Collectors.toList())
                .forEach(beforeMd5::append);
        beforeMd5.append(appSecret);
        return DigestUtils.md5Hex(beforeMd5.toString()).toUpperCase();
    }
}
