package com.ruoyi.quartz.task;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.config.WechatAccountConfig;
import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.MessageTypeEnum;
import com.ruoyi.common.enums.TemplateMessageEnum;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.quartz.service.ITaskService;
import com.ruoyi.system.domain.SysUserOpenid;
import com.ruoyi.system.service.ISysConfigService;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateData;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateMessage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * 工作流任务超时提醒定时任务
 *
 * @author JiangYuQi
 */
@Slf4j
@Component("flowTaskExpiredTask")
public class FlowTaskExpiredTask {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private WxMpService wxMpService;

    @Autowired
    private ITaskService taskService;

    @Autowired
    private ISysConfigService configService;

    /**
     * 从Flowable中查询超时数据进行消息提醒
     * 分布式锁::quartz.task.flowTaskExpiredTask.notifyExpiredData
     * 由程序定时调用 JiangYuQi
     * @param
     * @return
     */
    public void notifyApplyExpiredData() {
        /**String key = "quartz.task.flowTaskExpiredTask.notifyExpiredData";
        boolean lock = redisLock.tryLock(key, Constants.REDIS_LOCK, TimeUnit.SECONDS);
        if (lock) {*/
        try {
            log.info("劫持锁...{}...开始执行::工程审批超时提醒定时任务...{}");
            List<WxMpTemplateMessage> list = new ArrayList<>();
            List<Map<String, Object>> flowList = taskService.findDaysAwaitFlowTask();
            for(Map<String, Object> dataMap:flowList){
                List<String> candidateUsers = new ArrayList<>();
                List<String> candidateGroups = new ArrayList<>();
                if(StringUtils.isNotNull(dataMap.get("ASSIGNEE_"))){
                    candidateUsers.add(Convert.toStr(dataMap.get("ASSIGNEE_")));
                }
                if(StringUtils.isNotNull(dataMap.get("USER_ID_"))){
                    candidateUsers.add(Convert.toStr(dataMap.get("USER_ID_")));
                }
                if(StringUtils.isNotNull(dataMap.get("GROUP_ID_"))){
                    candidateGroups.add(Convert.toStr(dataMap.get("GROUP_ID_")));
                }
                String businessKey = Convert.toStr(dataMap.get("businessKey"));
                String businessKeyName = Convert.toStr(dataMap.get("businessKeyName"));
                String total = Convert.toStr(dataMap.get("total"));
                List<SysUser> sysUserList = taskService.findFlowTaskUsers(businessKey,candidateUsers,candidateGroups);
                if(StringUtils.isNotEmpty(sysUserList)){
                    for(SysUser taskUser:sysUserList){
                        //模板数据
                        WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                                .toUser(this.getMsgId(taskUser.getPhonenumber()))
                                .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pages/project_flowable/await/index?category=1&barProId="+businessKey))
                                .templateId(TemplateMessageEnum.APPLY_EXPIRED_MY.getId()).build();
                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", businessKeyName));
                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string8", total));
                        templateMessage.addWxMpTemplateData(new WxMpTemplateData("const9", "项目工程审批"));
                        list.add(templateMessage);
                    }
                    this.send(list,"EXPIRED_"+ MessageTypeEnum.GCSPCSBL.getCode());
                }
            }
        } catch (Exception e) {
            log.info("任务执行异常...{}...::::结束执行...{}", e.getMessage());
            throw e;
        }
        /**finally {
            log.info("释放锁...{}", key);
            redisLock.unlock(key);
        }
        }else{
            log.info("尝试劫持锁失败...{}", key);
        }*/
    }

    /**
     * 从Flowable中查询超时数据进行消息提醒
     * 分布式锁::quartz.task.flowTaskExpiredTask.notifyExpiredData
     * 由程序定时调用 JiangYuQi
     * @param
     * @return
     */
    public void notifyJpysExpiredData() {
        /**String key = "quartz.task.flowTaskExpiredTask.notifyExpiredData";
         boolean lock = redisLock.tryLock(key, Constants.REDIS_LOCK, TimeUnit.SECONDS);
         if (lock) {*/
        try {
            log.info("劫持锁...{}...开始执行::举牌验收超时提醒定时任务...{}");
            List<WxMpTemplateMessage> list = new ArrayList<>();
            List<Map<String, Object>> flowList = taskService.findDaysAwaitJpysList();
            for(Map<String, Object> dataMap:flowList){
                String projectId = Convert.toStr(dataMap.get("projectId"));
                String projectName = Convert.toStr(dataMap.get("projectName"));
                String superviseUser = Convert.toStr(dataMap.get("superviseUser"));
                String total = Convert.toStr(dataMap.get("total"));
                    //模板数据
                    WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                            .toUser(this.getMsgId(superviseUser))
                            .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_checking/list/index?barProId="+projectId))
                            .templateId(TemplateMessageEnum.APPLY_EXPIRED_MY.getId()).build();
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", projectName));
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string8", total));
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("const9", "举牌验收审批"));
                    list.add(templateMessage);
            }
            this.send(list,"EXPIRED_"+ MessageTypeEnum.JPYSSP.getCode());
        } catch (Exception e) {
            log.info("任务执行异常...{}...::::结束执行...{}", e.getMessage());
            throw e;
        }
        /**finally {
         log.info("释放锁...{}", key);
         redisLock.unlock(key);
         }
         }else{
         log.info("尝试劫持锁失败...{}", key);
         }*/
    }

    /**
     * 从Flowable中查询超时数据进行消息提醒
     * 分布式锁::quartz.task.flowTaskExpiredTask.notifyExpiredData
     * 由程序定时调用 JiangYuQi
     * @param
     * @return
     */
    public void notifyScslExpiredData() {
        /**String key = "quartz.task.flowTaskExpiredTask.notifyExpiredData";
         boolean lock = redisLock.tryLock(key, Constants.REDIS_LOCK, TimeUnit.SECONDS);
         if (lock) {*/
        try {
            log.info("劫持锁...{}...开始执行::实测实量超时提醒定时任务...{}");
            List<WxMpTemplateMessage> list = new ArrayList<>();
            List<Map<String, Object>> flowList = taskService.findDaysAwaitScslList();
            for(Map<String, Object> dataMap:flowList){
                String projectId = Convert.toStr(dataMap.get("projectId"));
                String projectName = Convert.toStr(dataMap.get("projectName"));
                String superviseUser = Convert.toStr(dataMap.get("superviseUser"));
                String total = Convert.toStr(dataMap.get("total"));
                //模板数据
                WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                        .toUser(this.getMsgId(superviseUser))
                        .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_measure/list/index?barProId="+projectId))
                        .templateId(TemplateMessageEnum.APPLY_EXPIRED_MY.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", projectName));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string8", total));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("const9", "实测实量审批"));
                list.add(templateMessage);
            }
            this.send(list,"EXPIRED_"+ MessageTypeEnum.CSCLSP.getCode());
        } catch (Exception e) {
            log.info("任务执行异常...{}...::::结束执行...{}", e.getMessage());
            throw e;
        }
        /**finally {
         log.info("释放锁...{}", key);
         redisLock.unlock(key);
         }
         }else{
         log.info("尝试劫持锁失败...{}", key);
         }*/
    }

    /**
     * 从Flowable中查询超时数据进行消息提醒
     * 分布式锁::quartz.task.flowTaskExpiredTask.notifyExpiredData
     * 由程序定时调用 JiangYuQi
     * @param
     * @return
     */
    public void notifyQyfsExpiredData() {
        /**String key = "quartz.task.flowTaskExpiredTask.notifyExpiredData";
         boolean lock = redisLock.tryLock(key, Constants.REDIS_LOCK, TimeUnit.SECONDS);
         if (lock) {*/
        try {
            log.info("劫持锁...{}...开始执行::取样复试超时提醒定时任务...{}");
            List<WxMpTemplateMessage> list = new ArrayList<>();
            List<Map<String, Object>> flowList = taskService.findDaysAwaitQyfsList();
            for(Map<String, Object> dataMap:flowList){
                String projectId = Convert.toStr(dataMap.get("projectId"));
                String projectName = Convert.toStr(dataMap.get("projectName"));
                String witnessUser = Convert.toStr(dataMap.get("witnessUser"));
                String total = Convert.toStr(dataMap.get("total"));
                //模板数据
                WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                        .toUser(this.getMsgId(witnessUser))
                        .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_checkDetection/list/index?barProId="+projectId))
                        .templateId(TemplateMessageEnum.APPLY_EXPIRED_MY.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", projectName));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string8", total));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("const9", "材料取样复试审批"));
                list.add(templateMessage);
            }
            this.send(list,"EXPIRED_"+ MessageTypeEnum.QYFSSP.getCode());
        } catch (Exception e) {
            log.info("任务执行异常...{}...::::结束执行...{}", e.getMessage());
            throw e;
        }
        /**finally {
         log.info("释放锁...{}", key);
         redisLock.unlock(key);
         }
         }else{
         log.info("尝试劫持锁失败...{}", key);
         }*/
    }

    /**
     * 从Flowable中查询超时数据进行消息提醒
     * 分布式锁::quartz.task.flowTaskExpiredTask.notifyExpiredData
     * 由程序定时调用 JiangYuQi
     * @param
     * @return
     */
    public void notifyClfyExpiredData() {
        /**String key = "quartz.task.flowTaskExpiredTask.notifyExpiredData";
         boolean lock = redisLock.tryLock(key, Constants.REDIS_LOCK, TimeUnit.SECONDS);
         if (lock) {*/
        try {
            log.info("劫持锁...{}...开始执行::材料封样超时提醒定时任务...{}");
            List<WxMpTemplateMessage> list = new ArrayList<>();
            List<Map<String, Object>> flowList = taskService.findDaysAwaitClfyList();
            for(Map<String, Object> dataMap:flowList){
                String projectId = Convert.toStr(dataMap.get("projectId"));
                String projectName = Convert.toStr(dataMap.get("projectName"));
                String witnessUser = Convert.toStr(dataMap.get("witnessUser"));
                String total = Convert.toStr(dataMap.get("total"));
                //模板数据
                WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                        .toUser(this.getMsgId(witnessUser))
                        .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_materialSeal/list/index?barProId="+projectId))
                        .templateId(TemplateMessageEnum.APPLY_EXPIRED_MY.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", projectName));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string8", total));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("const9", "材料封样审批"));
                list.add(templateMessage);
            }
            this.send(list,"EXPIRED_"+ MessageTypeEnum.CLFYSP.getCode());
        } catch (Exception e) {
            log.info("任务执行异常...{}...::::结束执行...{}", e.getMessage());
            throw e;
        }
        /**finally {
         log.info("释放锁...{}", key);
         redisLock.unlock(key);
         }
         }else{
         log.info("尝试劫持锁失败...{}", key);
         }*/
    }

    /**
     * 从Flowable中查询超时数据进行消息提醒
     * 分布式锁::quartz.task.flowTaskExpiredTask.notifyExpiredData
     * 由程序定时调用 JiangYuQi
     * @param
     * @return
     */
    public void notifyYhzgExpiredData() {
        /**String key = "quartz.task.flowTaskExpiredTask.notifyExpiredData";
         boolean lock = redisLock.tryLock(key, Constants.REDIS_LOCK, TimeUnit.SECONDS);
         if (lock) {*/
        try {
            log.info("劫持锁...{}...开始执行::隐患整改超时提醒定时任务...{}");
            List<WxMpTemplateMessage> list = new ArrayList<>();
            List<Map<String, Object>> flowList = taskService.findDaysAwaitYhzgList();
            for(Map<String, Object> dataMap:flowList){
                String projectId = Convert.toStr(dataMap.get("projectId"));
                String projectName = Convert.toStr(dataMap.get("projectName"));
                String lordsentuser = Convert.toStr(dataMap.get("lordsentuser"));
                String minNickTime = Convert.toStr(dataMap.get("minNickTime"));
                Integer infotype = Convert.toInt(dataMap.get("infotype"));
                String handlePath = infotype==0?"security":"quality";
                String infoTypeName = infotype==0?"安全隐患":"质量隐患";
                String total = Convert.toStr(dataMap.get("total"));
                //模板数据
                WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                        .toUser(this.getMsgId(lordsentuser))
                        .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+projectId))
                        .templateId(TemplateMessageEnum.ROUBLE_EXPIRED_ZG.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", projectName));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string2", total));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", infoTypeName));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("const9", minNickTime));
                list.add(templateMessage);
            }
            this.send(list,"EXPIRED_"+ MessageTypeEnum.YHZGCSGZ.getCode()+"_"+System.currentTimeMillis());
        } catch (Exception e) {
            log.info("任务执行异常...{}...::::结束执行...{}", e.getMessage());
            throw e;
        }
        /**finally {
         log.info("释放锁...{}", key);
         redisLock.unlock(key);
         }
         }else{
         log.info("尝试劫持锁失败...{}", key);
         }*/
    }

    /**
     * 从Flowable中查询超时数据进行消息提醒
     * 分布式锁::quartz.task.flowTaskExpiredTask.notifyExpiredData
     * 由程序定时调用 JiangYuQi
     * @param
     * @return
     */
    public void notifyYhfjExpiredData() {
        /**String key = "quartz.task.flowTaskExpiredTask.notifyExpiredData";
         boolean lock = redisLock.tryLock(key, Constants.REDIS_LOCK, TimeUnit.SECONDS);
         if (lock) {*/
        try {
            log.info("劫持锁...{}...开始执行::隐患复检超时提醒定时任务...{}");
            List<WxMpTemplateMessage> list = new ArrayList<>();
            List<Map<String, Object>> flowList = taskService.findDaysAwaitYhzgList();
            for(Map<String, Object> dataMap:flowList){
                String projectId = Convert.toStr(dataMap.get("projectId"));
                String projectName = Convert.toStr(dataMap.get("projectName"));
                String rechecksenduser = Convert.toStr(dataMap.get("rechecksenduser"));
                String minNickTime = Convert.toStr(dataMap.get("minNickTime"));
                Integer infotype = Convert.toInt(dataMap.get("infotype"));
                String handlePath = infotype==0?"security":"quality";
                String infoTypeName = infotype==0?"安全隐患":"质量隐患";
                String total = Convert.toStr(dataMap.get("total"));
                //模板数据
                WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                        .toUser(this.getMsgId(rechecksenduser))
                        .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+projectId))
                        .templateId(TemplateMessageEnum.ROUBLE_EXPIRED_FJ.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", projectName));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string2", total));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", infoTypeName));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("const9", minNickTime));
                list.add(templateMessage);
            }
            this.send(list,"EXPIRED_"+ MessageTypeEnum.YHFJCSGZ.getCode()+"_"+System.currentTimeMillis());
        } catch (Exception e) {
            log.info("任务执行异常...{}...::::结束执行...{}", e.getMessage());
            throw e;
        }
        /**finally {
         log.info("释放锁...{}", key);
         redisLock.unlock(key);
         }
         }else{
         log.info("尝试劫持锁失败...{}", key);
         }*/
    }

    /**
     * 查询微信用户列表
     * @param userName
     * @return
     */
    private String getMsgId(String userName){
        String openIds = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_OPENID +userName));
        if(StringUtils.isNotEmpty(openIds)){
            return openIds;
        }else{
            List<Map<String, Object>> list = taskService.findSysUserOpenidsByUser(userName);
            if(StringUtils.isNotEmpty(list)){
                List<Map<String, Object>> ids = list.stream().filter(m -> StringUtils.isNotEmpty(m.get("msgOpenId"))).collect(Collectors.toList());
                if(StringUtils.isNotEmpty(ids)){
                    List<String> strs = ids.stream().map(Map -> Map.get("msgOpenId").toString()).collect(Collectors.toList());
                    openIds = String.join(",",strs);
                }
            }
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_OPENID +userName,openIds,30, TimeUnit.MINUTES);
            return openIds;
        }
    }

    /**
     * 模板消息开关
     */
    private boolean wxSwitch = false;

    /**
     * 推送模板消息
     * @param lsit
     */
    private void send(List<WxMpTemplateMessage> lsit, String messageType){
        try {
            wxSwitch =  Convert.toBool(configService.selectConfigByKey("sys.wx.message"),false);
            if(wxSwitch && StringUtils.isNotEmpty(lsit)){
                for(WxMpTemplateMessage message:lsit){
                    if(StringUtils.isNotEmpty(message.getToUser())){
                        String[] toUsers = message.getToUser().split(",");
                        for(String toUser:toUsers){
                            //判断短时间内是否已发送相同类型的消息
                            String key = CacheConstants.WX_MPMESSAGE_KEY +toUser+"-"+messageType;
                            if(Convert.toBool(redisCache.getCacheObject(key),true)){
                                //多个登录账号时批量发送
                                message.setToUser(toUser);
                                wxMpService.getTemplateMsgService().sendTemplateMsg(message);
                                //5分钟内不推送相同类型的消息
                                redisCache.setCacheObject(key,false,5, TimeUnit.MINUTES);
                            }
                        }
                    }
                }
            }
        }catch (Exception e){
            log.info("出错了...{}",e.getMessage());
            try {
                JSONObject jsonObject = JSONObject.parseObject(e.getMessage());
                if(Objects.equals(jsonObject.getString("errcode"),"40164")){
                    String ip = jsonObject.getString("errmsg").split("ipv6")[0].split(" ")[2];
                    WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                            .toUser("oM5rN6Wb8UyBLuTAFNGjnZCeQs1U")
                            .templateId(TemplateMessageEnum.SERVER_ERROR.getId())
                            .build();
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string7", "IP>"+ip));
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("time6", DateUtils.dateTimeNow()));
                    wxMpService.getTemplateMsgService().sendTemplateMsg(templateMessage);
                }
            }catch (Exception ex){
                ex.printStackTrace();
            }
        }
    }

}
