package com.ruoyi.quartz.task;

import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.quartz.domain.*;
import com.ruoyi.quartz.service.*;
import okhttp3.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.*;

@Component("pitmonitSouthsmosTask")

public class PitmonitSouthsmosTask {
    @Autowired
    private ISurProjectPitMonitCfgService cfgService;
    @Autowired
    private IDevPitmonitSouthsmosAlarmService alarmService;
    @Autowired
    private IDevPitmonitSouthsmosDataService dataService;
    @Autowired
    private IDevPitmonitSouthsmosElementService elementService;
    @Autowired
    private IDevPitmonitSouthsmosSurveypointService surveypointService;
    @Autowired
    private IDevPitmonitSouthsmosThresholdService thresholdService;
    @Autowired
    private IDevPitmonitSouthsmosDeviceService deviceService;
    static String APIBASEURL="https://www.southsmos.com/api/";

    /**
     * 同步基本信息
     * 4.获取监测项列表
     * 5.获取测点列表
     * 7.获取报警阈值
     * 9.获取设备
     */
    public  void syncBaseInfo() {
        SurProjectPitMonitCfg cfgWhere=new SurProjectPitMonitCfg();
        cfgWhere.setEnabled(1l);
        cfgWhere.setIsDel(0l);
        List<SurProjectPitMonitCfg> cfgList= cfgService.selectSurProjectPitMonitCfgList(cfgWhere);
        cfgList.forEach(cfg->{
            JSONObject jo=JSON.parseObject(cfg.getVendorParamter());
            String identifier=jo.getString("identifier");
            String credential=jo.getString("credential");
            String orgId=jo.getString("orgId");
            String token=getToken(identifier,credential);
            //4.获取监测项列表
            List<DevPitmonitSouthsmosElement> elList=getMonitorElement(token,orgId);
            elementService.addList(elList,cfg);
            //5.获取测点列表
            List<DevPitmonitSouthsmosSurveypoint> ptList=getSurveyPoint(token,orgId);
            surveypointService.addList(ptList,cfg);
            //7.获取报警阈值
            DevPitmonitSouthsmosSurveypoint ptWhere=new DevPitmonitSouthsmosSurveypoint();
            ptWhere.setCfgId(cfg.getId());
            ptWhere.setIsDel(0l);
            ptList=surveypointService.selectDevPitmonitSouthsmosSurveypointList(ptWhere);
            ptList.forEach(d->{
                List<DevPitmonitSouthsmosThreshold> thList=getThreshold(""+d.getSpId(),token);
                thresholdService.addList(thList,cfg);
            });
            //9.获取设备
            List<DevPitmonitSouthsmosDevice> devList=getDevices(token,orgId);
            deviceService.addList(devList,cfg);
        });
    }

    /**
     * 获取当天数据
     * 6.获取测点数据
     * 8.获取报警信息
     */
    public void syncTodayData(){
        doGetData(new Date());
    }



    /**
     * 同步最近7天数据
     * 6.获取测点数据
     * 8.获取报警信息
     */
    public void sync7DayData(){
        long endTime=DateUtil.current();
        Date dt = DateUtil.date(endTime - 3600l * 1000 * 24 * 7);
        doGetData(dt);
    }
    /**
     * 同步从2023-01-01开始的所有数据
     * 6.获取测点数据
     * 8.获取报警信息
     */
    public void syncAllData(){
        doGetData(DateUtil.parse("2023-01-01"));
    }
    /**
     * 同步数据
     * 6.获取测点数据
     * 8.获取报警信息
     */
    private void doGetData(Date date) {
        SurProjectPitMonitCfg cfgWhere=new SurProjectPitMonitCfg();
        cfgWhere.setEnabled(1l);
        cfgWhere.setIsDel(0l);
        List<SurProjectPitMonitCfg> cfgList= cfgService.selectSurProjectPitMonitCfgList(cfgWhere);
        cfgList.forEach(cfg->{
            JSONObject jo=JSON.parseObject(cfg.getVendorParamter());
            String identifier=jo.getString("identifier");
            String credential=jo.getString("credential");
            String orgId=jo.getString("orgId");
            String token=getToken(identifier,credential);
            //6.获取测点数据
            DevPitmonitSouthsmosElement elWhere=new DevPitmonitSouthsmosElement();
            elWhere.setCfgId(cfg.getId());
            elWhere.setIsDel(0l);
            List<DevPitmonitSouthsmosElement> elList=elementService.selectDevPitmonitSouthsmosElementList(elWhere);
            elList.forEach(el->{
                List<DevPitmonitSouthsmosData> dataList=getElementData(orgId,""+el.getSrvId(),el.getNameEn(),token,date,1);
                dataService.addList(dataList,cfg,el);
            });
            //8.获取报警信息
            List<DevPitmonitSouthsmosAlarm> alarmList=getAlarm(orgId,token,date);
            alarmService.addList(alarmList,cfg);
        });

    }
    /**
     * 1.登录
     * @param identifier
     * @param credential
     * @return
     */
    private static String getToken(String identifier,String credential){
        String url="auth/tologin";
        Map<String, Object> params = new HashMap<>();
        params.put("identifier",identifier);
        params.put("credential",credential);
        params.put("type", "password");
        Request request = new Request.Builder()
                .url(APIBASEURL+url)
                .post(toJsonBody(params))
                .build();
        String data=AttendanceTask.getResult(request);
        JSONObject jo=JSON.parseObject(data);
        data=jo.getJSONObject("data").getString("token");
        return data;
    }

    private static RequestBody toJsonBody(Map<String, Object> params) {
        return RequestBody.create(MediaType.parse("application/json"), JSON.toJSONString(params));
    }

    public static void main(String[] args){
        String identifier="JHXC";
        String credential="Admin123456!";
        String orgId="1687";
        String token=getToken(identifier,credential);
        //4.获取监测项列表
        //List<DevPitmonitSouthsmosElement> list=getMonitorElement(token,orgId);
        //System.out.println(list);
        //5.获取测点列表
        //List<DevPitmonitSouthsmosSurveypoint> spList=getSurveyPoint(token,orgId);
        //System.out.println(spList);
        //6.获取测点数据
        List<DevPitmonitSouthsmosData> dataList=getElementData(orgId,"22","horizontal",token,DateUtil.parse("2024-01-01"),1);
        System.out.println(dataList);
        System.out.println(dataList.size());
        //7.获取报警阈值
        //List<DevPitmonitSouthsmosThreshold> thList=getThreshold("53245",token);
        //System.out.println(thList);
        //8.获取报警信息
        //List<DevPitmonitSouthsmosAlarm> alarmList=getAlarm(orgId,token,DateUtil.parse("2024-01-01"));
        //System.out.println(alarmList);
        //9.获取设备
        //List<DevPitmonitSouthsmosDevice> devList=getDevices(token,orgId);
        //System.out.println(devList);
    }

    private  static List<DevPitmonitSouthsmosDevice> getDevices(String token,String orgId){
        String url="instrument/device";
        Map<String, Object> params = new HashMap<>();
        params.put("structureId",orgId);
        String data=getJSON(APIBASEURL+url,token,params);
        JSONObject jo=JSON.parseObject(data);
        List<DevPitmonitSouthsmosDevice> list=jo.getList("data",DevPitmonitSouthsmosDevice.class);
        return  list;
    }
    /**
     * 4.获取监测项列表
     * @param token
     * @param orgId
     * @return
     */
    private   static List<DevPitmonitSouthsmosElement> getMonitorElement(String token,String orgId){
        String url="service/structure/"+orgId+"/monitorElement";
        Map<String, Object> params = new HashMap<>();
        params.put("isPaged","false");
        String data=getJSON(APIBASEURL+url,token,params);
        JSONArray jo=JSON.parseObject(data).getJSONArray("data");
        List<DevPitmonitSouthsmosElement> list=jo.toList(DevPitmonitSouthsmosElement.class);
        list.forEach(it->{
            it.setSrvId(it.getId());
            it.setId(null);
            it.getItems().forEach(item->{
                item.setSrvId(item.getId());
                item.setId(null);
            });
        });
        return  list;
    }

    /**
     * 5.获取测点列表
     * @param token
     * @param orgId
     * @return
     */
    private static  List<DevPitmonitSouthsmosSurveypoint> getSurveyPoint(String token,String orgId){
        String url="service/structure/"+orgId+"/surveyPoint";
        Map<String, Object> params = new HashMap<>();
        params.put("isPaged","false");
        String data=getJSON(APIBASEURL+url,token,params);
        JSONArray jo=JSON.parseObject(data).getJSONArray("data");
        List<DevPitmonitSouthsmosSurveypoint> list=jo.toList(DevPitmonitSouthsmosSurveypoint.class);
        return  list;
    }

    /**
     * 6.获取测点数据
     * @param orgId
     * @param spId
     * @param type
     * @param token
     * @param dt
     * @param pageIndex
     * @return
     */
    private   static  List<DevPitmonitSouthsmosData> getElementData(String orgId,String spId,String type, String token,Date dt,int pageIndex){
        String url="service/structure/"+orgId+"/element/"+spId+"/Data";
        Map<String, Object> params = new HashMap<>();
        params.put("isPaged","true");
        params.put("type",type);
        params.put("beginTime", DateUtil.format(dt, "YYYY-MM-dd 00:00:00"));
        params.put("size",""+100);
        params.put("page",""+pageIndex);
        String data=getJSON(APIBASEURL+url,token,params);
        JSONObject jo=JSON.parseObject(data).getJSONObject("data");
        List<DevPitmonitSouthsmosData> list=jo.getList("list",DevPitmonitSouthsmosData.class);
        JSONArray jarr=jo.getJSONArray("list");
        for (int i = 0; i < jarr.size(); i++) {
            if(type.equals("horizontal")) {
                list.get(i).convertToHorizontal(jarr.getJSONObject(i));//水平位移(x,y)
            }else if(type.equals("presureWallsideSoil")){ //围护墙侧向土压力
                list.get(i).convertToPresureWallsideSoil(jarr.getJSONObject(i));
            }else if(type.equals("waterLevel")){ //地下水位
                list.get(i).convertToWaterLevel(jarr.getJSONObject(i));
            }
        }
        if(jarr.size()>0){
          List<DevPitmonitSouthsmosData>  tmps= getElementData(orgId,spId,type,token,dt,pageIndex+1);
          list.addAll(tmps);
        }
        return  list;
    }

    /**
     * 7.获取报警阈值
     * @param spId
     * @param token
     * @return
     */
    private static  List<DevPitmonitSouthsmosThreshold> getThreshold(String spId,String token){
        String url="service/threshold";
        Map<String, Object> params = new HashMap<>();
        params.put("isPaged","false");
        params.put("spId",spId);
        String data=getJSON(APIBASEURL+url,token,params);
        JSONObject jo=JSON.parseObject(data);
        List<DevPitmonitSouthsmosThreshold> list=jo.getList("data",DevPitmonitSouthsmosThreshold.class);
        list.forEach(d->{
            d.setSrvId(d.getId());
            d.setId(null);
        });
        return list;
    }

    /**
     * 8.获取报警信息
     * @param orgId
     * @param token
     * @param dt
     * @return
     */
    private static  List<DevPitmonitSouthsmosAlarm> getAlarm(String orgId,String token,Date dt){
        String url="service/alarm/all";
        Map<String, Object> params = new HashMap<>();
        params.put("structureId",orgId);
        params.put("beginTime", DateUtil.format(dt, "YYYY-MM-dd 00:00:00"));
        params.put("status","false");
        String data=getJSON(APIBASEURL+url,token,params);
        JSONObject jo=JSON.parseObject(data);
        List<DevPitmonitSouthsmosAlarm> list=jo.getList("data", DevPitmonitSouthsmosAlarm.class);
        list.forEach(d->{
            d.setSrvId(d.getId());
            d.setId(null);
        });
        params.remove("status");
        params.put("status","true");
        data=getJSON(APIBASEURL+url,token,params);
        jo=JSON.parseObject(data);
        List<DevPitmonitSouthsmosAlarm> list2=jo.getList("data", DevPitmonitSouthsmosAlarm.class);
        list2.forEach(d->{
            d.setSrvId(d.getId());
            d.setId(null);
        });
        list.addAll(list2);
        return  list;
    }

    private static String getJSON(String url, String token, Map<String, Object> params) {
        HttpUrl.Builder urlBuilder = Objects.requireNonNull(HttpUrl.parse(url)).newBuilder();
        params.forEach((s, o) -> {
            urlBuilder.addQueryParameter(s, (String) o);
        });
        Request request = new Request.Builder()
                .header("token",token)
                .url(urlBuilder.build())
                .build();
        return  AttendanceTask.getResult(request);
    }

    private static RequestBody toFormBody(Map<String, Object> params ){
        FormBody.Builder builder=new FormBody.Builder();
        for(String key :params.keySet()){
            builder.add(key,params.get(key).toString());
        }
        return builder.build();
    }
}
