package com.ruoyi.web.flowable.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.flow.domain.FlowLabourAuditNode;
import com.yanzhu.jh.flow.domain.FlowLabourInfo;
import com.yanzhu.jh.flow.service.IFlowLabourAuditNodeService;
import com.yanzhu.jh.flow.service.IFlowLabourInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @version : V1.0
 * @ClassName: WcFlowLabourController
 * @Description: 劳资投诉
 * @Auther: JiangYuQi
 * @Date: 2024/04/20 18:03
 */
@RestController
@RequestMapping("/wechat/flow/flowLabour")
public class WcFlowLabourController extends BaseController {

    @Autowired
    private IFlowLabourInfoService flowLabourInfoService;

    @Autowired
    private IFlowLabourAuditNodeService flowLabourAuditNodeService;

    /**
     * 查询劳资投诉列表
     */
    @GetMapping("/list")
    public TableDataInfo list(FlowLabourInfo flowLabourInfo)
    {
        if(flowLabourInfo.getDeptId()==0){
            flowLabourInfo.setDeptId(null);
        }
        //启用分页
        List<FlowLabourInfo> list = flowLabourInfoService.selectFlowLabourInfoListV2(flowLabourInfo);
        return getDataTable(list);
    }

    /**
     * 统计劳资投诉信息
     */
    @GetMapping("/findGroupCountByApprove")
    public AjaxResult findGroupCountByApprove(FlowLabourInfo flowLabourInfo)
    {
        if(flowLabourInfo.getDeptId()==0){
            flowLabourInfo.setDeptId(null);
        }
        //启用分页
        return success(flowLabourInfoService.findGroupCountByApprove(flowLabourInfo));
    }

    /**
     * 查询劳资投诉进度
     */
    @GetMapping("/findMyFlowLabourNodes/{flowId}")
    public AjaxResult findMyFlowLabours(@PathVariable("flowId") Long flowId)
    {
        FlowLabourAuditNode flowLabourAuditNode = new FlowLabourAuditNode();
        flowLabourAuditNode.setFlowId(flowId);
        List<FlowLabourAuditNode> list = flowLabourAuditNodeService.selectFlowLabourAuditNodeList(flowLabourAuditNode);
        return success(list);
    }

    /**
     * 劳资投诉提交审批
     */
    @Log(title = "劳资投诉审批", businessType = BusinessType.UPDATE)
    @PostMapping("/submitFlowLabour")
    public AjaxResult submitFlowLabour(@RequestBody FlowLabourAuditNode flowLabourAuditNode)
    {
        return toAjax(flowLabourAuditNodeService.updateFlowLabourAuditNode(flowLabourAuditNode));
    }

    /**
     * 获取劳资投诉详细信息
     */
    @GetMapping(value = "/info/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(flowLabourInfoService.selectFlowLabourInfoById(id));
    }
}
