package com.ruoyi.web.project.controller;

import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.yanzhu.jh.project.domain.SurProjectAttendanceData;
import com.yanzhu.jh.project.domain.SurProjectAttendanceUser;
import com.yanzhu.jh.project.service.ISurProjectAttendanceDataService;
import com.yanzhu.jh.project.service.ISurProjectAttendanceUserService;
import com.yanzhu.jh.project.service.ISurProjectDeptWroksService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;
import java.util.concurrent.TimeUnit;

/**
 * @version : V1.0
 * @ClassName: ProjectDeptWroksController
 * @Description: 在岗人员
 * @Auther: JiangYuQi
 * @Date: 2020/7/7 18:03
 */
@RestController
@RequestMapping("/wechat/attendance")
public class ProjectAttendanceController extends BaseController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private ISurProjectDeptWroksService surProjectDeptWroksService;

    @Autowired
    private ISurProjectAttendanceDataService attendanceDataService;

    @Autowired
    private ISurProjectAttendanceUserService attendanceUserService;

    /**
     * 根据项目分组查询统计
     * @param projectId
     * @return
     */
    @GetMapping("/findSumByProjectId")
    public AjaxResult findSumByProjectId(Long projectId){
        return success(surProjectDeptWroksService.findSumByProjectId(projectId));
    }

    /**
     * 统计劳务人员信息
     * @param where
     * @return
     */
    @PostMapping("/v1/groupAllByParams")
    public AjaxResult groupAllByParams(@RequestBody SurProjectAttendanceData where){
        String key="WECHAT_ATTENDANCE-groupAllByParams-"+where.getProjectId();
        Object obj = redisCache.getCacheObject(key);
        if(obj!=null){
            return AjaxResult.success(obj);
        }
        List<Map<String, Object>> list = attendanceDataService.groupAllByParams(where);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE*2, TimeUnit.MINUTES);
        return AjaxResult.success(list);
    }

    /**
     * 统计劳务人员信息
     * @param where
     * @return
     */
    @PostMapping("/v1/findGroupAllByDays")
    public AjaxResult findGroupAllByDays(@RequestBody SurProjectAttendanceData where){
        String key="WECHAT_ATTENDANCE-findGroupAllByDays-"+where.getProjectId();
        Object obj = redisCache.getCacheObject(key);
        if(obj!=null){
            return AjaxResult.success(obj);
        }
        List<Map<String, Object>> users = attendanceUserService.findUserAllByDays(where.getProjectId());
        Calendar calendar = Calendar.getInstance();
        calendar.add(Calendar.DAY_OF_MONTH, -1);
        where.setAttendanceOutTime(DateUtil.format(calendar.getTime(),DateUtils.YYYY_MM_DD));
        calendar.add(Calendar.DAY_OF_MONTH, -6);
        where.setAttendanceTime(DateUtil.format(calendar.getTime(),DateUtils.YYYY_MM_DD));
        List<Map<String, Object>> list = attendanceDataService.findGroupAllByDays(where);
        Map<String, Object> data = new HashMap<>();
        data.put("list",list);
        data.put("user",users.stream().mapToInt((u) -> Integer.valueOf(String.valueOf(u.get("total")))).sum());
        redisCache.setCacheObject(key, data, Constants.BIGSCREEN_QUERY_CACHE*2, TimeUnit.MINUTES);
        return AjaxResult.success(data);
    }

    /**
     * 统计劳务人员信息
     * @param where
     * @return
     */
    @PostMapping("/v1/groupUserByParams")
    public AjaxResult groupUserByParams(@RequestBody SurProjectAttendanceUser where){
        String key="WECHAT_ATTENDANCE-groupDataByParams-"+where.getProjectId()+"-"+where.getName();
        Object obj = redisCache.getCacheObject(key);
        if(obj!=null){
            return AjaxResult.success(obj);
        }
        List<Map<String, Object>> list = attendanceUserService.groupUserByParams(where);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE*2, TimeUnit.MINUTES);
        return AjaxResult.success(list);
    }

    /**
     * 劳务人员详情
     * @param id
     * @return
     */
    @GetMapping("/v1/attendanceUser/{id}")
    public AjaxResult attendanceUserList(@PathVariable("id") Long id){
        SurProjectAttendanceUser where = new SurProjectAttendanceUser();
        where.setId(id);
        List<SurProjectAttendanceUser> list=attendanceUserService.attendanceUserList(where);
        if(StringUtils.isNotEmpty(list)){
            return success(list.get(0));
        }else{
            return error();
        }
    }

    /**
     * 劳务人员列表
     * @param where
     * @return
     */
    @GetMapping("/v1/attendanceUserList")
    public TableDataInfo attendanceUserList(SurProjectAttendanceUser where){
        startPage();
        List<SurProjectAttendanceUser> list=attendanceUserService.attendanceUserList(where);
        return getDataTable(list);
    }

    /**
     * 统计劳务人员信息
     * @param where
     * @return
     */
    @PostMapping("/v1/groupDataByParams")
    public AjaxResult groupDataByParams(@RequestBody SurProjectAttendanceData where){
        if(StringUtils.isEmpty(where.getWorkerId()) && StringUtils.isEmpty(where.getWorkerName()) && StringUtils.isEmpty(where.getAttendanceTime())){
            where.setAttendanceTime(DateUtil.formatDate(DateTime.now()));
        }
        String key="WECHAT_ATTENDANCE-groupDataByParams-"+where.getProjectId()+"-"+where.getWorkerName()+"-"+where.getAttendanceTime();
        Object obj = redisCache.getCacheObject(key);
        if(obj!=null){
            return AjaxResult.success(obj);
        }
        List<Map<String, Object>> list = attendanceDataService.groupDataByParams(where);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE*2, TimeUnit.MINUTES);
        return AjaxResult.success(list);
    }

    /**
     * 出勤数据列表
     */
    @GetMapping("/v1/attendanceDataList")
    public TableDataInfo attendanceDataList(SurProjectAttendanceData where){
        startPage();
        if(StringUtils.isEmpty(where.getWorkerId()) && StringUtils.isEmpty(where.getWorkerName()) && StringUtils.isEmpty(where.getAttendanceTime())){
            where.setAttendanceTime(DateUtil.formatDate(DateTime.now()));
        }
        List<SurProjectAttendanceData> list = attendanceDataService.attendanceDataList(where);
        return getDataTable(list);
    }
}
