package com.ruoyi.web.project.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.project.domain.SurProjectFunVerify;
import com.yanzhu.jh.project.service.ISurProjectFunVerifyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @version : V1.0
 * @ClassName: WxProjectFunVerifyController
 * @Description: 工程功能检验管理
 * @Auther: JiangYuQi
 * @Date: 2024/07/07 18:03
 */
@RestController
@RequestMapping("/wechat/projectFunVerify")
public class WxProjectFunVerifyController extends BaseController {

    @Autowired
    private ISurProjectFunVerifyService surProjectFunVerifyService;

    /**
     * 查询当前用户工程功能检验项目列表
     * @param surProjectFunVerify
     * @return
     */
    @GetMapping("/list")
    public TableDataInfo list(SurProjectFunVerify surProjectFunVerify){
        if(surProjectFunVerify.getDeptId()==0){
            surProjectFunVerify.setDeptId(null);
        }
        //启用分页
        startPage();
        List<SurProjectFunVerify> list = surProjectFunVerifyService.selectSurProjectFunVerifyList(surProjectFunVerify);
        return getDataTable(list);
    }

    /**
     *  统计工程功能检验
     * @param surProjectFunVerify
     * @return
     */
    @GetMapping("/findGroupCountByApprove")
    public AjaxResult findGroupCountByApprove(SurProjectFunVerify surProjectFunVerify){
        if(surProjectFunVerify.getDeptId()==0){
            surProjectFunVerify.setDeptId(null);
        }
        return success(surProjectFunVerifyService.findGroupCountByApprove(surProjectFunVerify));
    }

    /**
     * 查询工程功能检验详情
     * @param id
     * @return
     */
    @GetMapping("/info/{id}")
    public AjaxResult info(@PathVariable("id") Long id){
        return success(surProjectFunVerifyService.selectSurProjectFunVerifyById(id));
    }

    /**
     * 新增工程功能检验
     * @param surProjectFunVerify
     * @return
     */
    @PostMapping("/add")
    @Log(title = "工程功能检验", businessType = BusinessType.INSERT)
    public AjaxResult add(@RequestBody SurProjectFunVerify surProjectFunVerify){
        return success(surProjectFunVerifyService.insertSurProjectFunVerify(surProjectFunVerify));
    }

    /**
     * 修改工程功能检验
     * @param surProjectFunVerify
     * @return
     */
    @PostMapping("/edit")
    @Log(title = "工程功能检验", businessType = BusinessType.UPDATE)
    public AjaxResult edit(@RequestBody SurProjectFunVerify surProjectFunVerify){
        return success(surProjectFunVerifyService.updateSurProjectFunVerify(surProjectFunVerify));
    }

    /**
     * 修改工程功能检验
     * @param surProjectFunVerify
     * @return
     */
    @PostMapping("/editNoLog")
    @Log(title = "工程功能检验", businessType = BusinessType.UPDATE)
    public AjaxResult editNoLog(@RequestBody SurProjectFunVerify surProjectFunVerify){
        return success(surProjectFunVerifyService.updateSurProjectFunVerifyNoLog(surProjectFunVerify));
    }

    /**
     * 删除工程功能检验
     */
    @Log(title = "工程功能检验", businessType = BusinessType.DELETE)
    @GetMapping("/remove/{id}")
    public AjaxResult remove(@PathVariable("id") Long id)
    {
        return toAjax(surProjectFunVerifyService.deleteSurProjectFunVerifyById(id));
    }

}
