package com.ruoyi.web.userLogin.controller;

import cn.hutool.core.util.RandomUtil;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.domain.model.LoginBody;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.SmsUtils;
import com.ruoyi.framework.web.service.SysLoginService;
import com.ruoyi.framework.web.service.TokenService;
import com.ruoyi.system.domain.SysUserOpenid;
import com.ruoyi.system.domain.vo.AlertUserPassVo;
import com.ruoyi.system.service.ISysUserOpenidService;
import com.ruoyi.system.service.ISysUserService;
import com.ruoyi.web.userLogin.service.IWechatUserLoginService;
import liquibase.pro.packaged.S;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.validation.Valid;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @version : V1.0
 * @ClassName: LoginController
 * @Description: 用户登录
 * @Auther: JiangYuQi
 * @Date: 2020/7/7 18:03
 */
@RestController
@RequestMapping("/wechat")
public class WechatUserLoginController extends BaseController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private SysLoginService loginService;

    @Autowired
    private TokenService tokenService;

    @Autowired
    private ISysUserService sysUserService;

    @Autowired
    private IWechatUserLoginService wechatUserLoginService;

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public AjaxResult login(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        // 生成令牌
        String token = loginService.wxLogin(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
                loginBody.getUuid(),loginBody.getOpenId());
        ajax.put(Constants.TOKEN, token);
        // 移动端这里刷新token有效期为长期
        tokenService.refreshMobileToken(token);
        // 查询当前用户的微信公众号msgOpenId
        ajax.put("data",wechatUserLoginService.findUserInfo(loginBody.getUsername(),loginBody.getOpenId()));
        return ajax;
    }

    /**
     * 登录方法
     *
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/openIdLogin")
    public AjaxResult openIdLogin(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        Map<String,Object> data = null;
        //设置缓存
        String key="wechat_openIdLogin-"+loginBody.getOpenId();
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            ajax.put("data",obj);
            return ajax;
        }
        data = wechatUserLoginService.getLoginUserByOpenId(loginBody.getOpenId());
        String token = loginService.wxLogin(Convert.toStr(data.get("userName")),loginBody.getOpenId());
        // 移动端这里刷新token有效期为长期
        tokenService.refreshMobileToken(token);
        ajax.put(Constants.TOKEN, token);
        redisCache.setCacheObject(key, data, Constants.CAPTCHA_EXPIRATION*15, TimeUnit.MINUTES);
        if(data!=null){
            ajax.put("data",data);
            return ajax;
        }else {
            return error();
        }
    }

    /**
     * 查询出openid
     * @param code
     * @param appId
     * @return
     */
    @GetMapping("/getOpenId")
    public AjaxResult getOpenId(String code,String appId){
        Map<String,Object> data = wechatUserLoginService.getOpenId(code,appId);
        return success(data);
    }

    /**
     * 根据用户查询菜单信息
     * @param map
     * @return
     */
    @GetMapping("/selectRoleMenuList")
    public AjaxResult selectRoleMenuList(@RequestParam Map<String,Object> map){
        //设置缓存
        String key="wechat_selectRoleMenuList-"+map.get("username")+map.get("type");
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return success(obj);
        }
        List<Map<String,Object>> list = wechatUserLoginService.selectRoleMenuList(map);
        redisCache.setCacheObject(key, list, Constants.CAPTCHA_EXPIRATION, TimeUnit.MINUTES);
        return success(list);
    }

    /**
     *  查询登录用户的组织架构
     * @param map
     * @return
     */
    @RequestMapping("/selectDeptAll")
    public AjaxResult selectDeptAll(@RequestParam Map<String,Object> map){
        Map<String,Object> data = null;
        //设置缓存
        String key="wechat_selectDeptAll-deptId_"+map.get("deptId")+"-userId_"+map.get("userId")+"-minRoleId_"+map.get("minRoleId");
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            data = (Map<String,Object>) obj;
            return success(data);
        }
        data = wechatUserLoginService.getDeptAll(map);
        redisCache.setCacheObject(key, data, Constants.CAPTCHA_EXPIRATION, TimeUnit.MINUTES);
        return success(data);
    }

    @Autowired
    private ISysUserOpenidService sysUserOpenidService;

    /**
     * 查询公众号消息授权
     * @param openId
     * @return
     */
    @GetMapping("/findOpenUserMsgId/{openId}")
    public AjaxResult findOpenUserMsgId(@PathVariable("openId") String openId){
        return success(sysUserOpenidService.selectSysUserOpenidByOpenId(openId));
    }

    /**
     * 删除公众号消息授权
     * @param openId
     * @return
     */
    @GetMapping("/delOpenUserMsgId/{openId}")
    public AjaxResult delOpenUserMsgId(@PathVariable("openId") String openId){
        SysUserOpenid sysUserOpenid = sysUserOpenidService.selectSysUserOpenidByOpenId(openId);
        sysUserOpenid.setUnionid(sysUserOpenid.getMsgOpenId());
        sysUserOpenid.setMsgOpenId(null);
        return success(sysUserOpenidService.updateSysUserOpenid(sysUserOpenid));
    }

    /**
     * 发送短信验证码修改密码
     * @param data
     * @return
     */
    @PostMapping("/v1/sendPhoneMessage")
    public AjaxResult sendPhoneMessage(@RequestBody Map<String,String> data){
        return sysUserService.sendPhoneMessage(data.get("phoneNumber"));
    }

    /**
     * 用户修改密码&需要token
     * @param alertUserPassVo
     * @return
     */
    @PostMapping(value = "/v1/updatePassword")
    public AjaxResult updatePassword(@RequestBody @Valid AlertUserPassVo alertUserPassVo){
        return sysUserService.updataUserPassWord(alertUserPassVo);
    }

    /**
     * 用户修改密码&【不需要token】
     * @param alertUserPassVo
     * @return
     */
    @PostMapping(value = "/v1/codeUpdatePwd")
    public AjaxResult codeUpdatePwd(@RequestBody @Valid AlertUserPassVo alertUserPassVo){
        return sysUserService.updataUserPassWord(alertUserPassVo);
    }

    /**
     * 退出登录
     * @param request
     * @return
     */
    @GetMapping("/loginOut")
    public AjaxResult loginOut(HttpServletRequest request){
        try {
            String openId = tokenService.delLoginUser(request);
            String key="wechat_openIdLogin-"+openId;
            redisCache.deleteObject(key);
        }catch (Exception e){
            e.printStackTrace();
        }
        return success();
    }

}
