package com.yanzhu.jh.bigscreen.web.controller;

import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.PublicStateEnum;
import com.yanzhu.jh.device.domain.DevTowerDataLimit;
import com.yanzhu.jh.device.domain.DevTowerDataRun;
import com.yanzhu.jh.device.domain.DevTowerProjectConfig;
import com.yanzhu.jh.device.service.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * 塔吊监测Controller
 *
 * @author JiangYuQi
 * @date 2024-08-08
 */
@RestController
@RequestMapping("/bgscreen/tower")
public class TowerCraneController extends BaseController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private IDevTowerDataRunService devTowerDataRunService;

    @Autowired
    private IDevTowerDataRoundService devTowerDataRoundService;

    @Autowired
    private IDevTowerDataLimitService devTowerDataLimitService;

    @Autowired
    private IDevTowerDataLocalService devTowerDataLocalService;

    @Autowired
    private IDevTowerDataCollideService devTowerDataCollideService;

    @Autowired
    private IDevTowerProjectConfigService devTowerProjectConfigService;

    /**
     * 查询塔基配置列表
     */
    @GetMapping("/findTowerConfigGroupOnline")
    public AjaxResult findTowerConfigGroupOnline(String deptId, String projectId)
    {
        String key = "bgscreen.tower.findtowerConfigGroupOnline."+projectId;
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return AjaxResult.success(obj);
        }
        DevTowerProjectConfig devTowerProjectConfig = new DevTowerProjectConfig();
        devTowerProjectConfig.setProjectId(Convert.toLong(projectId));
        List<Map<String, Object>> list = devTowerProjectConfigService.findtowerConfigGroupOnline(devTowerProjectConfig);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }

    /**
     * 查询塔基配置列表
     */
    @GetMapping("/findTowerConfigListByProjectId")
    public AjaxResult findTowerConfigListByProjectId(String deptId, String projectId)
    {
        String key = "bgscreen.tower.findtowerConfigListByProjectId."+projectId;
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return AjaxResult.success(obj);
        }
        DevTowerProjectConfig devTowerProjectConfig = new DevTowerProjectConfig();
        devTowerProjectConfig.setProjectId(Convert.toLong(projectId));
        devTowerProjectConfig.setIsDel(Convert.toLong(PublicStateEnum.OK.getCode()));
        List<DevTowerProjectConfig> list = devTowerProjectConfigService.selectDevTowerProjectConfigList(devTowerProjectConfig);
        redisCache.setCacheObject(key, list, Constants.BIGSCREEN_QUERY_CACHE, TimeUnit.MINUTES);
        return success(list);
    }

    /**
     * 查询塔基运行统计
     */
    @GetMapping("/findTowerStatisticsView")
    public AjaxResult findTowerStatisticsView(String deviceSn)
    {
        String key = "bgscreen.tower.findtowerStatisticsView."+deviceSn;
        Object obj=redisCache.getCacheObject(key);
        if(obj!=null){
            return AjaxResult.success(obj);
        }
        Map<String, Object> data = devTowerDataRunService.findtowerStatisticsView(deviceSn);
        redisCache.setCacheObject(key, data, Constants.BIGSCREEN_QUERY_CACHE*5, TimeUnit.MINUTES);
        return success(data);
    }

    /**
     * 查询塔基限位数据
     */
    @GetMapping("/selectDevTowerDataLimitList")
    public AjaxResult selectDevTowerDataLimitList(DevTowerDataLimit devTowerDataLimit)
    {
        startPage();
        List<DevTowerDataLimit> list = devTowerDataLimitService.selectDevTowerDataLimitList(devTowerDataLimit);
        return success(list);
    }

    /**
     * 查询塔基实时数据
     */
    @GetMapping("/selectDevTowerDataRunList")
    public AjaxResult selectDevTowerDataRunList(DevTowerDataRun devTowerDataRun)
    {
        startPage();
        List<DevTowerDataRun> list = devTowerDataRunService.selectDevTowerDataRunList(devTowerDataRun);
        return success(list);
    }
}
