package com.yanzhu.jh.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.base.domain.BaseMag;
import com.yanzhu.jh.base.service.IBaseMagService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 期刊列表Controller
 * 
 * @author ruoyi
 * @date 2024-04-04
 */
@RestController
@RequestMapping("/base/mag")
public class BaseMagController extends BaseController
{
    @Autowired
    private IBaseMagService baseMagService;

    /**
     * 查询期刊列表列表
     */

    @GetMapping("/list")
    public TableDataInfo list(BaseMag baseMag)
    {
        startPage();
        List<BaseMag> list = baseMagService.selectBaseMagList(baseMag);
        return getDataTable(list);
    }

    /**
     * 导出期刊列表列表
     */
    @PreAuthorize("@ss.hasPermi('base:mag:export')")
    @Log(title = "期刊列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseMag baseMag)
    {
        List<BaseMag> list = baseMagService.selectBaseMagList(baseMag);
        ExcelUtil<BaseMag> util = new ExcelUtil<BaseMag>(BaseMag.class);
        util.exportExcel(response, list, "期刊列表数据");
    }

    /**
     * 获取期刊列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:mag:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(baseMagService.selectBaseMagById(id));
    }

    /**
     * 新增期刊列表
     */
    @PreAuthorize("@ss.hasPermi('base:mag:add')")
    @Log(title = "期刊列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseMag baseMag)
    {
        return toAjax(baseMagService.insertBaseMag(baseMag));
    }

    /**
     * 修改期刊列表
     */
    @PreAuthorize("@ss.hasPermi('base:mag:edit')")
    @Log(title = "期刊列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseMag baseMag)
    {
        return toAjax(baseMagService.updateBaseMag(baseMag));
    }

    /**
     * 删除期刊列表
     */
    @PreAuthorize("@ss.hasPermi('base:mag:remove')")
    @Log(title = "期刊列表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(baseMagService.deleteBaseMagByIds(ids));
    }
}
