package com.yanzhu.jh.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.base.domain.BaseMagDetail;
import com.yanzhu.jh.base.service.IBaseMagDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 期刊详情Controller
 * 
 * @author ruoyi
 * @date 2024-04-04
 */
@RestController
@RequestMapping("/base/magDetail")
public class BaseMagDetailController extends BaseController
{
    @Autowired
    private IBaseMagDetailService baseMagDetailService;

    /**
     * 查询期刊详情列表
     */

    @GetMapping("/list")
    public TableDataInfo list(BaseMagDetail baseMagDetail)
    {
        startPage();
        List<BaseMagDetail> list = baseMagDetailService.selectBaseMagDetailList(baseMagDetail);
        return getDataTable(list);
    }

    /**
     * 导出期刊详情列表
     */
    @PreAuthorize("@ss.hasPermi('base:magDetail:export')")
    @Log(title = "期刊详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseMagDetail baseMagDetail)
    {
        List<BaseMagDetail> list = baseMagDetailService.selectBaseMagDetailList(baseMagDetail);
        ExcelUtil<BaseMagDetail> util = new ExcelUtil<BaseMagDetail>(BaseMagDetail.class);
        util.exportExcel(response, list, "期刊详情数据");
    }

    /**
     * 获取期刊详情详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:magDetail:query')")
    @GetMapping(name="/get", value = "{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(baseMagDetailService.selectBaseMagDetailById(id));
    }

    /**
     * 新增期刊详情
     */
    @PreAuthorize("@ss.hasPermi('base:magDetail:add')")
    @Log(title = "期刊详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseMagDetail baseMagDetail)
    {
        return toAjax(baseMagDetailService.insertBaseMagDetail(baseMagDetail));
    }

    /**
     * 修改期刊详情
     */
    @PreAuthorize("@ss.hasPermi('base:magDetail:edit')")
    @Log(title = "期刊详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseMagDetail baseMagDetail)
    {
        return toAjax(baseMagDetailService.updateBaseMagDetail(baseMagDetail));
    }

    /**
     * 删除期刊详情
     */
    @PreAuthorize("@ss.hasPermi('base:magDetail:remove')")
    @Log(title = "期刊详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(baseMagDetailService.deleteBaseMagDetailByIds(ids));
    }

    /**
     * 工程管理-集团期刊汇总
     * @return
     */

    @GetMapping("/groupByTopic")
    public AjaxResult groupByTopic(){
        return AjaxResult.success(baseMagDetailService.groupByTopic());
    }
    /**
     * 期刊上传排名
     * @param magId
     * @return
     */

    @PostMapping("/groupByMag")
    public AjaxResult groupByMag(@RequestBody BaseMagDetail baseMagDetail){
        return AjaxResult.success(baseMagDetailService.groupByMag(baseMagDetail.getMagid()));
    }
}
