package com.yanzhu.jh.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.base.domain.BaseWorkingCommittee;
import com.yanzhu.jh.base.service.IBaseWorkingCommitteeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工委会列表Controller
 * 
 * @author ruoyi
 * @date 2024-04-04
 */
@RestController
@RequestMapping("/base/committee")
public class BaseWorkingCommitteeController extends BaseController
{
    @Autowired
    private IBaseWorkingCommitteeService baseWorkingCommitteeService;

    /**
     * 查询工委会列表列表
     * @PreAuthorize("@ss.hasPermi('base:committee:list')")
     */
    @GetMapping("/list")
    public TableDataInfo list(BaseWorkingCommittee baseWorkingCommittee)
    {
        startPage();
        List<BaseWorkingCommittee> list = baseWorkingCommitteeService.selectBaseWorkingCommitteeList(baseWorkingCommittee);
        return getDataTable(list);
    }

    /**
     * 导出工委会列表列表
     */
    @PreAuthorize("@ss.hasPermi('base:committee:export')")
    @Log(title = "工委会列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseWorkingCommittee baseWorkingCommittee)
    {
        List<BaseWorkingCommittee> list = baseWorkingCommitteeService.selectBaseWorkingCommitteeList(baseWorkingCommittee);
        ExcelUtil<BaseWorkingCommittee> util = new ExcelUtil<BaseWorkingCommittee>(BaseWorkingCommittee.class);
        util.exportExcel(response, list, "工委会列表数据");
    }

    /**
     * 获取工委会列表详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:committee:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(baseWorkingCommitteeService.selectBaseWorkingCommitteeById(id));
    }

    /**
     * 新增工委会列表
     */
    @PreAuthorize("@ss.hasPermi('base:committee:add')")
    @Log(title = "工委会列表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseWorkingCommittee baseWorkingCommittee)
    {
        return toAjax(baseWorkingCommitteeService.insertBaseWorkingCommittee(baseWorkingCommittee));
    }

    /**
     * 修改工委会列表
     */
    @PreAuthorize("@ss.hasPermi('base:committee:edit')")
    @Log(title = "工委会列表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseWorkingCommittee baseWorkingCommittee)
    {
        return toAjax(baseWorkingCommitteeService.updateBaseWorkingCommittee(baseWorkingCommittee));
    }

    /**
     * 删除工委会列表
     */
    @PreAuthorize("@ss.hasPermi('base:committee:remove')")
    @Log(title = "工委会列表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(baseWorkingCommitteeService.deleteBaseWorkingCommitteeByIds(ids));
    }


}
