package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.DevTowerDataCollide;
import com.yanzhu.jh.device.service.IDevTowerDataCollideService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 塔机碰撞信息Controller
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@RestController
@RequestMapping("/device/towerDataCollide")
public class DevTowerDataCollideController extends BaseController
{
    @Autowired
    private IDevTowerDataCollideService devTowerDataCollideService;

    /**
     * 查询塔机碰撞信息列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataCollide:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevTowerDataCollide devTowerDataCollide)
    {
        startPage();
        List<DevTowerDataCollide> list = devTowerDataCollideService.selectDevTowerDataCollideList(devTowerDataCollide);
        return getDataTable(list);
    }

    /**
     * 导出塔机碰撞信息列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataCollide:export')")
    @Log(title = "塔机碰撞信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevTowerDataCollide devTowerDataCollide)
    {
        List<DevTowerDataCollide> list = devTowerDataCollideService.selectDevTowerDataCollideList(devTowerDataCollide);
        ExcelUtil<DevTowerDataCollide> util = new ExcelUtil<DevTowerDataCollide>(DevTowerDataCollide.class);
        util.exportExcel(response, list, "塔机碰撞信息数据");
    }

    /**
     * 获取塔机碰撞信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataCollide:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devTowerDataCollideService.selectDevTowerDataCollideById(id));
    }

    /**
     * 新增塔机碰撞信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataCollide:add')")
    @Log(title = "塔机碰撞信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevTowerDataCollide devTowerDataCollide)
    {
        return toAjax(devTowerDataCollideService.insertDevTowerDataCollide(devTowerDataCollide));
    }

    /**
     * 修改塔机碰撞信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataCollide:edit')")
    @Log(title = "塔机碰撞信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevTowerDataCollide devTowerDataCollide)
    {
        return toAjax(devTowerDataCollideService.updateDevTowerDataCollide(devTowerDataCollide));
    }

    /**
     * 删除塔机碰撞信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataCollide:remove')")
    @Log(title = "塔机碰撞信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devTowerDataCollideService.deleteDevTowerDataCollideByIds(ids));
    }
}
