package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.DevTowerDataLimit;
import com.yanzhu.jh.device.service.IDevTowerDataLimitService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 塔机限位信息Controller
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@RestController
@RequestMapping("/device/towerDataLimit")
public class DevTowerDataLimitController extends BaseController
{
    @Autowired
    private IDevTowerDataLimitService devTowerDataLimitService;

    /**
     * 查询塔机限位信息列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLimit:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevTowerDataLimit devTowerDataLimit)
    {
        startPage();
        List<DevTowerDataLimit> list = devTowerDataLimitService.selectDevTowerDataLimitList(devTowerDataLimit);
        return getDataTable(list);
    }

    /**
     * 导出塔机限位信息列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLimit:export')")
    @Log(title = "塔机限位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevTowerDataLimit devTowerDataLimit)
    {
        List<DevTowerDataLimit> list = devTowerDataLimitService.selectDevTowerDataLimitList(devTowerDataLimit);
        ExcelUtil<DevTowerDataLimit> util = new ExcelUtil<DevTowerDataLimit>(DevTowerDataLimit.class);
        util.exportExcel(response, list, "塔机限位信息数据");
    }

    /**
     * 获取塔机限位信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLimit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devTowerDataLimitService.selectDevTowerDataLimitById(id));
    }

    /**
     * 新增塔机限位信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLimit:add')")
    @Log(title = "塔机限位信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevTowerDataLimit devTowerDataLimit)
    {
        return toAjax(devTowerDataLimitService.insertDevTowerDataLimit(devTowerDataLimit));
    }

    /**
     * 修改塔机限位信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLimit:edit')")
    @Log(title = "塔机限位信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevTowerDataLimit devTowerDataLimit)
    {
        return toAjax(devTowerDataLimitService.updateDevTowerDataLimit(devTowerDataLimit));
    }

    /**
     * 删除塔机限位信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLimit:remove')")
    @Log(title = "塔机限位信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devTowerDataLimitService.deleteDevTowerDataLimitByIds(ids));
    }
}
