package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.DevTowerDataLocal;
import com.yanzhu.jh.device.service.IDevTowerDataLocalService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 塔机定位信息Controller
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@RestController
@RequestMapping("/device/towerDataLocal")
public class DevTowerDataLocalController extends BaseController
{
    @Autowired
    private IDevTowerDataLocalService devTowerDataLocalService;

    /**
     * 查询塔机定位信息列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLocal:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevTowerDataLocal devTowerDataLocal)
    {
        startPage();
        List<DevTowerDataLocal> list = devTowerDataLocalService.selectDevTowerDataLocalList(devTowerDataLocal);
        return getDataTable(list);
    }

    /**
     * 导出塔机定位信息列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLocal:export')")
    @Log(title = "塔机定位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevTowerDataLocal devTowerDataLocal)
    {
        List<DevTowerDataLocal> list = devTowerDataLocalService.selectDevTowerDataLocalList(devTowerDataLocal);
        ExcelUtil<DevTowerDataLocal> util = new ExcelUtil<DevTowerDataLocal>(DevTowerDataLocal.class);
        util.exportExcel(response, list, "塔机定位信息数据");
    }

    /**
     * 获取塔机定位信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLocal:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devTowerDataLocalService.selectDevTowerDataLocalById(id));
    }

    /**
     * 新增塔机定位信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLocal:add')")
    @Log(title = "塔机定位信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevTowerDataLocal devTowerDataLocal)
    {
        return toAjax(devTowerDataLocalService.insertDevTowerDataLocal(devTowerDataLocal));
    }

    /**
     * 修改塔机定位信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLocal:edit')")
    @Log(title = "塔机定位信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevTowerDataLocal devTowerDataLocal)
    {
        return toAjax(devTowerDataLocalService.updateDevTowerDataLocal(devTowerDataLocal));
    }

    /**
     * 删除塔机定位信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataLocal:remove')")
    @Log(title = "塔机定位信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devTowerDataLocalService.deleteDevTowerDataLocalByIds(ids));
    }
}
