package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.DevTowerDataRound;
import com.yanzhu.jh.device.service.IDevTowerDataRoundService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 塔机工作循环Controller
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@RestController
@RequestMapping("/device/towerDataRound")
public class DevTowerDataRoundController extends BaseController
{
    @Autowired
    private IDevTowerDataRoundService devTowerDataRoundService;

    /**
     * 查询塔机工作循环列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRound:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevTowerDataRound devTowerDataRound)
    {
        startPage();
        List<DevTowerDataRound> list = devTowerDataRoundService.selectDevTowerDataRoundList(devTowerDataRound);
        return getDataTable(list);
    }

    /**
     * 导出塔机工作循环列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRound:export')")
    @Log(title = "塔机工作循环", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevTowerDataRound devTowerDataRound)
    {
        List<DevTowerDataRound> list = devTowerDataRoundService.selectDevTowerDataRoundList(devTowerDataRound);
        ExcelUtil<DevTowerDataRound> util = new ExcelUtil<DevTowerDataRound>(DevTowerDataRound.class);
        util.exportExcel(response, list, "塔机工作循环数据");
    }

    /**
     * 获取塔机工作循环详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRound:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devTowerDataRoundService.selectDevTowerDataRoundById(id));
    }

    /**
     * 新增塔机工作循环
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRound:add')")
    @Log(title = "塔机工作循环", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevTowerDataRound devTowerDataRound)
    {
        return toAjax(devTowerDataRoundService.insertDevTowerDataRound(devTowerDataRound));
    }

    /**
     * 修改塔机工作循环
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRound:edit')")
    @Log(title = "塔机工作循环", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevTowerDataRound devTowerDataRound)
    {
        return toAjax(devTowerDataRoundService.updateDevTowerDataRound(devTowerDataRound));
    }

    /**
     * 删除塔机工作循环
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRound:remove')")
    @Log(title = "塔机工作循环", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devTowerDataRoundService.deleteDevTowerDataRoundByIds(ids));
    }
}
