package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.DevTowerDataRun;
import com.yanzhu.jh.device.service.IDevTowerDataRunService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 塔机实时数据Controller
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@RestController
@RequestMapping("/device/towerDataRun")
public class DevTowerDataRunController extends BaseController
{
    @Autowired
    private IDevTowerDataRunService devTowerDataRunService;

    /**
     * 查询塔机实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRun:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevTowerDataRun devTowerDataRun)
    {
        startPage();
        List<DevTowerDataRun> list = devTowerDataRunService.selectDevTowerDataRunList(devTowerDataRun);
        return getDataTable(list);
    }

    /**
     * 导出塔机实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRun:export')")
    @Log(title = "塔机实时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevTowerDataRun devTowerDataRun)
    {
        List<DevTowerDataRun> list = devTowerDataRunService.selectDevTowerDataRunList(devTowerDataRun);
        ExcelUtil<DevTowerDataRun> util = new ExcelUtil<DevTowerDataRun>(DevTowerDataRun.class);
        util.exportExcel(response, list, "塔机实时数据数据");
    }

    /**
     * 获取塔机实时数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRun:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devTowerDataRunService.selectDevTowerDataRunById(id));
    }

    /**
     * 新增塔机实时数据
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRun:add')")
    @Log(title = "塔机实时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevTowerDataRun devTowerDataRun)
    {
        return toAjax(devTowerDataRunService.insertDevTowerDataRun(devTowerDataRun));
    }

    /**
     * 修改塔机实时数据
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRun:edit')")
    @Log(title = "塔机实时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevTowerDataRun devTowerDataRun)
    {
        return toAjax(devTowerDataRunService.updateDevTowerDataRun(devTowerDataRun));
    }

    /**
     * 删除塔机实时数据
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataRun:remove')")
    @Log(title = "塔机实时数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devTowerDataRunService.deleteDevTowerDataRunByIds(ids));
    }
}
