package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.DevTowerDataWarning;
import com.yanzhu.jh.device.service.IDevTowerDataWarningService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 塔机预警管理Controller
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@RestController
@RequestMapping("/device/towerDataWarning")
public class DevTowerDataWarningController extends BaseController
{
    @Autowired
    private IDevTowerDataWarningService devTowerDataWarningService;

    /**
     * 查询塔机预警管理列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataWarning:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevTowerDataWarning devTowerDataWarning)
    {
        startPage();
        List<DevTowerDataWarning> list = devTowerDataWarningService.selectDevTowerDataWarningList(devTowerDataWarning);
        return getDataTable(list);
    }

    /**
     * 导出塔机预警管理列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataWarning:export')")
    @Log(title = "塔机预警管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevTowerDataWarning devTowerDataWarning)
    {
        List<DevTowerDataWarning> list = devTowerDataWarningService.selectDevTowerDataWarningList(devTowerDataWarning);
        ExcelUtil<DevTowerDataWarning> util = new ExcelUtil<DevTowerDataWarning>(DevTowerDataWarning.class);
        util.exportExcel(response, list, "塔机预警管理数据");
    }

    /**
     * 获取塔机预警管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataWarning:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devTowerDataWarningService.selectDevTowerDataWarningById(id));
    }

    /**
     * 新增塔机预警管理
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataWarning:add')")
    @Log(title = "塔机预警管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevTowerDataWarning devTowerDataWarning)
    {
        return toAjax(devTowerDataWarningService.insertDevTowerDataWarning(devTowerDataWarning));
    }

    /**
     * 修改塔机预警管理
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataWarning:edit')")
    @Log(title = "塔机预警管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevTowerDataWarning devTowerDataWarning)
    {
        return toAjax(devTowerDataWarningService.updateDevTowerDataWarning(devTowerDataWarning));
    }

    /**
     * 删除塔机预警管理
     */
    @PreAuthorize("@ss.hasPermi('device:towerDataWarning:remove')")
    @Log(title = "塔机预警管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devTowerDataWarningService.deleteDevTowerDataWarningByIds(ids));
    }
}
