package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.DevTowerProjectConfig;
import com.yanzhu.jh.device.service.IDevTowerProjectConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 塔基检测配置Controller
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@RestController
@RequestMapping("/device/towerProjectConfig")
public class DevTowerProjectConfigController extends BaseController
{
    @Autowired
    private IDevTowerProjectConfigService devTowerProjectConfigService;

    /**
     * 查询塔基检测配置列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerProjectConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevTowerProjectConfig devTowerProjectConfig)
    {
        startPage();
        List<DevTowerProjectConfig> list = devTowerProjectConfigService.selectDevTowerProjectConfigList(devTowerProjectConfig);
        return getDataTable(list);
    }

    /**
     * 导出塔基检测配置列表
     */
    @PreAuthorize("@ss.hasPermi('device:towerProjectConfig:export')")
    @Log(title = "塔基检测配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevTowerProjectConfig devTowerProjectConfig)
    {
        List<DevTowerProjectConfig> list = devTowerProjectConfigService.selectDevTowerProjectConfigList(devTowerProjectConfig);
        ExcelUtil<DevTowerProjectConfig> util = new ExcelUtil<DevTowerProjectConfig>(DevTowerProjectConfig.class);
        util.exportExcel(response, list, "塔基检测配置数据");
    }

    /**
     * 获取塔基检测配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:towerProjectConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devTowerProjectConfigService.selectDevTowerProjectConfigById(id));
    }

    /**
     * 新增塔基检测配置
     */
    @PreAuthorize("@ss.hasPermi('device:towerProjectConfig:add')")
    @Log(title = "塔基检测配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevTowerProjectConfig devTowerProjectConfig)
    {
        return toAjax(devTowerProjectConfigService.insertDevTowerProjectConfig(devTowerProjectConfig));
    }

    /**
     * 修改塔基检测配置
     */
    @PreAuthorize("@ss.hasPermi('device:towerProjectConfig:edit')")
    @Log(title = "塔基检测配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevTowerProjectConfig devTowerProjectConfig)
    {
        return toAjax(devTowerProjectConfigService.updateDevTowerProjectConfig(devTowerProjectConfig));
    }

    /**
     * 删除塔基检测配置
     */
    @PreAuthorize("@ss.hasPermi('device:towerProjectConfig:remove')")
    @Log(title = "塔基检测配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devTowerProjectConfigService.deleteDevTowerProjectConfigByIds(ids));
    }
}
