package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.PitmonitSouthsmosAlarm;
import com.yanzhu.jh.device.service.IPitmonitSouthsmosAlarmService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 报警信息Controller
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@RestController
@RequestMapping("/device/pitAlarm")
public class PitmonitSouthsmosAlarmController extends BaseController
{
    @Autowired
    private IPitmonitSouthsmosAlarmService devPitmonitSouthsmosAlarmService;

    /**
     * 查询报警信息列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitAlarm:list')")
    @GetMapping("/list")
    public TableDataInfo list(PitmonitSouthsmosAlarm pitmonitSouthsmosAlarm)
    {
        startPage();
        List<PitmonitSouthsmosAlarm> list = devPitmonitSouthsmosAlarmService.selectDevPitmonitSouthsmosAlarmList(pitmonitSouthsmosAlarm);
        return getDataTable(list);
    }

    /**
     * 导出报警信息列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitAlarm:export')")
    @Log(title = "报警信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PitmonitSouthsmosAlarm pitmonitSouthsmosAlarm)
    {
        List<PitmonitSouthsmosAlarm> list = devPitmonitSouthsmosAlarmService.selectDevPitmonitSouthsmosAlarmList(pitmonitSouthsmosAlarm);
        ExcelUtil<PitmonitSouthsmosAlarm> util = new ExcelUtil<PitmonitSouthsmosAlarm>(PitmonitSouthsmosAlarm.class);
        util.exportExcel(response, list, "报警信息数据");
    }

    /**
     * 获取报警信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitAlarm:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devPitmonitSouthsmosAlarmService.selectDevPitmonitSouthsmosAlarmById(id));
    }

    /**
     * 新增报警信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitAlarm:add')")
    @Log(title = "报警信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PitmonitSouthsmosAlarm pitmonitSouthsmosAlarm)
    {
        return toAjax(devPitmonitSouthsmosAlarmService.insertDevPitmonitSouthsmosAlarm(pitmonitSouthsmosAlarm));
    }

    /**
     * 修改报警信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitAlarm:edit')")
    @Log(title = "报警信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PitmonitSouthsmosAlarm pitmonitSouthsmosAlarm)
    {
        return toAjax(devPitmonitSouthsmosAlarmService.updateDevPitmonitSouthsmosAlarm(pitmonitSouthsmosAlarm));
    }

    /**
     * 删除报警信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitAlarm:remove')")
    @Log(title = "报警信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devPitmonitSouthsmosAlarmService.deleteDevPitmonitSouthsmosAlarmByIds(ids));
    }
}
