package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.PitmonitSouthsmosData;
import com.yanzhu.jh.device.service.IPitmonitSouthsmosDataService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 测点数据Controller
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@RestController
@RequestMapping("/device/pitData")
public class PitmonitSouthsmosDataController extends BaseController
{
    @Autowired
    private IPitmonitSouthsmosDataService devPitmonitSouthsmosDataService;

    /**
     * 查询测点数据列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitData:list')")
    @GetMapping("/list")
    public TableDataInfo list(PitmonitSouthsmosData pitmonitSouthsmosData)
    {
        startPage();
        List<PitmonitSouthsmosData> list = devPitmonitSouthsmosDataService.selectDevPitmonitSouthsmosDataList(pitmonitSouthsmosData);
        return getDataTable(list);
    }

    /**
     * 导出测点数据列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitData:export')")
    @Log(title = "测点数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PitmonitSouthsmosData pitmonitSouthsmosData)
    {
        List<PitmonitSouthsmosData> list = devPitmonitSouthsmosDataService.selectDevPitmonitSouthsmosDataList(pitmonitSouthsmosData);
        ExcelUtil<PitmonitSouthsmosData> util = new ExcelUtil<PitmonitSouthsmosData>(PitmonitSouthsmosData.class);
        util.exportExcel(response, list, "测点数据数据");
    }

    /**
     * 获取测点数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitData:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devPitmonitSouthsmosDataService.selectDevPitmonitSouthsmosDataById(id));
    }

    /**
     * 新增测点数据
     */
    @PreAuthorize("@ss.hasPermi('device:pitData:add')")
    @Log(title = "测点数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PitmonitSouthsmosData pitmonitSouthsmosData)
    {
        return toAjax(devPitmonitSouthsmosDataService.insertDevPitmonitSouthsmosData(pitmonitSouthsmosData));
    }

    /**
     * 修改测点数据
     */
    @PreAuthorize("@ss.hasPermi('device:pitData:edit')")
    @Log(title = "测点数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PitmonitSouthsmosData pitmonitSouthsmosData)
    {
        return toAjax(devPitmonitSouthsmosDataService.updateDevPitmonitSouthsmosData(pitmonitSouthsmosData));
    }

    /**
     * 删除测点数据
     */
    @PreAuthorize("@ss.hasPermi('device:pitData:remove')")
    @Log(title = "测点数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devPitmonitSouthsmosDataService.deleteDevPitmonitSouthsmosDataByIds(ids));
    }
}
