package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.PitmonitSouthsmosDevSp;
import com.yanzhu.jh.device.service.IPitmonitSouthsmosDevSpService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 设测点关系Controller
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@RestController
@RequestMapping("/device/pitDeviceSurveyPoint")
public class PitmonitSouthsmosDevSpController extends BaseController
{
    @Autowired
    private IPitmonitSouthsmosDevSpService devPitmonitSouthsmosDevSpService;

    /**
     * 查询设测点关系列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitDeviceSurveyPoint:list')")
    @GetMapping("/list")
    public TableDataInfo list(PitmonitSouthsmosDevSp pitmonitSouthsmosDevSp)
    {
        startPage();
        List<PitmonitSouthsmosDevSp> list = devPitmonitSouthsmosDevSpService.selectDevPitmonitSouthsmosDevSpList(pitmonitSouthsmosDevSp);
        return getDataTable(list);
    }

    /**
     * 导出设测点关系列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitDeviceSurveyPoint:export')")
    @Log(title = "设测点关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PitmonitSouthsmosDevSp pitmonitSouthsmosDevSp)
    {
        List<PitmonitSouthsmosDevSp> list = devPitmonitSouthsmosDevSpService.selectDevPitmonitSouthsmosDevSpList(pitmonitSouthsmosDevSp);
        ExcelUtil<PitmonitSouthsmosDevSp> util = new ExcelUtil<PitmonitSouthsmosDevSp>(PitmonitSouthsmosDevSp.class);
        util.exportExcel(response, list, "设测点关系数据");
    }

    /**
     * 获取设测点关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitDeviceSurveyPoint:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devPitmonitSouthsmosDevSpService.selectDevPitmonitSouthsmosDevSpById(id));
    }

    /**
     * 新增设测点关系
     */
    @PreAuthorize("@ss.hasPermi('device:pitDeviceSurveyPoint:add')")
    @Log(title = "设测点关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PitmonitSouthsmosDevSp pitmonitSouthsmosDevSp)
    {
        return toAjax(devPitmonitSouthsmosDevSpService.insertDevPitmonitSouthsmosDevSp(pitmonitSouthsmosDevSp));
    }

    /**
     * 修改设测点关系
     */
    @PreAuthorize("@ss.hasPermi('device:pitDeviceSurveyPoint:edit')")
    @Log(title = "设测点关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PitmonitSouthsmosDevSp pitmonitSouthsmosDevSp)
    {
        return toAjax(devPitmonitSouthsmosDevSpService.updateDevPitmonitSouthsmosDevSp(pitmonitSouthsmosDevSp));
    }

    /**
     * 删除设测点关系
     */
    @PreAuthorize("@ss.hasPermi('device:pitDeviceSurveyPoint:remove')")
    @Log(title = "设测点关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devPitmonitSouthsmosDevSpService.deleteDevPitmonitSouthsmosDevSpByIds(ids));
    }
}
