package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.PitmonitSouthsmosDevice;
import com.yanzhu.jh.device.service.IPitmonitSouthsmosDeviceService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 设备管理Controller
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@RestController
@RequestMapping("/device/pitDevice")
public class PitmonitSouthsmosDeviceController extends BaseController
{
    @Autowired
    private IPitmonitSouthsmosDeviceService devPitmonitSouthsmosDeviceService;

    /**
     * 查询设备管理列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitDevice:list')")
    @GetMapping("/list")
    public TableDataInfo list(PitmonitSouthsmosDevice pitmonitSouthsmosDevice)
    {
        startPage();
        List<PitmonitSouthsmosDevice> list = devPitmonitSouthsmosDeviceService.selectDevPitmonitSouthsmosDeviceList(pitmonitSouthsmosDevice);
        return getDataTable(list);
    }

    /**
     * 导出设备管理列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitDevice:export')")
    @Log(title = "设备管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PitmonitSouthsmosDevice pitmonitSouthsmosDevice)
    {
        List<PitmonitSouthsmosDevice> list = devPitmonitSouthsmosDeviceService.selectDevPitmonitSouthsmosDeviceList(pitmonitSouthsmosDevice);
        ExcelUtil<PitmonitSouthsmosDevice> util = new ExcelUtil<PitmonitSouthsmosDevice>(PitmonitSouthsmosDevice.class);
        util.exportExcel(response, list, "设备管理数据");
    }

    /**
     * 获取设备管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitDevice:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devPitmonitSouthsmosDeviceService.selectDevPitmonitSouthsmosDeviceById(id));
    }

    /**
     * 新增设备管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitDevice:add')")
    @Log(title = "设备管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PitmonitSouthsmosDevice pitmonitSouthsmosDevice)
    {
        return toAjax(devPitmonitSouthsmosDeviceService.insertDevPitmonitSouthsmosDevice(pitmonitSouthsmosDevice));
    }

    /**
     * 修改设备管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitDevice:edit')")
    @Log(title = "设备管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PitmonitSouthsmosDevice pitmonitSouthsmosDevice)
    {
        return toAjax(devPitmonitSouthsmosDeviceService.updateDevPitmonitSouthsmosDevice(pitmonitSouthsmosDevice));
    }

    /**
     * 删除设备管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitDevice:remove')")
    @Log(title = "设备管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devPitmonitSouthsmosDeviceService.deleteDevPitmonitSouthsmosDeviceByIds(ids));
    }
}
