package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.PitmonitSouthsmosElement;
import com.yanzhu.jh.device.service.IPitmonitSouthsmosElementService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 监测项管理Controller
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@RestController
@RequestMapping("/device/pitElement")
public class PitmonitSouthsmosElementController extends BaseController
{
    @Autowired
    private IPitmonitSouthsmosElementService devPitmonitSouthsmosElementService;

    /**
     * 查询监测项管理列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitElement:list')")
    @GetMapping("/list")
    public TableDataInfo list(PitmonitSouthsmosElement pitmonitSouthsmosElement)
    {
        startPage();
        List<PitmonitSouthsmosElement> list = devPitmonitSouthsmosElementService.selectDevPitmonitSouthsmosElementList(pitmonitSouthsmosElement);
        return getDataTable(list);
    }

    /**
     * 导出监测项管理列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitElement:export')")
    @Log(title = "监测项管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PitmonitSouthsmosElement pitmonitSouthsmosElement)
    {
        List<PitmonitSouthsmosElement> list = devPitmonitSouthsmosElementService.selectDevPitmonitSouthsmosElementList(pitmonitSouthsmosElement);
        ExcelUtil<PitmonitSouthsmosElement> util = new ExcelUtil<PitmonitSouthsmosElement>(PitmonitSouthsmosElement.class);
        util.exportExcel(response, list, "监测项管理数据");
    }

    /**
     * 获取监测项管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitElement:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devPitmonitSouthsmosElementService.selectDevPitmonitSouthsmosElementById(id));
    }

    /**
     * 新增监测项管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitElement:add')")
    @Log(title = "监测项管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PitmonitSouthsmosElement pitmonitSouthsmosElement)
    {
        return toAjax(devPitmonitSouthsmosElementService.insertDevPitmonitSouthsmosElement(pitmonitSouthsmosElement));
    }

    /**
     * 修改监测项管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitElement:edit')")
    @Log(title = "监测项管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PitmonitSouthsmosElement pitmonitSouthsmosElement)
    {
        return toAjax(devPitmonitSouthsmosElementService.updateDevPitmonitSouthsmosElement(pitmonitSouthsmosElement));
    }

    /**
     * 删除监测项管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitElement:remove')")
    @Log(title = "监测项管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devPitmonitSouthsmosElementService.deleteDevPitmonitSouthsmosElementByIds(ids));
    }
}
