package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.PitmonitSouthsmosSurveypoint;
import com.yanzhu.jh.device.service.IPitmonitSouthsmosSurveypointService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 测点管理Controller
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@RestController
@RequestMapping("/device/pitSurveyPoint")
public class PitmonitSouthsmosSurveypointController extends BaseController
{
    @Autowired
    private IPitmonitSouthsmosSurveypointService devPitmonitSouthsmosSurveypointService;

    /**
     * 查询测点管理列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitSurveyPoint:list')")
    @GetMapping("/list")
    public TableDataInfo list(PitmonitSouthsmosSurveypoint pitmonitSouthsmosSurveypoint)
    {
        startPage();
        List<PitmonitSouthsmosSurveypoint> list = devPitmonitSouthsmosSurveypointService.selectDevPitmonitSouthsmosSurveypointList(pitmonitSouthsmosSurveypoint);
        return getDataTable(list);
    }

    /**
     * 导出测点管理列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitSurveyPoint:export')")
    @Log(title = "测点管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PitmonitSouthsmosSurveypoint pitmonitSouthsmosSurveypoint)
    {
        List<PitmonitSouthsmosSurveypoint> list = devPitmonitSouthsmosSurveypointService.selectDevPitmonitSouthsmosSurveypointList(pitmonitSouthsmosSurveypoint);
        ExcelUtil<PitmonitSouthsmosSurveypoint> util = new ExcelUtil<PitmonitSouthsmosSurveypoint>(PitmonitSouthsmosSurveypoint.class);
        util.exportExcel(response, list, "测点管理数据");
    }

    /**
     * 获取测点管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitSurveyPoint:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devPitmonitSouthsmosSurveypointService.selectDevPitmonitSouthsmosSurveypointById(id));
    }

    /**
     * 新增测点管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitSurveyPoint:add')")
    @Log(title = "测点管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PitmonitSouthsmosSurveypoint pitmonitSouthsmosSurveypoint)
    {
        return toAjax(devPitmonitSouthsmosSurveypointService.insertDevPitmonitSouthsmosSurveypoint(pitmonitSouthsmosSurveypoint));
    }

    /**
     * 修改测点管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitSurveyPoint:edit')")
    @Log(title = "测点管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PitmonitSouthsmosSurveypoint pitmonitSouthsmosSurveypoint)
    {
        return toAjax(devPitmonitSouthsmosSurveypointService.updateDevPitmonitSouthsmosSurveypoint(pitmonitSouthsmosSurveypoint));
    }

    /**
     * 删除测点管理
     */
    @PreAuthorize("@ss.hasPermi('device:pitSurveyPoint:remove')")
    @Log(title = "测点管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devPitmonitSouthsmosSurveypointService.deleteDevPitmonitSouthsmosSurveypointByIds(ids));
    }
}
