package com.yanzhu.jh.device.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.device.domain.PitmonitSouthsmosThreshold;
import com.yanzhu.jh.device.service.IPitmonitSouthsmosThresholdService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 报警阈值Controller
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@RestController
@RequestMapping("/device/pitThreshold")
public class PitmonitSouthsmosThresholdController extends BaseController
{
    @Autowired
    private IPitmonitSouthsmosThresholdService devPitmonitSouthsmosThresholdService;

    /**
     * 查询报警阈值列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitThreshold:list')")
    @GetMapping("/list")
    public TableDataInfo list(PitmonitSouthsmosThreshold pitmonitSouthsmosThreshold)
    {
        startPage();
        List<PitmonitSouthsmosThreshold> list = devPitmonitSouthsmosThresholdService.selectDevPitmonitSouthsmosThresholdList(pitmonitSouthsmosThreshold);
        return getDataTable(list);
    }

    /**
     * 导出报警阈值列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitThreshold:export')")
    @Log(title = "报警阈值", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PitmonitSouthsmosThreshold pitmonitSouthsmosThreshold)
    {
        List<PitmonitSouthsmosThreshold> list = devPitmonitSouthsmosThresholdService.selectDevPitmonitSouthsmosThresholdList(pitmonitSouthsmosThreshold);
        ExcelUtil<PitmonitSouthsmosThreshold> util = new ExcelUtil<PitmonitSouthsmosThreshold>(PitmonitSouthsmosThreshold.class);
        util.exportExcel(response, list, "报警阈值数据");
    }

    /**
     * 获取报警阈值详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitThreshold:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devPitmonitSouthsmosThresholdService.selectDevPitmonitSouthsmosThresholdById(id));
    }

    /**
     * 新增报警阈值
     */
    @PreAuthorize("@ss.hasPermi('device:pitThreshold:add')")
    @Log(title = "报警阈值", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PitmonitSouthsmosThreshold pitmonitSouthsmosThreshold)
    {
        return toAjax(devPitmonitSouthsmosThresholdService.insertDevPitmonitSouthsmosThreshold(pitmonitSouthsmosThreshold));
    }

    /**
     * 修改报警阈值
     */
    @PreAuthorize("@ss.hasPermi('device:pitThreshold:edit')")
    @Log(title = "报警阈值", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PitmonitSouthsmosThreshold pitmonitSouthsmosThreshold)
    {
        return toAjax(devPitmonitSouthsmosThresholdService.updateDevPitmonitSouthsmosThreshold(pitmonitSouthsmosThreshold));
    }

    /**
     * 删除报警阈值
     */
    @PreAuthorize("@ss.hasPermi('device:pitThreshold:remove')")
    @Log(title = "报警阈值", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devPitmonitSouthsmosThresholdService.deleteDevPitmonitSouthsmosThresholdByIds(ids));
    }
}
