package com.yanzhu.jh.device.controller;

import java.util.List;

import com.ruoyi.common.enums.BusinessType;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.yanzhu.jh.device.domain.ProjectPitMonitCfg;
import com.yanzhu.jh.device.service.IProjectPitMonitCfgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

import javax.servlet.http.HttpServletResponse;

/**
 * 项目基坑监测配置
Controller
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@RestController
@RequestMapping("/device/pitConfig")
public class ProjectPitMonitCfgController extends BaseController
{
    @Autowired
    private IProjectPitMonitCfgService surProjectPitMonitCfgService;

    /**
     * 查询项目基坑监测配置
列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProjectPitMonitCfg projectPitMonitCfg)
    {
        startPage();
        List<ProjectPitMonitCfg> list = surProjectPitMonitCfgService.selectSurProjectPitMonitCfgList(projectPitMonitCfg);
        return getDataTable(list);
    }

    /**
     * 导出项目基坑监测配置
列表
     */
    @PreAuthorize("@ss.hasPermi('device:pitConfig:export')")
    @Log(title = "项目基坑监测配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProjectPitMonitCfg surProjectPitMonitCfg)
    {
        List<ProjectPitMonitCfg> list = surProjectPitMonitCfgService.selectSurProjectPitMonitCfgList(surProjectPitMonitCfg);
        ExcelUtil<ProjectPitMonitCfg> util = new ExcelUtil<ProjectPitMonitCfg>(ProjectPitMonitCfg.class);
        util.exportExcel(response, list, "项目基坑监测配置数据");
    }

    /**
     * 获取项目基坑监测配置
详细信息
     */
    @PreAuthorize("@ss.hasPermi('device:pitConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectPitMonitCfgService.selectSurProjectPitMonitCfgById(id));
    }

    /**
     * 新增项目基坑监测配置

     */
    @PreAuthorize("@ss.hasPermi('device:pitConfig:add')")
    @Log(title = "项目基坑监测配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProjectPitMonitCfg surProjectPitMonitCfg)
    {
        return toAjax(surProjectPitMonitCfgService.insertSurProjectPitMonitCfg(surProjectPitMonitCfg));
    }

    /**
     * 修改项目基坑监测配置

     */
    @PreAuthorize("@ss.hasPermi('device:pitConfig:edit')")
    @Log(title = "项目基坑监测配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProjectPitMonitCfg surProjectPitMonitCfg)
    {
        return toAjax(surProjectPitMonitCfgService.updateSurProjectPitMonitCfg(surProjectPitMonitCfg));
    }

    /**
     * 删除项目基坑监测配置

     */
    @PreAuthorize("@ss.hasPermi('device:pitConfig:remove')")
    @Log(title = "项目基坑监测配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectPitMonitCfgService.deleteSurProjectPitMonitCfgByIds(ids));
    }
}
