package com.yanzhu.jh.device.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.ArrayList;
import com.ruoyi.common.utils.StringUtils;
import org.springframework.transaction.annotation.Transactional;
import com.yanzhu.jh.device.domain.DevTowerDataCollideDetail;
import com.yanzhu.jh.device.mapper.DevTowerDataCollideMapper;
import com.yanzhu.jh.device.domain.DevTowerDataCollide;
import com.yanzhu.jh.device.service.IDevTowerDataCollideService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 塔机碰撞信息Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@Service
public class DevTowerDataCollideServiceImpl implements IDevTowerDataCollideService 
{
    @Autowired
    private DevTowerDataCollideMapper devTowerDataCollideMapper;

    /**
     * 查询塔机碰撞信息
     * 
     * @param id 塔机碰撞信息主键
     * @return 塔机碰撞信息
     */
    @Override
    public DevTowerDataCollide selectDevTowerDataCollideById(Long id)
    {
        return devTowerDataCollideMapper.selectDevTowerDataCollideById(id);
    }

    /**
     * 查询塔机碰撞信息列表
     * 
     * @param devTowerDataCollide 塔机碰撞信息
     * @return 塔机碰撞信息
     */
    @Override
    public List<DevTowerDataCollide> selectDevTowerDataCollideList(DevTowerDataCollide devTowerDataCollide)
    {
        return devTowerDataCollideMapper.selectDevTowerDataCollideList(devTowerDataCollide);
    }

    /**
     * 新增塔机碰撞信息
     * 
     * @param devTowerDataCollide 塔机碰撞信息
     * @return 结果
     */
    @Transactional
    @Override
    public int insertDevTowerDataCollide(DevTowerDataCollide devTowerDataCollide)
    {
        //devTowerDataCollide.setCreateBy(SecurityUtils.getUsername());
        devTowerDataCollide.setCreateTime(DateUtils.getNowDate());
        int rows = devTowerDataCollideMapper.insertDevTowerDataCollide(devTowerDataCollide);
        insertDevTowerDataCollideDetail(devTowerDataCollide);
        return rows;
    }

    /**
     * 修改塔机碰撞信息
     * 
     * @param devTowerDataCollide 塔机碰撞信息
     * @return 结果
     */
    @Transactional
    @Override
    public int updateDevTowerDataCollide(DevTowerDataCollide devTowerDataCollide)
    {
        //devTowerDataCollide.setUpdateBy(SecurityUtils.getUsername());
        devTowerDataCollide.setUpdateTime(DateUtils.getNowDate());
        devTowerDataCollideMapper.deleteDevTowerDataCollideDetailByCollideId(devTowerDataCollide.getId());
        insertDevTowerDataCollideDetail(devTowerDataCollide);
        return devTowerDataCollideMapper.updateDevTowerDataCollide(devTowerDataCollide);
    }

    /**
     * 批量删除塔机碰撞信息
     * 
     * @param ids 需要删除的塔机碰撞信息主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteDevTowerDataCollideByIds(Long[] ids)
    {
        devTowerDataCollideMapper.deleteDevTowerDataCollideDetailByCollideIds(ids);
        return devTowerDataCollideMapper.deleteDevTowerDataCollideByIds(ids);
    }

    /**
     * 删除塔机碰撞信息信息
     * 
     * @param id 塔机碰撞信息主键
     * @return 结果
     */
    @Transactional
    @Override
    public int deleteDevTowerDataCollideById(Long id)
    {
        devTowerDataCollideMapper.deleteDevTowerDataCollideDetailByCollideId(id);
        return devTowerDataCollideMapper.deleteDevTowerDataCollideById(id);
    }

    /**
     * 新增碰撞详情信息
     * 
     * @param devTowerDataCollide 塔机碰撞信息对象
     */
    public void insertDevTowerDataCollideDetail(DevTowerDataCollide devTowerDataCollide)
    {
        List<DevTowerDataCollideDetail> devTowerDataCollideDetailList = devTowerDataCollide.getDevTowerDataCollideDetailList();
        Long id = devTowerDataCollide.getId();
        if (StringUtils.isNotNull(devTowerDataCollideDetailList))
        {
            List<DevTowerDataCollideDetail> list = new ArrayList<DevTowerDataCollideDetail>();
            for (DevTowerDataCollideDetail devTowerDataCollideDetail : devTowerDataCollideDetailList)
            {
                devTowerDataCollideDetail.setCollideId(id);
                list.add(devTowerDataCollideDetail);
            }
            if (list.size() > 0)
            {
                devTowerDataCollideMapper.batchDevTowerDataCollideDetail(list);
            }
        }
    }
}
