package com.yanzhu.jh.device.service.impl;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.DateUtils;
import org.apache.commons.collections4.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.device.mapper.DevTowerProjectConfigMapper;
import com.yanzhu.jh.device.domain.DevTowerProjectConfig;
import com.yanzhu.jh.device.service.IDevTowerProjectConfigService;
import com.ruoyi.common.utils.SecurityUtils;

import javax.annotation.PostConstruct;

/**
 * 塔基检测配置Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-08-04
 */
@Service
public class DevTowerProjectConfigServiceImpl implements IDevTowerProjectConfigService 
{
    @Autowired
    private RedisCache redisCache;

    @Autowired
    private DevTowerProjectConfigMapper devTowerProjectConfigMapper;

    /**
     * 项目启动时，初始化塔吊检测配置到缓存
     */
    @PostConstruct
    public void init()
    {
        loadingDevTowerProjectConfigCache();
    }

    /**
     * 加载注册应用
     */
    @Override
    public void loadingDevTowerProjectConfigCache()
    {
        this.clearConfigCache();
        List<DevTowerProjectConfig> configList = devTowerProjectConfigMapper.selectDevTowerProjectConfigList(new DevTowerProjectConfig());
        if(CollectionUtils.isNotEmpty(configList)){
            for (DevTowerProjectConfig config : configList) {
                redisCache.setCacheObject(CacheConstants.YANZHU_DEVICE_TOWER + config.getDeviceSn(), config);
            }
        }
    }

    private void clearConfigCache()
    {
        Collection<String> keys = redisCache.keys(CacheConstants.YANZHU_DEVICE_TOWER + "*");
        redisCache.deleteObject(keys);
    }

    /**
     * 查询塔基检测配置
     * 
     * @param id 塔基检测配置主键
     * @return 塔基检测配置
     */
    @Override
    public DevTowerProjectConfig selectDevTowerProjectConfigById(Long id)
    {
        return devTowerProjectConfigMapper.selectDevTowerProjectConfigById(id);
    }

    /**
     * 查询塔基检测配置列表
     * 
     * @param devTowerProjectConfig 塔基检测配置
     * @return 塔基检测配置
     */
    @Override
    public List<DevTowerProjectConfig> selectDevTowerProjectConfigList(DevTowerProjectConfig devTowerProjectConfig)
    {
        return devTowerProjectConfigMapper.selectDevTowerProjectConfigList(devTowerProjectConfig);
    }

    /**
     * 新增塔基检测配置
     * 
     * @param devTowerProjectConfig 塔基检测配置
     * @return 结果
     */
    @Override
    public int insertDevTowerProjectConfig(DevTowerProjectConfig devTowerProjectConfig)
    {
        devTowerProjectConfig.setCreateBy(SecurityUtils.getUsername());
        devTowerProjectConfig.setCreateTime(DateUtils.getNowDate());
        int res = devTowerProjectConfigMapper.insertDevTowerProjectConfig(devTowerProjectConfig);
        this.loadingDevTowerProjectConfigCache();
        return res;
    }

    /**
     * 修改塔基检测配置
     * 
     * @param devTowerProjectConfig 塔基检测配置
     * @return 结果
     */
    @Override
    public int updateDevTowerProjectConfig(DevTowerProjectConfig devTowerProjectConfig)
    {
        devTowerProjectConfig.setUpdateBy(SecurityUtils.getUsername());
        devTowerProjectConfig.setUpdateTime(DateUtils.getNowDate());
        int res = devTowerProjectConfigMapper.updateDevTowerProjectConfig(devTowerProjectConfig);
        this.loadingDevTowerProjectConfigCache();
        return res;
    }

    /**
     * 修改塔基检测配置
     *
     * @param devTowerProjectConfig 塔基检测配置
     * @return 结果
     */
    @Override
    public int updateDevTowerProjectConfigNoCache(DevTowerProjectConfig devTowerProjectConfig)
    {
        devTowerProjectConfig.setUpdateTime(DateUtils.getNowDate());
        return devTowerProjectConfigMapper.updateDevTowerProjectConfig(devTowerProjectConfig);
    }

    /**
     * 批量删除塔基检测配置
     * 
     * @param ids 需要删除的塔基检测配置主键
     * @return 结果
     */
    @Override
    public int deleteDevTowerProjectConfigByIds(Long[] ids)
    {
        int res = devTowerProjectConfigMapper.deleteDevTowerProjectConfigByIds(ids);
        this.loadingDevTowerProjectConfigCache();
        return res;
    }

    /**
     * 删除塔基检测配置信息
     * 
     * @param id 塔基检测配置主键
     * @return 结果
     */
    @Override
    public int deleteDevTowerProjectConfigById(Long id)
    {
        int res = devTowerProjectConfigMapper.deleteDevTowerProjectConfigById(id);
        this.loadingDevTowerProjectConfigCache();
        return res;
    }

    /**
     * 根据设备状态统计设备
     * @param devTowerProjectConfig
     * @return
     */
    public List<Map<String, Object>> findtowerConfigGroupOnline(DevTowerProjectConfig devTowerProjectConfig){
        return devTowerProjectConfigMapper.findtowerConfigGroupOnline(devTowerProjectConfig);
    }
}
