package com.yanzhu.jh.device.service.impl;

import java.util.Date;
import java.util.List;

import cn.hutool.core.date.DateUnit;
import cn.hutool.core.date.DateUtil;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.device.mapper.PitmonitSouthsmosDataMapper;
import com.yanzhu.jh.device.domain.PitmonitSouthsmosData;
import com.yanzhu.jh.device.service.IPitmonitSouthsmosDataService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 测点数据Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
@Service
public class PitmonitSouthsmosDataServiceImpl implements IPitmonitSouthsmosDataService
{
    @Autowired
    private PitmonitSouthsmosDataMapper pitmonitSouthsmosDataMapper;

    /**
     * 查询测点数据
     * 
     * @param id 测点数据主键
     * @return 测点数据
     */
    @Override
    public PitmonitSouthsmosData selectDevPitmonitSouthsmosDataById(Long id)
    {
        return pitmonitSouthsmosDataMapper.selectDevPitmonitSouthsmosDataById(id);
    }

    /**
     * 查询测点数据列表
     * 
     * @param pitmonitSouthsmosData 测点数据
     * @return 测点数据
     */
    @Override
    public List<PitmonitSouthsmosData> selectDevPitmonitSouthsmosDataList(PitmonitSouthsmosData pitmonitSouthsmosData)
    {
        return pitmonitSouthsmosDataMapper.selectDevPitmonitSouthsmosDataList(pitmonitSouthsmosData);
    }

    /**
     * 新增测点数据
     * 
     * @param pitmonitSouthsmosData 测点数据
     * @return 结果
     */
    @Override
    public int insertDevPitmonitSouthsmosData(PitmonitSouthsmosData pitmonitSouthsmosData)
    {
        pitmonitSouthsmosData.setCreateBy(SecurityUtils.getUsername());
        pitmonitSouthsmosData.setCreateTime(DateUtils.getNowDate());
        return pitmonitSouthsmosDataMapper.insertDevPitmonitSouthsmosData(pitmonitSouthsmosData);
    }

    /**
     * 修改测点数据
     * 
     * @param pitmonitSouthsmosData 测点数据
     * @return 结果
     */
    @Override
    public int updateDevPitmonitSouthsmosData(PitmonitSouthsmosData pitmonitSouthsmosData)
    {
        pitmonitSouthsmosData.setUpdateBy(SecurityUtils.getUsername());
        pitmonitSouthsmosData.setUpdateTime(DateUtils.getNowDate());
        return pitmonitSouthsmosDataMapper.updateDevPitmonitSouthsmosData(pitmonitSouthsmosData);
    }

    /**
     * 批量删除测点数据
     * 
     * @param ids 需要删除的测点数据主键
     * @return 结果
     */
    @Override
    public int deleteDevPitmonitSouthsmosDataByIds(Long[] ids)
    {
        return pitmonitSouthsmosDataMapper.deleteDevPitmonitSouthsmosDataByIds(ids);
    }

    /**
     * 删除测点数据信息
     * 
     * @param id 测点数据主键
     * @return 结果
     */
    @Override
    public int deleteDevPitmonitSouthsmosDataById(Long id)
    {
        return pitmonitSouthsmosDataMapper.deleteDevPitmonitSouthsmosDataById(id);
    }

    @Override
    public int getCountByPrjId(Long prjId) {
        return pitmonitSouthsmosDataMapper.getCountByPrjId(prjId);
    }

    /**
     * 获取项目中测点最后一条数据
     * @param id
     * @return
     */
    @Override
    public List<PitmonitSouthsmosData> getLastDataForElement(Long id) {
        return pitmonitSouthsmosDataMapper.getLastDataForElement(id);
    }
    /**
     * 按收集日期和数据类型查询数据
     * @param where
     * @return
     */
    @Override
    public List<PitmonitSouthsmosData> selectByDate(PitmonitSouthsmosData where) {
        return pitmonitSouthsmosDataMapper.selectByDate(where);
    }

    @Override
    public Long monitDays(Long id) {
        Date dt= pitmonitSouthsmosDataMapper.monitDays(id);
       return dt==null?0: DateUtil.between(new Date(),dt, DateUnit.DAY);
    }
}
