package com.yanzhu.jh.flow.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.annotation.RateLimiter;
import com.ruoyi.common.enums.LimitType;
import com.yanzhu.jh.flow.domain.FlowLabourInfo;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.flow.domain.FlowLabourAuditNode;
import com.yanzhu.jh.flow.service.IFlowLabourAuditNodeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 劳资投诉审批节点Controller
 * 
 * @author JiangYuQi
 * @date 2024-04-20
 */
@RestController
@RequestMapping("/flow/flowLabourAuditNode")
public class FlowLabourAuditNodeController extends BaseController
{
    @Autowired
    private IFlowLabourAuditNodeService flowLabourAuditNodeService;

    /**
     * 查询劳资投诉审批节点列表
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourAuditNode:list')")
    @GetMapping("/list")
    public TableDataInfo list(FlowLabourAuditNode flowLabourAuditNode)
    {
        startPage();
        List<FlowLabourAuditNode> list = flowLabourAuditNodeService.selectFlowLabourAuditNodeList(flowLabourAuditNode);
        return getDataTable(list);
    }

    /**
     * 导出劳资投诉审批节点列表
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourAuditNode:export')")
    @Log(title = "劳资投诉审批节点", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FlowLabourAuditNode flowLabourAuditNode)
    {
        List<FlowLabourAuditNode> list = flowLabourAuditNodeService.selectFlowLabourAuditNodeList(flowLabourAuditNode);
        ExcelUtil<FlowLabourAuditNode> util = new ExcelUtil<FlowLabourAuditNode>(FlowLabourAuditNode.class);
        util.exportExcel(response, list, "劳资投诉审批节点数据");
    }

    /**
     * 获取劳资投诉审批节点详细信息
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourAuditNode:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(flowLabourAuditNodeService.selectFlowLabourAuditNodeById(id));
    }

    /**
     * 新增劳资投诉审批节点
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourAuditNode:add')")
    @Log(title = "劳资投诉审批节点", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FlowLabourAuditNode flowLabourAuditNode)
    {
        return toAjax(flowLabourAuditNodeService.insertFlowLabourAuditNode(flowLabourAuditNode));
    }

    /**
     * 修改劳资投诉审批节点
     * flow:flowLabourInfo:edit
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourInfo:edit')")
    @Log(title = "劳资投诉审批", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FlowLabourAuditNode flowLabourAuditNode)
    {
        return toAjax(flowLabourAuditNodeService.updateFlowLabourAuditNode(flowLabourAuditNode));
    }

    /**
     * 删除劳资投诉审批节点
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourAuditNode:remove')")
    @Log(title = "劳资投诉审批节点", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(flowLabourAuditNodeService.deleteFlowLabourAuditNodeByIds(ids));
    }

    /**
     * 查询劳资投诉进度
     */
    @Anonymous
    @GetMapping("/findMyFlowLabourNodes/{flowId}")
    @RateLimiter(count = 10, limitType = LimitType.IP)
    public AjaxResult findMyFlowLabours(@PathVariable("flowId") Long flowId)
    {
        FlowLabourAuditNode flowLabourAuditNode = new FlowLabourAuditNode();
        flowLabourAuditNode.setFlowId(flowId);
        List<FlowLabourAuditNode> list = flowLabourAuditNodeService.selectFlowLabourAuditNodeList(flowLabourAuditNode);
        return success(list);
    }
}
