package com.yanzhu.jh.flow.controller;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.RateLimiter;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.LimitType;
import com.ruoyi.common.enums.SysRoleEnum;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.service.ISysDeptService;
import com.yanzhu.jh.flow.domain.FlowLabourInfo;
import com.yanzhu.jh.flow.service.IFlowLabourInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 劳资投诉Controller
 * 
 * @author JiangYuQi
 * @date 2024-04-19
 */
@RestController
@RequestMapping("/flow/flowLabourInfo")
public class FlowLabourInfoController extends BaseController
{
    @Autowired
    private ISysDeptService sysDeptService;

    @Autowired
    private IFlowLabourInfoService flowLabourInfoService;

    /**
     * 查询劳资投诉列表
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(FlowLabourInfo flowLabourInfo)
    {
        startPage();
        flowLabourInfo.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(flowLabourInfo.getNowRole())){
            flowLabourInfo.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            flowLabourInfo.setNowDept(Convert.toStr(getDeptId()));
        }
        flowLabourInfo.setNowUser(Convert.toStr(getUserId()));
        List<FlowLabourInfo> list = flowLabourInfoService.selectFlowLabourInfoListV2(flowLabourInfo);
        return getDataTable(list);
    }

    /**
     * 查询劳资投诉列表
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourInfo:list')")
    @GetMapping("/findGroupCountByApprove")
    public AjaxResult findGroupCountByApprove(FlowLabourInfo flowLabourInfo)
    {
        flowLabourInfo.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(flowLabourInfo.getNowRole())){
            flowLabourInfo.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            flowLabourInfo.setNowDept(Convert.toStr(getDeptId()));
        }
        flowLabourInfo.setNowUser(Convert.toStr(getUserId()));
        return success(flowLabourInfoService.findGroupCountByApprove(flowLabourInfo));
    }

    /**
     * 导出劳资投诉列表
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourInfo:export')")
    @Log(title = "劳资投诉", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FlowLabourInfo flowLabourInfo)
    {
        List<FlowLabourInfo> list = flowLabourInfoService.selectFlowLabourInfoList(flowLabourInfo);
        if(StringUtils.isNotEmpty(list)){
            for(FlowLabourInfo v:list){
                if(StringUtils.isNotEmpty(v.getFiles())){
                    String path = v.getFiles().split(",")[0];
                    v.setFiles(RuoYiConfig.getProjectUrl()+path);
                }
            }
        }
        ExcelUtil<FlowLabourInfo> util = new ExcelUtil<FlowLabourInfo>(FlowLabourInfo.class);
        util.exportExcel(response, list, "劳资投诉数据");
    }

    /**
     * 获取劳资投诉详细信息
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourInfo:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(flowLabourInfoService.selectFlowLabourInfoById(id));
    }

    /**
     * 新增劳资投诉
     */
    @Anonymous
    @PostMapping
    @RateLimiter(count = 10, limitType = LimitType.IP)
    public AjaxResult add(@RequestBody FlowLabourInfo flowLabourInfo)
    {
        return flowLabourInfoService.insertFlowLabourInfo(flowLabourInfo);
    }

    /**
     * 查询劳资投诉进度
     */
    @Anonymous
    @GetMapping("/findMyFlowLabours/{cardId}")
    @RateLimiter(count = 10, limitType = LimitType.IP)
    public AjaxResult findMyFlowLabours(@PathVariable("cardId") String cardId)
    {
        return success(flowLabourInfoService.selectFlowLabourInfoByCardId(cardId));
    }

    /**
     * 修改劳资投诉
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourInfo:edit')")
    @Log(title = "劳资投诉", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FlowLabourInfo flowLabourInfo)
    {
        return toAjax(flowLabourInfoService.updateFlowLabourInfo(flowLabourInfo));
    }

    /**
     * 删除劳资投诉
     */
    @PreAuthorize("@ss.hasPermi('flow:flowLabourInfo:remove')")
    @Log(title = "劳资投诉", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(flowLabourInfoService.deleteFlowLabourInfoByIds(ids));
    }

}
