package com.yanzhu.jh.flow.mapper;

import java.util.List;
import java.util.Map;

import com.yanzhu.jh.flow.domain.FlowLabourInfo;

/**
 * 劳资投诉Mapper接口
 * 
 * @author JiangYuQi
 * @date 2024-04-19
 */
public interface FlowLabourInfoMapper 
{
    /**
     * 查询劳资投诉
     * 
     * @param id 劳资投诉主键
     * @return 劳资投诉
     */
    public FlowLabourInfo selectFlowLabourInfoById(Long id);

    /**
     * 身份证查询劳资投诉列表
     *
     * @param cardId 身份证号
     * @return 劳资投诉
     */
    public List<FlowLabourInfo> selectFlowLabourInfoByCardId(String cardId);

    /**
     * 查询劳资投诉列表
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉集合
     */
    public List<FlowLabourInfo> selectFlowLabourInfoList(FlowLabourInfo flowLabourInfo);

    /**
     * 查询劳资投诉列表
     *
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉集合
     */
    public List<FlowLabourInfo> selectFlowLabourInfoListV2(FlowLabourInfo flowLabourInfo);

    /**
     * 统计劳资投诉信息
     *
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉集合
     */
    public List<Map<String, Object>> findGroupCountByApprove(FlowLabourInfo flowLabourInfo);

    /**
     * 统计劳资投诉信息
     *
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉集合
     */
    public List<Map<String, Object>> findGroupCountByApproveTask(FlowLabourInfo flowLabourInfo);

    /**
     * 新增劳资投诉
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 结果
     */
    public int insertFlowLabourInfo(FlowLabourInfo flowLabourInfo);

    /**
     * 修改劳资投诉
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 结果
     */
    public int updateFlowLabourInfo(FlowLabourInfo flowLabourInfo);

    /**
     * 删除劳资投诉
     * 
     * @param id 劳资投诉主键
     * @return 结果
     */
    public int deleteFlowLabourInfoById(Long id);

    /**
     * 批量删除劳资投诉
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFlowLabourInfoByIds(Long[] ids);
}
