package com.yanzhu.jh.flow.service.impl;

import java.util.List;
import java.util.Objects;

import com.ruoyi.common.utils.DateUtils;
import com.yanzhu.jh.flow.domain.FlowLabourInfo;
import com.yanzhu.jh.flow.mapper.FlowLabourInfoMapper;
import com.yanzhu.jh.wxsetting.service.impl.WeChatMessageServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.flow.mapper.FlowLabourAuditNodeMapper;
import com.yanzhu.jh.flow.domain.FlowLabourAuditNode;
import com.yanzhu.jh.flow.service.IFlowLabourAuditNodeService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 劳资投诉审批节点Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-04-20
 */
@Service
public class FlowLabourAuditNodeServiceImpl extends WeChatMessageServiceImpl implements IFlowLabourAuditNodeService
{
    @Autowired
    private FlowLabourInfoMapper flowLabourInfoMapper;

    @Autowired
    private FlowLabourAuditNodeMapper flowLabourAuditNodeMapper;

    /**
     * 查询劳资投诉审批节点
     * 
     * @param id 劳资投诉审批节点主键
     * @return 劳资投诉审批节点
     */
    @Override
    public FlowLabourAuditNode selectFlowLabourAuditNodeById(Long id)
    {
        return flowLabourAuditNodeMapper.selectFlowLabourAuditNodeById(id);
    }

    /**
     * 查询劳资投诉审批节点列表
     * 
     * @param flowLabourAuditNode 劳资投诉审批节点
     * @return 劳资投诉审批节点
     */
    @Override
    public List<FlowLabourAuditNode> selectFlowLabourAuditNodeList(FlowLabourAuditNode flowLabourAuditNode)
    {
        return flowLabourAuditNodeMapper.selectFlowLabourAuditNodeList(flowLabourAuditNode);
    }

    /**
     * 新增劳资投诉审批节点
     * 
     * @param flowLabourAuditNode 劳资投诉审批节点
     * @return 结果
     */
    @Override
    public int insertFlowLabourAuditNode(FlowLabourAuditNode flowLabourAuditNode)
    {
        flowLabourAuditNode.setCreateTime(DateUtils.getNowDate());
        return flowLabourAuditNodeMapper.insertFlowLabourAuditNode(flowLabourAuditNode);
    }

    /**
     * 修改劳资投诉审批节点
     * 
     * @param flowLabourAuditNode 劳资投诉审批节点
     * @return 结果
     */
    @Override
    public int updateFlowLabourAuditNode(FlowLabourAuditNode flowLabourAuditNode)
    {
        //查询节点
        FlowLabourInfo flowLabourInfo = flowLabourInfoMapper.selectFlowLabourInfoById(flowLabourAuditNode.getFlowId());
        if(Objects.equals(flowLabourInfo.getApproveStatus(),"100")){
            throw new RuntimeException("数据异常...请刷新重试");
        }
        String approveStatus = flowLabourInfo.getApproveStatus();
        String flowNode = flowLabourAuditNode.getFlowNode();
        //总包审批
        if(Objects.equals(flowLabourInfo.getApproveStatus(),"10") || Objects.equals(flowLabourInfo.getApproveStatus(),"21")){
            //通过||驳回
            if(Objects.equals(flowLabourAuditNode.getFlowResult(),"100")){
                approveStatus = "20";
                flowNode = "10";

            }else{
                approveStatus = "11";
                flowNode = "11";
            }
        }
        //甲代审批
        else if(Objects.equals(flowLabourInfo.getApproveStatus(),"20") || Objects.equals(flowLabourInfo.getApproveStatus(),"31")){
            //通过||驳回
            if(Objects.equals(flowLabourAuditNode.getFlowResult(),"100")){
                approveStatus = "30";
                flowNode = "20";
            }else{
                approveStatus = "21";
                flowNode = "21";
            }
        }
        //集团公司审核
        else if(Objects.equals(flowLabourInfo.getApproveStatus(),"30")){
            //通过||驳回
            if(Objects.equals(flowLabourAuditNode.getFlowResult(),"100")){
                approveStatus = "100";
                flowNode = "30";
            }else{
                approveStatus = "31";
                flowNode = "31";
            }
        }
        flowLabourInfo.setApproveStatus(approveStatus);
        flowLabourAuditNode.setFlowNode(flowNode);
        flowLabourInfo.setUpdateBy(SecurityUtils.getUsername());
        flowLabourInfo.setUpdateTime(DateUtils.getNowDate());
        int res = flowLabourInfoMapper.updateFlowLabourInfo(flowLabourInfo);
        if(res>0){
            flowLabourAuditNode.setCreateBy(SecurityUtils.getLoginUser().getUser().getNickName());
            flowLabourAuditNode.setCreateTime(DateUtils.getNowDate());
            flowLabourAuditNode.setUpdateBy(SecurityUtils.getUsername());
            flowLabourAuditNode.setUpdateTime(DateUtils.getNowDate());
            flowLabourAuditNodeMapper.insertFlowLabourAuditNode(flowLabourAuditNode);

            //super.send(flowLabourInfo);
        }
        return res;
    }

    /**
     * 批量删除劳资投诉审批节点
     * 
     * @param ids 需要删除的劳资投诉审批节点主键
     * @return 结果
     */
    @Override
    public int deleteFlowLabourAuditNodeByIds(Long[] ids)
    {
        return flowLabourAuditNodeMapper.deleteFlowLabourAuditNodeByIds(ids);
    }

    /**
     * 删除劳资投诉审批节点信息
     * 
     * @param id 劳资投诉审批节点主键
     * @return 结果
     */
    @Override
    public int deleteFlowLabourAuditNodeById(Long id)
    {
        return flowLabourAuditNodeMapper.deleteFlowLabourAuditNodeById(id);
    }
}
