package com.yanzhu.jh.flow.service.impl;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.yanzhu.jh.flow.domain.FlowLabourAuditNode;
import com.yanzhu.jh.flow.mapper.FlowLabourAuditNodeMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.flow.mapper.FlowLabourInfoMapper;
import com.yanzhu.jh.flow.domain.FlowLabourInfo;
import com.yanzhu.jh.flow.service.IFlowLabourInfoService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 劳资投诉Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2024-04-19
 */
@Service
public class FlowLabourInfoServiceImpl implements IFlowLabourInfoService 
{
    @Autowired
    private FlowLabourInfoMapper flowLabourInfoMapper;

    @Autowired
    private FlowLabourAuditNodeMapper flowLabourAuditNodeMapper;

    /**
     * 查询劳资投诉
     * 
     * @param id 劳资投诉主键
     * @return 劳资投诉
     */
    @Override
    public FlowLabourInfo selectFlowLabourInfoById(Long id)
    {
        return flowLabourInfoMapper.selectFlowLabourInfoById(id);
    }

    /**
     * 身份证查询劳资投诉列表
     *
     * @param cardId 身份证号
     * @return 劳资投诉
     */
    @Override
    public List<FlowLabourInfo> selectFlowLabourInfoByCardId(String cardId)
    {
        return flowLabourInfoMapper.selectFlowLabourInfoByCardId(cardId);
    }

    /**
     * 查询劳资投诉列表
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉
     */
    @Override
    public List<FlowLabourInfo> selectFlowLabourInfoList(FlowLabourInfo flowLabourInfo)
    {
        if(Convert.toInt(flowLabourInfo.getNowRole(),1)>4){
            //这里总包只能审批自己单位数据
            flowLabourInfo.setDeptId(Convert.toLong(flowLabourInfo.getNowDept()));
        }
        return flowLabourInfoMapper.selectFlowLabourInfoList(flowLabourInfo);
    }

    /**
     * 查询劳资投诉列表
     *
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉集合
     */
    public List<FlowLabourInfo> selectFlowLabourInfoListV2(FlowLabourInfo flowLabourInfo){
        if(Convert.toInt(flowLabourInfo.getNowRole(),1)>4){
            //这里总包只能审批自己单位数据
            flowLabourInfo.setDeptId(Convert.toLong(flowLabourInfo.getNowDept()));
        }
        return flowLabourInfoMapper.selectFlowLabourInfoListV2(flowLabourInfo);
    }

    /**
     * 统计劳资投诉信息
     *
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉集合
     */
    @Override
    public Map<String, Object> findGroupCountByApprove(FlowLabourInfo flowLabourInfo){
        if(Convert.toInt(flowLabourInfo.getNowRole())>4){
            //这里总包只能审批自己单位数据
            flowLabourInfo.setDeptId(Convert.toLong(flowLabourInfo.getNowDept()));
        }
        List<Map<String, Object>> list = flowLabourInfoMapper.findGroupCountByApprove(flowLabourInfo);
        int db=0,yb=0;
        if(StringUtils.isNotEmpty(list)){
            if(flowLabourInfo.getNowRole().equals("4")){
                for(Map<String, Object> map:list){
                    if(map.get("approveStatus").equals("20") || map.get("approveStatus").equals("31")){
                        db+= Convert.toInt(map.get("total"));
                    }else{
                        yb+= Convert.toInt(map.get("total"));
                    }
                }
            }else if(flowLabourInfo.getNowRole().equals("5") || flowLabourInfo.getNowRole().equals("6") || flowLabourInfo.getNowRole().equals("7")){
                for(Map<String, Object> map:list){
                    if(map.get("approveStatus").equals("10") || map.get("approveStatus").equals("21")){
                        db+= Convert.toInt(map.get("total"));
                    }else{
                        yb+= Convert.toInt(map.get("total"));
                    }
                }
            }else if(flowLabourInfo.getNowRole().equals("15") || flowLabourInfo.getNowRole().equals("16") || flowLabourInfo.getNowRole().equals("17")){
                for(Map<String, Object> map:list){
                    if(map.get("approveStatus").equals("10") || map.get("approveStatus").equals("21")){
                        db+= Convert.toInt(map.get("total"));
                    }else{
                        yb+= Convert.toInt(map.get("total"));
                    }
                }
            }else if(flowLabourInfo.getNowRole().equals("1") || flowLabourInfo.getNowRole().equals("2") || flowLabourInfo.getNowRole().equals("3")){
                for(Map<String, Object> map:list){
                    if(map.get("approveStatus").equals("100")){
                        yb+= Convert.toInt(map.get("total"));
                    }else{
                        db+= Convert.toInt(map.get("total"));
                    }
                }
            }
        }
        Map<String, Object> data = new HashMap<>();
        data.put("db",db);
        data.put("yb",yb);
        data.put("all",db+yb);
        return data;
    }

    /**
     * 统计劳资投诉信息
     *
     * @param flowLabourInfo 劳资投诉
     * @return 劳资投诉集合
     */
    @Override
    public Map<String, Object> findFlowLabourGroupCountByApprove(FlowLabourInfo flowLabourInfo){
        List<Map<String, Object>> list = flowLabourInfoMapper.findGroupCountByApprove(flowLabourInfo);
        int db=0,yb=0;
        for(Map<String, Object> map:list){
            if(map.get("approveStatus").equals("100")){
                yb += Convert.toInt(map.get("total"));
            }else{
                db += Convert.toInt(map.get("total"));
            }
        }
        Map<String, Object> data = new HashMap<>();
        data.put("db",db);
        data.put("yb",yb);
        data.put("all",db+yb);
        return data;
    }

    /**
     * 新增劳资投诉
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 结果
     */
    @Override
    public AjaxResult insertFlowLabourInfo(FlowLabourInfo flowLabourInfo)
    {
        //查询是否已有投诉中的问题
        FlowLabourInfo searchModel = new FlowLabourInfo();
        searchModel.setLaborCardId(flowLabourInfo.getLaborCardId());
        searchModel.setActiveName("MyAwait");
        List<FlowLabourInfo> list = flowLabourInfoMapper.selectFlowLabourInfoList(searchModel);
        if(StringUtils.isNotEmpty(list)){
            flowLabourInfo.setId(0L);
            return AjaxResult.success(flowLabourInfo);
        }else{
            try {
                flowLabourInfo.setApproveStatus("10");
                flowLabourInfo.setCreateBy(flowLabourInfo.getLaborName());
                flowLabourInfo.setCreateTime(DateUtils.getNowDate());
                flowLabourInfoMapper.insertFlowLabourInfo(flowLabourInfo);
                //保存流程节点信息
                FlowLabourAuditNode flowLabourAuditNode = new FlowLabourAuditNode();
                flowLabourAuditNode.setFlowId(flowLabourInfo.getId());
                flowLabourAuditNode.setFlowNode("0");
                flowLabourAuditNode.setCreateBy(flowLabourInfo.getLaborName());
                flowLabourAuditNode.setCreateTime(new Date());
                flowLabourAuditNodeMapper.insertFlowLabourAuditNode(flowLabourAuditNode);
                return AjaxResult.success(flowLabourInfo);
            }catch (Exception e){
                throw new RuntimeException("输入字符中包含系统未识别的乱码！");
            }
        }
    }

    /**
     * 修改劳资投诉
     * 
     * @param flowLabourInfo 劳资投诉
     * @return 结果
     */
    @Override
    public int updateFlowLabourInfo(FlowLabourInfo flowLabourInfo)
    {
        flowLabourInfo.setUpdateBy(SecurityUtils.getUsername());
        flowLabourInfo.setUpdateTime(DateUtils.getNowDate());
        return flowLabourInfoMapper.updateFlowLabourInfo(flowLabourInfo);
    }

    /**
     * 批量删除劳资投诉
     * 
     * @param ids 需要删除的劳资投诉主键
     * @return 结果
     */
    @Override
    public int deleteFlowLabourInfoByIds(Long[] ids)
    {
        return flowLabourInfoMapper.deleteFlowLabourInfoByIds(ids);
    }

    /**
     * 删除劳资投诉信息
     * 
     * @param id 劳资投诉主键
     * @return 结果
     */
    @Override
    public int deleteFlowLabourInfoById(Long id)
    {
        return flowLabourInfoMapper.deleteFlowLabourInfoById(id);
    }
}
