package com.yanzhu.jh.project.controller;

import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;
import javax.servlet.http.HttpServletResponse;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.utils.DateUtils;
import com.yanzhu.jh.project.domain.SurProjectAttendanceData;
import com.yanzhu.jh.project.service.ISurProjectAttendanceDataService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.project.domain.SurProjectAttendanceUnitpay;
import com.yanzhu.jh.project.service.ISurProjectAttendanceUnitpayService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 劳资管理Controller
 * 
 * @author ruoyi
 * @date 2024-11-10
 */
@RestController
@RequestMapping("/project/unitpay")
public class SurProjectAttendanceUnitpayController extends BaseController
{
    @Autowired
    private ISurProjectAttendanceUnitpayService surProjectAttendanceUnitpayService;
    @Autowired
    private ISurProjectAttendanceDataService surProjectAttendanceDataService;
    /**
     * 查询劳资管理列表
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:list')")
    @GetMapping("/list")
    public AjaxResult list(SurProjectAttendanceUnitpay surProjectAttendanceUnitpay)
    {
        List<SurProjectAttendanceUnitpay> list = surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(surProjectAttendanceUnitpay);
        List<SurProjectAttendanceUnitpay>  iniList=surProjectAttendanceUnitpayService.initList(surProjectAttendanceUnitpay);
        for(SurProjectAttendanceUnitpay it :iniList){
            List<SurProjectAttendanceUnitpay> tmpList=  list.stream().filter(item->StrUtil.equals(it.getWorkTypeName(),item.getWorkTypeName()) && StrUtil.equals(it.getGroupName(),item.getGroupName())).collect(Collectors.toList());
           if(tmpList.isEmpty()){
               it.setUnitPay(0l);
               list.add(it);
           }
        }
        return success(list);
    }
    /**
     * 查询劳资管理列表
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:list')")
    @GetMapping("/listByDay")
    public TableDataInfo listByDay(SurProjectAttendanceData attWhere)
    {
        attWhere.setAttendanceOutTime(attWhere.getAttendanceOutTime());
        startPage();
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataListByDate(attWhere);
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        payWhere.setCfgId(attWhere.getCfgid());
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        for(SurProjectAttendanceData it :list){
            it.setDays(1l);
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
        }

        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('project:unitpay:list')")
    @GetMapping("/listByMonth")
    public TableDataInfo listByMonth(SurProjectAttendanceData attWhere)
    {
        Date dt=DateUtil.parse(attWhere.getAttendanceTime());
        attWhere.setAttendanceTime( DateUtil.formatDate(DateUtil.beginOfMonth(dt)) );
        attWhere.setAttendanceOutTime( DateUtil.formatDate(DateUtil.endOfMonth(dt)));
        startPage();
        String tmp=attWhere.getAttendanceTime();
        if(StrUtil.isNotEmpty(tmp)){
            int year= DateUtil.parse(tmp).year();
            attWhere.setYear(year);
        }
        List<SurProjectAttendanceData> list = surProjectAttendanceDataService.selectSurProjectAttendanceDataListByMonth(attWhere);
        SurProjectAttendanceUnitpay payWhere=new SurProjectAttendanceUnitpay();
        payWhere.setCfgId(attWhere.getCfgid());
        List<SurProjectAttendanceUnitpay> payList= surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(payWhere);
        for(SurProjectAttendanceData it :list){
            it.setPay(surProjectAttendanceUnitpayService.getPay(payList,it));
        }

        return getDataTable(list);
    }

    /**
     * 导出劳资管理列表
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:export')")
    @Log(title = "劳资管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SurProjectAttendanceUnitpay surProjectAttendanceUnitpay)
    {
        List<SurProjectAttendanceUnitpay> list = surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayList(surProjectAttendanceUnitpay);
        ExcelUtil<SurProjectAttendanceUnitpay> util = new ExcelUtil<SurProjectAttendanceUnitpay>(SurProjectAttendanceUnitpay.class);
        util.exportExcel(response, list, "劳资管理数据");
    }

    /**
     * 获取劳资管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:query')")
    @GetMapping(value = "/one/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectAttendanceUnitpayService.selectSurProjectAttendanceUnitpayById(id));
    }

    /**
     * 新增劳资管理
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:add')")
    @Log(title = "劳资管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody List<SurProjectAttendanceUnitpay> datas)
    {
        return toAjax(surProjectAttendanceUnitpayService.addSurProjectAttendanceUnitpaies(datas));
    }

    /**
     * 修改劳资管理
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:edit')")
    @Log(title = "劳资管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurProjectAttendanceUnitpay surProjectAttendanceUnitpay)
    {
        return toAjax(surProjectAttendanceUnitpayService.updateSurProjectAttendanceUnitpay(surProjectAttendanceUnitpay));
    }

    /**
     * 删除劳资管理
     */
    @PreAuthorize("@ss.hasPermi('project:unitpay:remove')")
    @Log(title = "劳资管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectAttendanceUnitpayService.deleteSurProjectAttendanceUnitpayByIds(ids));
    }
}
