package com.yanzhu.jh.project.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.enums.SysRoleEnum;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.service.ISysDeptService;
import com.yanzhu.jh.project.domain.SurProjectFunVerify;
import com.yanzhu.jh.project.service.ISurProjectFunVerifyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 工程功能检验Controller
 * 
 * @author JiangYuQi
 * @date 2023-08-18
 */
@RestController
@RequestMapping("/project/projectFunVerify")
public class SurProjectFunVerifyController extends BaseController
{
    @Autowired
    private ISurProjectFunVerifyService surProjectFunVerifyService;

    @Autowired
    private ISysDeptService sysDeptService;

    /**
     * 查询工程功能检验列表
     */
    @PreAuthorize("@ss.hasPermi('project:projectFunVerify:list')")
    @GetMapping("/list")
    public TableDataInfo list(SurProjectFunVerify surProjectFunVerify)
    {
        startPage();
        surProjectFunVerify.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(surProjectFunVerify.getNowRole())){
            surProjectFunVerify.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            surProjectFunVerify.setNowDept(Convert.toStr(getDeptId()));
        }
        surProjectFunVerify.setNowUser(Convert.toStr(getUserId()));
        surProjectFunVerify.setNowUserName(getUsername());
        List<SurProjectFunVerify> list = surProjectFunVerifyService.selectSurProjectFunVerifyList(surProjectFunVerify);
        return getDataTable(list);
    }

    /**
     * 统计工程功能检验
     */
    @PreAuthorize("@ss.hasPermi('project:projectFunVerify:list')")
    @GetMapping("/findGroupCountByApprove")
    public AjaxResult findGroupCountByApprove(SurProjectFunVerify surProjectFunVerify)
    {
        surProjectFunVerify.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(surProjectFunVerify.getNowRole())){
            surProjectFunVerify.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            surProjectFunVerify.setNowDept(Convert.toStr(getDeptId()));
        }
        surProjectFunVerify.setNowUser(Convert.toStr(getUserId()));
        surProjectFunVerify.setNowUserName(getUsername());
        return success(surProjectFunVerifyService.findGroupCountByApprove(surProjectFunVerify));
    }

    /**
     * 导出工程功能检验列表
     */
    @PreAuthorize("@ss.hasPermi('project:projectFunVerify:export')")
    @Log(title = "工程功能检验", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SurProjectFunVerify surProjectFunVerify)
    {
        surProjectFunVerify.setNowRole(Convert.toStr(getUserFirstRole()));
        if(SysRoleEnum.ZGS.getCode().equals(surProjectFunVerify.getNowRole())){
            surProjectFunVerify.setNowDept(Convert.toStr(sysDeptService.getZGSDeptId(getDeptId())));
        }else{
            surProjectFunVerify.setNowDept(Convert.toStr(getDeptId()));
        }
        surProjectFunVerify.setNowUser(Convert.toStr(getUserId()));
        surProjectFunVerify.setNowUserName(getUsername());
        List<SurProjectFunVerify> list = surProjectFunVerifyService.selectSurProjectFunVerifyList(surProjectFunVerify);
        ExcelUtil<SurProjectFunVerify> util = new ExcelUtil<SurProjectFunVerify>(SurProjectFunVerify.class);
        util.exportExcel(response, list, "工程功能检验数据");
    }

    /**
     * 获取工程功能检验详细信息
     */
    @PreAuthorize("@ss.hasPermi('project:projectFunVerify:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(surProjectFunVerifyService.selectSurProjectFunVerifyById(id));
    }

    /**
     * 新增工程功能检验
     */
    @PreAuthorize("@ss.hasPermi('project:projectFunVerify:add')")
    @Log(title = "工程功能检验", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SurProjectFunVerify surProjectFunVerify)
    {
        surProjectFunVerify.setCreateBy(getUsername());
        return toAjax(surProjectFunVerifyService.insertSurProjectFunVerify(surProjectFunVerify));
    }

    /**
     * 修改工程功能检验
     */
    @PreAuthorize("@ss.hasPermi('project:projectFunVerify:edit')")
    @Log(title = "工程功能检验", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SurProjectFunVerify surProjectFunVerify)
    {
        return toAjax(surProjectFunVerifyService.updateSurProjectFunVerify(surProjectFunVerify));
    }

    /**
     * 修改工程功能检验
     */
    @PreAuthorize("@ss.hasPermi('project:projectFunVerify:edit')")
    @Log(title = "工程功能检验", businessType = BusinessType.UPDATE)
    @PostMapping("/editNoLog")
    public AjaxResult editNoLog(@RequestBody SurProjectFunVerify surProjectFunVerify)
    {
        return toAjax(surProjectFunVerifyService.updateSurProjectFunVerifyNoLog(surProjectFunVerify));
    }

    /**
     * 删除工程功能检验
     */
    @PreAuthorize("@ss.hasPermi('project:projectFunVerify:remove')")
    @Log(title = "工程功能检验", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(surProjectFunVerifyService.deleteSurProjectFunVerifyByIds(ids));
    }

    @GetMapping("/groupByCheckType")
    public AjaxResult groupByCheckType(String deptId, String projectId){
        SurProjectFunVerify where=new SurProjectFunVerify();
        if(deptId!=null && !"0".equals(deptId)){
            where.setProjectDeptId(deptId);
        }else{
            if (SecurityUtils.isUserB()) {
                where.setPrjIds(getProjectIds());
            }
        }
        if(projectId!=null && !"0".equals(projectId)){
            where.setProjectId(Convert.toLong(projectId));
        }
        return  AjaxResult.success(surProjectFunVerifyService.groupByCheckType(where));
    }
}
