package com.yanzhu.jh.project.service.impl;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.utils.DateUtils;
import com.yanzhu.jh.project.domain.SurProjectAttendanceData;
import com.yanzhu.jh.project.mapper.SurProjectAttendanceDataMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.project.mapper.SurProjectAttendanceUnitpayMapper;
import com.yanzhu.jh.project.domain.SurProjectAttendanceUnitpay;
import com.yanzhu.jh.project.service.ISurProjectAttendanceUnitpayService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 劳资管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-11-10
 */
@Service
public class SurProjectAttendanceUnitpayServiceImpl implements ISurProjectAttendanceUnitpayService 
{
    @Autowired
    private SurProjectAttendanceUnitpayMapper surProjectAttendanceUnitpayMapper;


    /**
     * 查询劳资管理
     * 
     * @param id 劳资管理主键
     * @return 劳资管理
     */
    @Override
    public SurProjectAttendanceUnitpay selectSurProjectAttendanceUnitpayById(Long id)
    {
        return surProjectAttendanceUnitpayMapper.selectSurProjectAttendanceUnitpayById(id);
    }

    /**
     * 查询劳资管理列表
     * 
     * @param surProjectAttendanceUnitpay 劳资管理
     * @return 劳资管理
     */
    @Override
    public List<SurProjectAttendanceUnitpay> selectSurProjectAttendanceUnitpayList(SurProjectAttendanceUnitpay surProjectAttendanceUnitpay)
    {
        return surProjectAttendanceUnitpayMapper.selectSurProjectAttendanceUnitpayList(surProjectAttendanceUnitpay);
    }

    /**
     * 新增劳资管理
     * 
     * @param surProjectAttendanceUnitpay 劳资管理
     * @return 结果
     */
    @Override
    public int insertSurProjectAttendanceUnitpay(SurProjectAttendanceUnitpay surProjectAttendanceUnitpay)
    {
        surProjectAttendanceUnitpay.setCreateBy(SecurityUtils.getUsername());
        surProjectAttendanceUnitpay.setCreateTime(DateUtils.getNowDate());
        return surProjectAttendanceUnitpayMapper.insertSurProjectAttendanceUnitpay(surProjectAttendanceUnitpay);
    }

    /**
     * 修改劳资管理
     * 
     * @param surProjectAttendanceUnitpay 劳资管理
     * @return 结果
     */
    @Override
    public int updateSurProjectAttendanceUnitpay(SurProjectAttendanceUnitpay surProjectAttendanceUnitpay)
    {
        surProjectAttendanceUnitpay.setUpdateBy(SecurityUtils.getUsername());
        surProjectAttendanceUnitpay.setUpdateTime(DateUtils.getNowDate());
        return surProjectAttendanceUnitpayMapper.updateSurProjectAttendanceUnitpay(surProjectAttendanceUnitpay);
    }

    /**
     * 批量删除劳资管理
     * 
     * @param ids 需要删除的劳资管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceUnitpayByIds(Long[] ids)
    {
        return surProjectAttendanceUnitpayMapper.deleteSurProjectAttendanceUnitpayByIds(ids);
    }

    /**
     * 删除劳资管理信息
     * 
     * @param id 劳资管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectAttendanceUnitpayById(Long id)
    {
        return surProjectAttendanceUnitpayMapper.deleteSurProjectAttendanceUnitpayById(id);
    }

    @Override
    public Long getPay(List<SurProjectAttendanceUnitpay> payList, SurProjectAttendanceData it) {
        for(SurProjectAttendanceUnitpay pay : payList){
            if(StrUtil.equals(pay.getGroupName(),it.getGroupName()) && StrUtil.equals(pay.getWorkTypeName(),it.getWorkTypeName())){
                it.setUnitPay(pay.getUnitPay());
                return  it.getDays()*pay.getUnitPay();
            }
        }
        return 0l;
    }

    @Override
    public List<SurProjectAttendanceUnitpay> initList(SurProjectAttendanceUnitpay surProjectAttendanceUnitpay) {
        int year= DateUtil.parse(DateUtil.now()).year();
        surProjectAttendanceUnitpay.setYear(year);
        return surProjectAttendanceUnitpayMapper.initList(surProjectAttendanceUnitpay);
    }

    @Override
    public int addSurProjectAttendanceUnitpaies(List<SurProjectAttendanceUnitpay> datas) {
        if(datas.size()==0){
            return 0;
        }
        Long cfgId= datas.get(0).getCfgId();
        SurProjectAttendanceUnitpay where=new SurProjectAttendanceUnitpay();
        where.setCfgId(cfgId);
        List<SurProjectAttendanceUnitpay> olds=surProjectAttendanceUnitpayMapper.selectSurProjectAttendanceUnitpayList(where);
        List<Long> addIds=new ArrayList<>();
        for(SurProjectAttendanceUnitpay it : datas){
            if(it.getId()!=null){
                surProjectAttendanceUnitpayMapper.updateSurProjectAttendanceUnitpay(it);
                addIds.add(it.getId());
            }else{
                surProjectAttendanceUnitpayMapper.insertSurProjectAttendanceUnitpay(it);
            }
        }
        for(SurProjectAttendanceUnitpay it : olds){
            if(!addIds.contains(it.getId())){
                surProjectAttendanceUnitpayMapper.deleteSurProjectAttendanceUnitpayById(it.getId());
            }
        }
        return datas.size();
    }
}
