package com.yanzhu.jh.project.service.impl;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.PublicStateEnum;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.yanzhu.jh.project.domain.SurProjectAuditinfo;
import com.yanzhu.jh.project.domain.SurProjectFunVerify;
import com.yanzhu.jh.project.mapper.SurProjectAuditinfoMapper;
import com.yanzhu.jh.project.mapper.SurProjectFunVerifyMapper;
import com.yanzhu.jh.project.service.ISurProjectFunVerifyService;
import com.yanzhu.jh.wxsetting.service.impl.WeChatMessageServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 工程功能检验Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2023-08-18
 */
@Service
public class SurProjectFunVerifyServiceImpl extends WeChatMessageServiceImpl implements ISurProjectFunVerifyService
{
    @Autowired
    private SurProjectAuditinfoMapper surProjectAuditinfoMapper;

    @Autowired
    private SurProjectFunVerifyMapper surProjectFunVerifyMapper;

    /**
     * 查询工程功能检验
     * 
     * @param id 工程功能检验主键
     * @return 工程功能检验
     */
    @Override
    public SurProjectFunVerify selectSurProjectFunVerifyById(Long id)
    {
        return surProjectFunVerifyMapper.selectSurProjectFunVerifyById(id);
    }

    /**
     * 查询工程功能检验列表
     * 
     * @param surProjectFunVerify 工程功能检验
     * @return 工程功能检验
     */
    @Override
    public List<SurProjectFunVerify> selectSurProjectFunVerifyList(SurProjectFunVerify surProjectFunVerify)
    {
        return surProjectFunVerifyMapper.selectSurProjectFunVerifyList(surProjectFunVerify);
    }

    /**
     * 统计工程功能检验
     *
     * @param surProjectFunVerify 工程功能检验
     * @return 工程功能检验集合
     */
    @Override
    public Map<String,Object> findGroupCountByApprove(SurProjectFunVerify surProjectFunVerify) {
        Map<String,Object> dataMap = new HashMap<>();
        surProjectFunVerify.setActiveName("jxz");
        List<SurProjectFunVerify> awaitList = surProjectFunVerifyMapper.selectSurProjectFunVerifyList(surProjectFunVerify);
        if(awaitList!=null){
            dataMap.put("jxz",awaitList.size());
        }else{
            dataMap.put("jxz",0);
        }
        surProjectFunVerify.setActiveName("ywc");
        List<SurProjectFunVerify> finishedList = surProjectFunVerifyMapper.selectSurProjectFunVerifyList(surProjectFunVerify);
        if(finishedList!=null){
            dataMap.put("ywc",finishedList.size());
        }else{
            dataMap.put("ywc",0);
        }
        return dataMap;
    }

    /**
     * 新增工程功能检验
     * 
     * @param surProjectFunVerify 工程功能检验
     * @return 结果
     */
    @Override
    @Transactional
    public int insertSurProjectFunVerify(SurProjectFunVerify surProjectFunVerify)
    {
        //默认第一张图是主图
        surProjectFunVerify.setMainImage(surProjectFunVerify.getImageUrls().split(",")[0]);
        surProjectFunVerify.setIsDel(Convert.toLong(PublicStateEnum.OK.getCode()));
        surProjectFunVerify.setCreateTime(DateUtils.getNowDate());

        int res = surProjectFunVerifyMapper.insertSurProjectFunVerify(surProjectFunVerify);
        //操作日志
        if(StringUtils.isNotBlank(surProjectFunVerify.getApproveStatus())){
            SurProjectAuditinfo surProjectAuditinfo = new SurProjectAuditinfo();
            surProjectAuditinfo.setFromType(PublicStateEnum.AUDIT_TYPE_GCGNJY.getCode());
            surProjectAuditinfo.setFromId(surProjectFunVerify.getId());
            surProjectAuditinfo.setApproveStatus(surProjectFunVerify.getApproveStatus());
            if(StringUtils.isNotBlank(surProjectFunVerify.getComment())){
                surProjectAuditinfo.setComment(surProjectFunVerify.getComment());
            }
            surProjectAuditinfo.setCreateBy(surProjectFunVerify.getCreateBy());
            surProjectAuditinfo.setCreateTime(new Date());
            surProjectAuditinfoMapper.insertSurProjectAuditinfo(surProjectAuditinfo);
        }

        if(res>0){
            super.send(surProjectFunVerify);
        }
        return res;
    }

    /**
     * 修改工程功能检验
     * 
     * @param surProjectFunVerify 工程功能检验
     * @return 结果
     */
    @Override
    @Transactional
    public int updateSurProjectFunVerify(SurProjectFunVerify surProjectFunVerify)
    {
        if(surProjectFunVerify.getImageUrls()!=null){
            surProjectFunVerify.setMainImage(surProjectFunVerify.getImageUrls().split(",")[0]);
        }
        if(surProjectFunVerify.getUpdateBy()==null){
            surProjectFunVerify.setUpdateBy(SecurityUtils.getUsername());
        }
        surProjectFunVerify.setUpdateTime(DateUtils.getNowDate());
        int res = surProjectFunVerifyMapper.updateSurProjectFunVerify(surProjectFunVerify);

        //操作日志
        if(StringUtils.isNotBlank(surProjectFunVerify.getApproveStatus())){
            SurProjectAuditinfo surProjectAuditinfo = new SurProjectAuditinfo();
            surProjectAuditinfo.setFromType(PublicStateEnum.AUDIT_TYPE_GCGNJY.getCode());
            surProjectAuditinfo.setFromId(surProjectFunVerify.getId());
            surProjectAuditinfo.setApproveStatus(surProjectFunVerify.getApproveStatus());
            if(StringUtils.isNotBlank(surProjectFunVerify.getComment())){
                surProjectAuditinfo.setComment(surProjectFunVerify.getComment());
            }
            surProjectAuditinfo.setCreateBy(surProjectFunVerify.getUpdateBy());
            surProjectAuditinfo.setCreateTime(new Date());
            surProjectAuditinfoMapper.insertSurProjectAuditinfo(surProjectAuditinfo);

            //推送代办消息
            if(res>0){
                surProjectFunVerify = surProjectFunVerifyMapper.selectSurProjectFunVerifyById(surProjectFunVerify.getId());
                super.send(surProjectFunVerify);
            }
        }

        return res;
    }

    /**
     * 修改工程功能检验
     *
     * @param surProjectFunVerify 工程功能检验
     * @return 结果
     */
    @Override
    @Transactional
    public int updateSurProjectFunVerifyNoLog(SurProjectFunVerify surProjectFunVerify)
    {
        return surProjectFunVerifyMapper.updateSurProjectFunVerify(surProjectFunVerify);
    }

    /**
     * 批量删除工程功能检验
     * 
     * @param ids 需要删除的工程功能检验主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectFunVerifyByIds(Long[] ids)
    {
        return surProjectFunVerifyMapper.deleteSurProjectFunVerifyByIds(ids);
    }

    /**
     * 删除工程功能检验信息
     * 
     * @param id 工程功能检验主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectFunVerifyById(Long id)
    {
        return surProjectFunVerifyMapper.deleteSurProjectFunVerifyById(id);
    }

    @Override
    public List<SurProjectFunVerify> groupByCheckType(SurProjectFunVerify where) {
        return surProjectFunVerifyMapper.groupByCheckType(where);
    }
}
