package com.yanzhu.jh.project.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.project.mapper.SurProjectMapper;
import com.yanzhu.jh.project.domain.SurProject;
import com.yanzhu.jh.project.service.ISurProjectService;

/**
 * 项目管理Service业务层处理
 * 
 * @author JiangYuQi
 * @date 2023-07-29
 */
@Service
public class SurProjectServiceImpl implements ISurProjectService 
{
    @Autowired
    private SurProjectMapper surProjectMapper;

    /**
     * 查询项目管理
     * 
     * @param id 项目管理主键
     * @return 项目管理
     */
    @Override
    public SurProject selectSurProjectById(Long id)
    {
        return surProjectMapper.selectSurProjectById(id);
    }

    /**
     * 查询项目管理列表
     * 
     * @param surProject 项目管理
     * @return 项目管理
     */
    @Override
    public List<SurProject> selectSurProjectList(SurProject surProject)
    {
        return surProjectMapper.selectSurProjectList(surProject);
    }

    /**
     * 查询项目管理列表
     *
     * @return 项目管理集合
     */
    @Override
    public List<SurProject> selectAllProjectList() {
        return surProjectMapper.selectAllProjectList();
    }

    /**
     * 新增项目管理
     * 
     * @param surProject 项目管理
     * @return 结果
     */
    @Override
    public int insertSurProject(SurProject surProject)
    {
        surProject.setCreateTime(DateUtils.getNowDate());
        surProject.setIsDel(0l);
        return surProjectMapper.insertSurProject(surProject);
    }

    /**
     * 修改项目管理
     * 
     * @param surProject 项目管理
     * @return 结果
     */
    @Override
    public int updateSurProject(SurProject surProject)
    {
        surProject.setUpdateTime(DateUtils.getNowDate());
        surProject.setUpdateBy(SecurityUtils.getUsername());
        return surProjectMapper.updateSurProject(surProject);
    }

    /**
     * 批量删除项目管理
     * 
     * @param ids 需要删除的项目管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectByIds(Long[] ids)
    {
        return surProjectMapper.deleteSurProjectByIds(ids);
    }

    /**
     * 删除项目管理信息
     * 
     * @param id 项目管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectById(Long id)
    {
        return surProjectMapper.deleteSurProjectById(id);
    }

    @Override
    public List<SurProject> selectProgressProjects(SurProject surProject) {
        return surProjectMapper.selectProgressProjects(surProject);
    }

    @Override
    public List<SurProject> groupByProjectCategory(SurProject surProject) {
        return surProjectMapper.groupByProjectCategory(surProject);
    }

    @Override
    public List<SurProject> groupByCategory(SurProject surProject) {
        return surProjectMapper.groupByCategory(surProject);
    }

    @Override
    public List<SurProject> groupByLevel(SurProject surProject) {
        return surProjectMapper.groupByLevel(surProject);
    }

    /**
     * 监理单位、总包单位、分包单位用户不展示项目概况菜单,二级菜单只展示自已参与的项目
     * roleId（15，16，17，99）(select spu.project_id from sur_project_userinfo spu where spu.user_id = #{id} and spu.is_del=0) id-->userId
     * roleId（5，6，7） select spui.projectId from sur_project_unit_info spui where spui.unitId = #{deptId} and spui.del_flag=0 --->deptId     *
     * @param surProject
     * @return
     */
    @Override
    public List<SurProject> selectSurProjectListByBuser(SurProject where) {
        return surProjectMapper.selectSurProjectListByBuser(where);
    }
}
