package com.yanzhu.jh.project.service.impl;

import java.util.List;

import cn.hutool.core.util.StrUtil;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yanzhu.jh.project.mapper.SurProjectWorkingCommitteeMapper;
import com.yanzhu.jh.project.domain.SurProjectWorkingCommittee;
import com.yanzhu.jh.project.service.ISurProjectWorkingCommitteeService;
import com.ruoyi.common.utils.SecurityUtils;
/**
 * 工委会管理Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-04-06
 */
@Service
public class SurProjectWorkingCommitteeServiceImpl implements ISurProjectWorkingCommitteeService 
{
    @Autowired
    private SurProjectWorkingCommitteeMapper surProjectWorkingCommitteeMapper;

    /**
     * 查询工委会管理
     * 
     * @param id 工委会管理主键
     * @return 工委会管理
     */
    @Override
    public SurProjectWorkingCommittee selectSurProjectWorkingCommitteeById(Long id)
    {
        return surProjectWorkingCommitteeMapper.selectSurProjectWorkingCommitteeById(id);
    }

    /**
     * 查询工委会管理列表
     * 
     * @param surProjectWorkingCommittee 工委会管理
     * @return 工委会管理
     */
    @Override
    public List<SurProjectWorkingCommittee> selectSurProjectWorkingCommitteeList(SurProjectWorkingCommittee surProjectWorkingCommittee)
    {
        return surProjectWorkingCommitteeMapper.selectSurProjectWorkingCommitteeList(surProjectWorkingCommittee);
    }

    /**
     * 新增工委会管理
     * 
     * @param surProjectWorkingCommittee 工委会管理
     * @return 结果
     */
    @Override
    public int insertSurProjectWorkingCommittee(SurProjectWorkingCommittee surProjectWorkingCommittee)
    {
        surProjectWorkingCommittee.setCreateBy(SecurityUtils.getUsername());
        surProjectWorkingCommittee.setCreateTime(DateUtils.getNowDate());
        return surProjectWorkingCommitteeMapper.insertSurProjectWorkingCommittee(surProjectWorkingCommittee);
    }

    /**
     * 修改工委会管理
     * 
     * @param surProjectWorkingCommittee 工委会管理
     * @return 结果
     */
    @Override
    public int updateSurProjectWorkingCommittee(SurProjectWorkingCommittee surProjectWorkingCommittee)
    {
        surProjectWorkingCommittee.setUpdateBy(SecurityUtils.getUsername());
        surProjectWorkingCommittee.setUpdateTime(DateUtils.getNowDate());
        return surProjectWorkingCommitteeMapper.updateSurProjectWorkingCommittee(surProjectWorkingCommittee);
    }

    /**
     * 批量删除工委会管理
     * 
     * @param ids 需要删除的工委会管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectWorkingCommitteeByIds(Long[] ids)
    {
        return surProjectWorkingCommitteeMapper.deleteSurProjectWorkingCommitteeByIds(ids);
    }

    /**
     * 删除工委会管理信息
     * 
     * @param id 工委会管理主键
     * @return 结果
     */
    @Override
    public int deleteSurProjectWorkingCommitteeById(Long id)
    {
        return surProjectWorkingCommitteeMapper.deleteSurProjectWorkingCommitteeById(id);
    }

    /**
     * 批量处理
     * @param list
     * @return
     */
    @Override
    public int insertSurProjectWorkingCommitteeList(List<SurProjectWorkingCommittee> list) {
        //有id 无costName和money的删除
        //无id 有costName和money的增加
        //有id 有costName和money的修改
        int cnt=0;
        for(SurProjectWorkingCommittee it:list){
            if(it.getId()!=null && it.getId()>0){
                if(StrUtil.isEmpty(it.getCostName())  && (it.getMoney()==null || it.getMoney()==0)){
                    deleteSurProjectWorkingCommitteeById(it.getId());
                    cnt++;
                }else{
                    updateSurProjectWorkingCommittee(it);
                    cnt++;
                }
            }else{
                if(StrUtil.isNotEmpty(it.getCostName()) && it.getMoney()!=null && it.getMoney()>0){
                    insertSurProjectWorkingCommittee(it);
                    cnt++;
                }
            }
        }
        return cnt;
    }
    /**
     * 大屏工程管理 - 汇总信息
     * @param where
     * @return
     */
    @Override
    public List<SurProjectWorkingCommittee> sumGroupByType(SurProjectWorkingCommittee where) {
        return surProjectWorkingCommitteeMapper.sumGroupByType(where);
    }

    /**
     * 大屏工程管理 - 付款明细
     * @param where
     * @return
     */
    @Override
    public List<SurProjectWorkingCommittee> selectByWorkingType(SurProjectWorkingCommittee where) {
        return surProjectWorkingCommitteeMapper.selectByWorkingType(where);
    }
}
