package com.yanzhu.jh.video.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.yanzhu.jh.video.domain.DevAiProjectConfig;
import com.yanzhu.jh.video.service.IDevAiProjectConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 设备配置Controller
 * 
 * @author JiangYuQi
 * @date 2023-10-03
 */
@RestController
@RequestMapping("/video/aiBoxProjectConfig")
public class DevAiProjectConfigController extends BaseController
{
    @Autowired
    private IDevAiProjectConfigService devAiProjectConfigService;

    /**
     * 查询设备配置列表
     */
    @PreAuthorize("@ss.hasPermi('video:aiBoxProjectConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(DevAiProjectConfig devAiProjectConfig)
    {
        startPage();
        List<DevAiProjectConfig> list = devAiProjectConfigService.selectDevAiProjectConfigList(devAiProjectConfig);
        return getDataTable(list);
    }

    /**
     * 导出设备配置列表
     */
    @PreAuthorize("@ss.hasPermi('video:aiBoxProjectConfig:export')")
    @Log(title = "设备配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DevAiProjectConfig devAiProjectConfig)
    {
        List<DevAiProjectConfig> list = devAiProjectConfigService.selectDevAiProjectConfigList(devAiProjectConfig);
        ExcelUtil<DevAiProjectConfig> util = new ExcelUtil<DevAiProjectConfig>(DevAiProjectConfig.class);
        util.exportExcel(response, list, "设备配置数据");
    }

    /**
     * 获取设备配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('video:aiBoxProjectConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(devAiProjectConfigService.selectDevAiProjectConfigById(id));
    }

    /**
     * 新增设备配置
     */
    @PreAuthorize("@ss.hasPermi('video:aiBoxProjectConfig:add')")
    @Log(title = "设备配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DevAiProjectConfig devAiProjectConfig)
    {
        return toAjax(devAiProjectConfigService.insertDevAiProjectConfig(devAiProjectConfig));
    }

    /**
     * 修改设备配置
     */
    @PreAuthorize("@ss.hasPermi('video:aiBoxProjectConfig:edit')")
    @Log(title = "设备配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DevAiProjectConfig devAiProjectConfig)
    {
        return toAjax(devAiProjectConfigService.updateDevAiProjectConfig(devAiProjectConfig));
    }

    /**
     * 删除设备配置
     */
    @PreAuthorize("@ss.hasPermi('video:aiBoxProjectConfig:remove')")
    @Log(title = "设备配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(devAiProjectConfigService.deleteDevAiProjectConfigByIds(ids));
    }
}
