package com.yanzhu.jh.wxsetting.controller;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.config.RuoYiConfig;
import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.SysUserOpenid;
import com.ruoyi.system.service.ISysUserOpenidService;
import com.yanzhu.jh.wxsetting.domain.vo.WxBindingVo;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.api.WxConsts;
import me.chanjar.weixin.common.exception.WxErrorException;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.result.WxMpOAuth2AccessToken;
import me.chanjar.weixin.mp.bean.result.WxMpUser;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.net.URLEncoder;
import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * 微信openId绑定
 *
 * @author JiangYuQi
 * @date 2023-08-24
 */
@Slf4j
@Controller
@RequestMapping("/wxAuth")
public class WxAuthController extends BaseController {

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private WxMpService wxMpService;

    @Autowired
    private ISysUserOpenidService sysUserOpenidService;

    /**
     * @author ：tao
     * @param: ：
     * @return： 重定向到获取用户信息的类
     * 微信授权登录
     */
    @Anonymous
    @GetMapping("/authorize")
    public void authorize(@RequestParam(value = "returnUrl", defaultValue = "https://szgc.jhncidg.com") String returnUrl, HttpServletResponse response) throws Exception {
        log.info("【微信网页授权】进来了，参数={}", returnUrl);
        //1. 配置
        //2. 调用方法
        String url = RuoYiConfig.getProjectUrl() + "wxAuth/userInfo";
        /*
         * 相当于这种形式
         * URLEncoder.decode(returnUrl,"UTF-8"
         * https://open.weixin.qq.com/connect/oauth2/authorize?appid=APPID&redirect_uri=REDIRECT_URI&response_type=code&scope=SCOPE&state=STATE#wechat_redirect
         */
        String redirectUrl = wxMpService.oauth2buildAuthorizationUrl(url, WxConsts.OAUTH2_SCOPE_BASE, returnUrl);
        log.info("【微信网页授权】获取code,result={}", redirectUrl);
        response.sendRedirect(redirectUrl);
    }

    /**
     * @author ：tao
     * @param: ：
     * @return： 重定向
     * 获取用户信息类，最后重定向到指定url
     */
    @Anonymous
    @GetMapping("/userInfo")
    public void userInfo(@RequestParam("code") String code,
                         @RequestParam("state") String returnUrl,HttpServletResponse response) throws Exception {
        /*当用户同意授权后，会回调所设置的url并把authorization code传过来，
        然后用这个code获得access token，其中也包含用户的openid等信息*/
        WxMpOAuth2AccessToken wxMpOAuth2AccessToken = new WxMpOAuth2AccessToken();
        try {
            //获取access token
            wxMpOAuth2AccessToken = wxMpService.oauth2getAccessToken(code);
            log.info("【AccessToken：】{}", wxMpOAuth2AccessToken.getAccessToken());
        } catch (WxErrorException e) {
            log.error("【微信网页授权】{}", e);
        }

        // 拿到openid
        String openId = wxMpOAuth2AccessToken.getOpenId();
        log.info("【openid：】{}", openId);
        log.info("【我是前端要回调的地址：】{}", returnUrl + "&openid=" + openId);
        // 顺便获取一下用户信息
        WxMpUser wxMpUser = wxMpService.oauth2getUserInfo(wxMpOAuth2AccessToken, "zh_CN");
        log.info("【用户信息：】{}", wxMpUser.toString());

        //注意拼接参数，第一个参数需要加问号，之后参数使用&拼接的问题
        //return "redirect:" + returnUrl + "/#/?openid=" + openId;
        response.sendRedirect(returnUrl + "&rd="+System.currentTimeMillis()+"&openid=" + openId);
    }

    /**
     * @author ：JiangYuQi
     * @param: ：
     * @return： 重定向
     * 获取用户信息类，最后重定向到指定url
     */
    @Anonymous
    @ResponseBody
    @PostMapping("/binding")
    public AjaxResult binding(@Validated @RequestBody WxBindingVo vo) throws Exception {
        String key="wxAuth_binding_"+vo.getCode();
        Object obj = redisCache.getCacheObject(key);
        if(obj!=null){
            return success();
        }
        /*当用户同意授权后，会回调所设置的url并把authorization code传过来，
        然后用这个code获得access token，其中也包含用户的openid等信息*/
        WxMpOAuth2AccessToken wxMpOAuth2AccessToken = new WxMpOAuth2AccessToken();
        try {
            //获取access token
            wxMpOAuth2AccessToken = wxMpService.oauth2getAccessToken(vo.getCode());
            //log.info("【AccessToken：】{}", wxMpOAuth2AccessToken.getAccessToken());
            // 拿到openid
            String openId = wxMpOAuth2AccessToken.getOpenId();
            log.info("【openid：】{}", openId);
            // 顺便获取一下用户信息
            //WxMpUser wxMpUser = wxMpService.oauth2getUserInfo(wxMpOAuth2AccessToken, "zh_CN");
            //log.info("【用户信息：】{}", wxMpUser.toString());
            /*当用户同意授权后，将小程序openId和公众号OpenId进行绑定*/
            SysUserOpenid sysUserOpenid = sysUserOpenidService.selectSysUserOpenidByOpenId(vo.getOpenId());
            if(sysUserOpenid!=null){
                sysUserOpenid.setMsgOpenId(openId);
                sysUserOpenidService.updateSysUserOpenid(sysUserOpenid);
                //删除缓存
                redisCache.deleteObject(CacheConstants.WX_MPMESSAGE_OPENID +sysUserOpenid.getLoginName());
                redisCache.setCacheObject(key,vo.getCode(),5, TimeUnit.MINUTES);
                return success();
            }
        } catch (WxErrorException e) {
            log.error("【微信网页授权】{}", e);
            return error();
        }
        return error();
    }

}
