package com.yanzhu.jh.wxsetting.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.common.config.WechatAccountConfig;
import com.ruoyi.common.constant.CacheConstants;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.enums.MessageTypeEnum;
import com.ruoyi.common.enums.PublicStateEnum;
import com.ruoyi.common.enums.TemplateMessageEnum;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.SysUserOpenid;
import com.ruoyi.system.mapper.SysDeptMapper;
import com.ruoyi.system.mapper.SysUserMapper;
import com.ruoyi.system.mapper.SysUserOpenidMapper;
import com.ruoyi.system.service.ISysConfigService;
import com.yanzhu.jh.flow.domain.FlowLabourInfo;
import com.yanzhu.jh.project.domain.*;
import com.yanzhu.jh.project.mapper.SurProjectMapper;
import com.yanzhu.jh.trouble.domain.SmzSspProblemmodify;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.mp.api.WxMpService;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateData;
import me.chanjar.weixin.mp.bean.template.WxMpTemplateMessage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;
import java.util.stream.Collectors;

/**
 * 逻辑处理完毕
 * 这里使用Async修饰为异步方法
 * JiangYuQi
 */
@Slf4j
@Component
@EnableAsync
public class WeChatMessageServiceImpl {

    @Autowired
    private ISysConfigService configService;

    @Autowired
    private WxMpService wxMpService;

    @Autowired
    private SysDeptMapper sysDeptMapper;

    @Autowired
    private SysUserMapper sysUserMapper;

    @Autowired
    private SurProjectMapper surProjectMapper;

    @Autowired
    private SysUserOpenidMapper sysUserOpenidMapper;

    @Async
    public void send(SmzSspProblemmodify smzSspProblemmodify){
        List<WxMpTemplateMessage> list = new ArrayList<>();
        Long state = smzSspProblemmodify.getCheckState();
        String handlePath = smzSspProblemmodify.getInfoType()==0?"security":"quality";
        String infoTypeName = smzSspProblemmodify.getInfoType()==0?"安全隐患":"质量隐患";
        String infoTypeDict = smzSspProblemmodify.getInfoType()==0?"ssp_aqyhlx":"ssp_zlyhlx";
        /**
         * 提交隐患通知整改人
         */
        if(state==0){
            /**
             * 复检人驳回整改
             * 消息通知整改人
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(smzSspProblemmodify.getLordSentUser()))
                    .templateId(TemplateMessageEnum.TROUBLE_SUBMIT.getId())
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+smzSspProblemmodify.getProjectId()))
                    .build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", this.getMsgProName(smzSspProblemmodify.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing5", this.getMsgName(smzSspProblemmodify.getCreateUser())+"〔"+DictUtils.getDictLabel("sys_ssp_yhfl",smzSspProblemmodify.getRoleType()+"")+"〕"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time6", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time9", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD,smzSspProblemmodify.getNickedTime())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", infoTypeName+"/"+ DictUtils.getDictLabel(infoTypeDict,smzSspProblemmodify.getDangerType())));
            list.add(templateMessage);

            /**
             * 通知抄送人
             */
            if(StringUtils.isNotBlank(smzSspProblemmodify.getCopySendUser())){
                String[] copySendUsers = smzSspProblemmodify.getCopySendUser().split(",");
                for(String copySendUser:copySendUsers){
                    WxMpTemplateMessage copyTemplateMessage = WxMpTemplateMessage.builder()
                            .toUser(this.getMsgId(copySendUser))
                            .templateId(TemplateMessageEnum.TROUBLE_SUBMIT.getId())
                            .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+smzSspProblemmodify.getProjectId()))
                            .build();
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("thing7", this.getMsgProName(smzSspProblemmodify.getProjectId())));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("thing5", this.getMsgName(smzSspProblemmodify.getCreateUser())+"〔"+DictUtils.getDictLabel("sys_ssp_yhfl",smzSspProblemmodify.getRoleType()+"")+"〕"));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("time6", DateUtils.getTime()));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("time9", DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD,smzSspProblemmodify.getNickedTime())));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", infoTypeName+"/"+ DictUtils.getDictLabel(infoTypeDict,smzSspProblemmodify.getDangerType())));
                    list.add(copyTemplateMessage);
                }
            }
        } else if(state==1){
            /**
             * 整改人提交复检
             * 消息通知复检人
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(smzSspProblemmodify.getRecheckSendUser()))
                    .templateId(TemplateMessageEnum.TROUBLE_HANDLE.getId())
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+smzSspProblemmodify.getProjectId()))
                    .build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing11", this.getMsgProName(smzSspProblemmodify.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("const16", infoTypeName+"/"+ DictUtils.getDictLabel(infoTypeDict,smzSspProblemmodify.getDangerType())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", smzSspProblemmodify.getLordSent()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time3", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", "隐患整改提交复检"));
            list.add(templateMessage);

            /**
             * 通知抄送人
             */
            if(StringUtils.isNotBlank(smzSspProblemmodify.getCopySendUser())){
                String[] copySendUsers = smzSspProblemmodify.getCopySendUser().split(",");
                for(String copySendUser:copySendUsers){
                    WxMpTemplateMessage copyTemplateMessage = WxMpTemplateMessage.builder()
                            .toUser(this.getMsgId(smzSspProblemmodify.getRecheckSendUser()))
                            .templateId(this.getMsgId(copySendUser))
                            .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+smzSspProblemmodify.getProjectId()))
                            .build();
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("thing11", this.getMsgProName(smzSspProblemmodify.getProjectId())));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("const16", infoTypeName+"/"+ DictUtils.getDictLabel(infoTypeDict,smzSspProblemmodify.getDangerType())));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", smzSspProblemmodify.getLordSent()));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("time3", DateUtils.getTime()));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", "隐患整改提交复检"));
                    list.add(copyTemplateMessage);
                }
            }
        } else if(state==3){
            /**
             * 复检人驳回整改
             * 消息通知整改人
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(smzSspProblemmodify.getLordSentUser()))
                    .templateId(TemplateMessageEnum.TROUBLE_HANDLE.getId())
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+smzSspProblemmodify.getProjectId()))
                    .build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing11", this.getMsgProName(smzSspProblemmodify.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("const16", infoTypeName+"/"+ DictUtils.getDictLabel(infoTypeDict,smzSspProblemmodify.getDangerType())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", smzSspProblemmodify.getRecheckSend()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time3", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", "隐患整改复检驳回，请重新提交整改"));
            list.add(templateMessage);

            /**
             * 通知抄送人
             */
            if(StringUtils.isNotBlank(smzSspProblemmodify.getCopySendUser())){
                String[] copySendUsers = smzSspProblemmodify.getCopySendUser().split(",");
                for(String copySendUser:copySendUsers){
                    WxMpTemplateMessage copyTemplateMessage = WxMpTemplateMessage.builder()
                            .toUser(this.getMsgId(smzSspProblemmodify.getRecheckSendUser()))
                            .templateId(this.getMsgId(copySendUser))
                            .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+smzSspProblemmodify.getProjectId()))
                            .build();
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("thing11", this.getMsgProName(smzSspProblemmodify.getProjectId())));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("const16", infoTypeName+"/"+ DictUtils.getDictLabel(infoTypeDict,smzSspProblemmodify.getDangerType())));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", smzSspProblemmodify.getRecheckSend()));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("time3", DateUtils.getTime()));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", "隐患整改复检驳回，请重新提交整改"));
                    list.add(copyTemplateMessage);
                }
            }
        } else if(state==4){
            /**
             * 复检人通过整改
             * 消息通知整改人
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(smzSspProblemmodify.getLordSentUser()))
                    .templateId(TemplateMessageEnum.TROUBLE_HANDLE.getId())
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+smzSspProblemmodify.getProjectId()))
                    .build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing11", this.getMsgProName(smzSspProblemmodify.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("const16", infoTypeName+"/"+ DictUtils.getDictLabel(infoTypeDict,smzSspProblemmodify.getDangerType())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", smzSspProblemmodify.getRecheckSend()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time3", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", "隐患整改复检通过"));
            list.add(templateMessage);

            /**
             * 通知抄送人
             */
            if(StringUtils.isNotBlank(smzSspProblemmodify.getCopySendUser())){
                String[] copySendUsers = smzSspProblemmodify.getCopySendUser().split(",");
                for(String copySendUser:copySendUsers){
                    WxMpTemplateMessage copyTemplateMessage = WxMpTemplateMessage.builder()
                            .toUser(this.getMsgId(smzSspProblemmodify.getRecheckSendUser()))
                            .templateId(this.getMsgId(copySendUser))
                            .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_problemmodify/"+handlePath+"/list/index?barProId="+smzSspProblemmodify.getProjectId()))
                            .build();
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("thing11", this.getMsgProName(smzSspProblemmodify.getProjectId())));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("const16", infoTypeName+"/"+ DictUtils.getDictLabel(infoTypeDict,smzSspProblemmodify.getDangerType())));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", smzSspProblemmodify.getRecheckSend()));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("time3", DateUtils.getTime()));
                    copyTemplateMessage.addWxMpTemplateData(new WxMpTemplateData("const10", "隐患整改复检通过"));
                    list.add(copyTemplateMessage);
                }
            }
        }
        this.send(list, MessageTypeEnum.getYHPCLX(smzSspProblemmodify.getInfoType())+state);
    }

    /**
     * 举牌验收操作时推送信息
     * @param surProjectChecking
     */
    @Async
    public void send(SurProjectChecking surProjectChecking){
        List<WxMpTemplateMessage> list = new ArrayList<>();
        String stateStr = surProjectChecking.getApproveStatus();
        if(Objects.equals(PublicStateEnum.AUDITINFO_DSH.getCode(),stateStr)){
            /**
             * 监理审批待审批
             */
            String supMsgId = this.getMsgId(surProjectChecking.getSuperviseUser());
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(supMsgId)
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId())
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_checking/list/index?barProId="+surProjectChecking.getProjectId()))
                    .build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectChecking.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "待"+surProjectChecking.getSuperviseUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectChecking.getCreateBy())+"["+this.getMsgDepName(surProjectChecking.getDeptId())+"]"));
            list.add(templateMessage);

            /**
             * 抄送项目甲代
             */
            /**templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgProMagUsers(surProjectChecking.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectChecking.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "待"+surProjectChecking.getSuperviseUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectChecking.getCreateBy())+"["+this.getMsgDepName(surProjectChecking.getDeptId())+"]"));
            list.add(templateMessage);*/

            /**
             * 抄送项目总监
             * 非审批人时推送消息
             */
            /**String _supMsgId = this.getMsgProSupUsers(surProjectChecking.getProjectId());
            if(StringUtils.isEmpty(_supMsgId)){
                _supMsgId = "";
            }
            if(!Objects.equals(supMsgId,_supMsgId)){
                templateMessage = WxMpTemplateMessage.builder()
                        .toUser(_supMsgId)
                        .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectChecking.getProjectId())));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "待"+surProjectChecking.getSuperviseUserName()+"审批"));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectChecking.getCreateBy())+"["+this.getMsgDepName(surProjectChecking.getDeptId())+"]"));
                list.add(templateMessage);
            }*/
        }else if(Objects.equals(PublicStateEnum.AUDITINFO_SHTG.getCode(),stateStr)){
            /**
             * 审批通过
             * 通知提交人审核通过
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectChecking.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_checking/list/index?barProId="+surProjectChecking.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectChecking.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectChecking.getSuperviseUserName()+"审批通过"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectChecking.getCreateBy())+"["+this.getMsgDepName(surProjectChecking.getDeptId())+"]"));
            list.add(templateMessage);
        }else{
            /**
             * 审批驳回
             * 通知提交人审核驳回
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectChecking.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_checking/list/index?barProId="+surProjectChecking.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectChecking.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectChecking.getSuperviseUserName()+"审批驳回"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectChecking.getCreateBy())+"["+this.getMsgDepName(surProjectChecking.getDeptId())+"]"));
            list.add(templateMessage);
        }
       this.send(list,MessageTypeEnum.JPYSSP.getCode()+stateStr);
    }

    /**
     * 工程功能检验操作时推送信息
     * @param surProjectFunVerify
     */
    @Async
    public void send(SurProjectFunVerify surProjectFunVerify){
        List<WxMpTemplateMessage> list = new ArrayList<>();
        String stateStr = surProjectFunVerify.getApproveStatus();
        if(Objects.equals(PublicStateEnum.AUDITINFO_DSH.getCode(),stateStr)){
            /**
             * 监理审批待审批
             */
            String supMsgId = this.getMsgId(surProjectFunVerify.getSuperviseUser());
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(supMsgId)
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId())
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_funVerify/list/index?barProId="+surProjectFunVerify.getProjectId()))
                    .build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectFunVerify.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.GCGNJY.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "待"+surProjectFunVerify.getSuperviseUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectFunVerify.getCreateBy())+"["+this.getMsgDepName(surProjectFunVerify.getDeptId())+"]"));
            list.add(templateMessage);

        }else if(Objects.equals(PublicStateEnum.AUDITINFO_SHTG.getCode(),stateStr)){
            /**
             * 审批通过
             * 通知提交人审核通过
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectFunVerify.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_funVerify/list/index?barProId="+surProjectFunVerify.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectFunVerify.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.GCGNJY.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectFunVerify.getSuperviseUserName()+"审批通过"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectFunVerify.getCreateBy())+"["+this.getMsgDepName(surProjectFunVerify.getDeptId())+"]"));
            list.add(templateMessage);
        }else{
            /**
             * 审批驳回
             * 通知提交人审核驳回
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectFunVerify.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_funVerify/list/index?barProId="+surProjectFunVerify.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectFunVerify.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.GCGNJY.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectFunVerify.getSuperviseUserName()+"审批驳回"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectFunVerify.getCreateBy())+"["+this.getMsgDepName(surProjectFunVerify.getDeptId())+"]"));
            list.add(templateMessage);
        }
        this.send(list,MessageTypeEnum.GCGNJY.getCode()+stateStr);
    }

    /**
     * 实测实量操作时推送信息
     * @param surProjectMeasure
     */
    @Async
    public void send(SurProjectMeasure surProjectMeasure){
        List<WxMpTemplateMessage> list = new ArrayList<>();
        String stateStr = surProjectMeasure.getApproveStatus();
        if(Objects.equals(PublicStateEnum.AUDITINFO_DSH.getCode(),stateStr)){
            /**
             * 监理审批待审批
             */
            String supMsgId = this.getMsgId(surProjectMeasure.getSuperviseUser());
            //模板数据
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(supMsgId)
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_measure/list/index?barProId="+surProjectMeasure.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMeasure.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.CSCLSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "待"+surProjectMeasure.getSuperviseUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMeasure.getCreateBy())+"["+this.getMsgDepName(surProjectMeasure.getDeptId())+"]"));
            list.add(templateMessage);

            /**
             * 抄送项目甲代
             */
            /**templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgProMagUsers(surProjectMeasure.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMeasure.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "待"+surProjectMeasure.getSuperviseUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMeasure.getCreateBy())+"["+this.getMsgDepName(surProjectMeasure.getDeptId())+"]"));
            list.add(templateMessage);*/

            /**
             * 抄送项目总监
             * 非审批人时推送消息
             */
            /**String _supMsgId = this.getMsgProSupUsers(surProjectMeasure.getProjectId());
            if(StringUtils.isEmpty(_supMsgId)){
                _supMsgId = "";
            }
            if(!Objects.equals(supMsgId,_supMsgId)){
                templateMessage = WxMpTemplateMessage.builder()
                        .toUser(_supMsgId)
                        .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMeasure.getProjectId())));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", "待"+surProjectMeasure.getSuperviseUserName()+"审批"));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMeasure.getCreateBy())+"["+this.getMsgDepName(surProjectMeasure.getDeptId())+"]"));
                list.add(templateMessage);
            }*/
        }else if(Objects.equals(PublicStateEnum.AUDITINFO_SHTG.getCode(),stateStr)){
            /**
             * 审批通过
             * 通知提交人审核通过
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectMeasure.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_measure/list/index?barProId="+surProjectMeasure.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMeasure.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.CSCLSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectMeasure.getSuperviseUserName()+"审批通过"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMeasure.getCreateBy())+"["+this.getMsgDepName(surProjectMeasure.getDeptId())+"]"));
            list.add(templateMessage);
        }else{
            /**
             * 审批驳回
             * 通知提交人审核驳回
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectMeasure.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_measure/list/index?barProId="+surProjectMeasure.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMeasure.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.CSCLSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectMeasure.getSuperviseUserName()+"审批驳回"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMeasure.getCreateBy())+"["+this.getMsgDepName(surProjectMeasure.getDeptId())+"]"));
            list.add(templateMessage);
        }
        this.send(list,MessageTypeEnum.CSCLSP.getCode()+stateStr);
    }

    /**
     * 材料封样操作时推送信息
     * @param surProjectMaterialSeal
     */
    @Async
    public void send(SurProjectMaterialSeal surProjectMaterialSeal){
        List<WxMpTemplateMessage> list = new ArrayList<>();
        String stateStr = surProjectMaterialSeal.getApproveStatus();
        if(Objects.equals(PublicStateEnum.AUDITINFO_DSH.getCode(),stateStr)){
            /**
             * 监理审批待审批
             */
            String supMsgId = this.getMsgId(surProjectMaterialSeal.getWitnessUser());
            //模板数据
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(supMsgId)
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_materialSeal/list/index?barProId="+surProjectMaterialSeal.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMaterialSeal.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.CLFYSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectMaterialSeal.getWitnessUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMaterialSeal.getCreateBy())+"["+this.getMsgDepName(surProjectMaterialSeal.getDeptId())+"]"));
            list.add(templateMessage);

            /**
             * 抄送项目甲代
             */
            /**templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgProMagUsers(surProjectMaterialSeal.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMaterialSeal.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectMaterialSeal.getWitnessUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMaterialSeal.getCreateBy())+"["+this.getMsgDepName(surProjectMaterialSeal.getDeptId())+"]"));
            list.add(templateMessage);*/

            /**
             * 抄送项目总监
             * 非审批人时推送消息
             */
            /**String _supMsgId = this.getMsgProSupUsers(surProjectMaterialSeal.getProjectId());
            if(StringUtils.isEmpty(_supMsgId)){
                _supMsgId = "";
            }
            if(!Objects.equals(supMsgId,_supMsgId)){
                templateMessage = WxMpTemplateMessage.builder()
                        .toUser(_supMsgId)
                        .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMaterialSeal.getProjectId())));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectMaterialSeal.getWitnessUserName()+"审批"));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMaterialSeal.getCreateBy())+"["+this.getMsgDepName(surProjectMaterialSeal.getDeptId())+"]"));
                list.add(templateMessage);
            }*/
        }else if(Objects.equals(PublicStateEnum.AUDITINFO_SHTG.getCode(),stateStr)){
            /**
             * 审批通过
             * 通知提交人审核通过
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectMaterialSeal.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_materialSeal/list/index?barProId="+surProjectMaterialSeal.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMaterialSeal.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.CLFYSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectMaterialSeal.getWitnessUserName()+"审批通过"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMaterialSeal.getCreateBy())+"["+this.getMsgDepName(surProjectMaterialSeal.getDeptId())+"]"));
            list.add(templateMessage);
        }else{
            /**
             * 审批驳回
             * 通知提交人审核驳回
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectMaterialSeal.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_materialSeal/list/index?barProId="+surProjectMaterialSeal.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectMaterialSeal.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.CLFYSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectMaterialSeal.getWitnessUserName()+"审批驳回"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectMaterialSeal.getCreateBy())+"["+this.getMsgDepName(surProjectMaterialSeal.getDeptId())+"]"));
            list.add(templateMessage);
        }
        this.send(list,MessageTypeEnum.CLFYSP.getCode()+stateStr);
    }

    /**
     * 取样复试操作时推送信息
     * @param surProjectCheckDetection
     */
    @Async
    public void send(SurProjectCheckDetection surProjectCheckDetection){
        List<WxMpTemplateMessage> list = new ArrayList<>();
        String stateStr = surProjectCheckDetection.getApproveStatus();
        if(Objects.equals(PublicStateEnum.AUDITINFO_DSH.getCode(),stateStr)){
            /**
             * 监理审批待审批
             */
            String supMsgId = this.getMsgId(surProjectCheckDetection.getWitnessUser());
            //模板数据
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(supMsgId)
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_checkDetection/list/index?barProId="+surProjectCheckDetection.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectCheckDetection.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.QYFSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectCheckDetection.getWitnessUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectCheckDetection.getCreateBy())+"["+this.getMsgDepName(surProjectCheckDetection.getDeptId())+"]"));
            list.add(templateMessage);

            /**
             * 抄送项目甲代
             */
            /**templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgProMagUsers(surProjectCheckDetection.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectCheckDetection.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectCheckDetection.getWitnessUserName()+"审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectCheckDetection.getCreateBy())+"["+this.getMsgDepName(surProjectCheckDetection.getDeptId())+"]"));
            list.add(templateMessage);*/

            /**
             * 抄送项目总监
             * 非审批人时推送消息
             */
            /**String _supMsgId = this.getMsgProSupUsers(surProjectCheckDetection.getProjectId());
            if(StringUtils.isEmpty(_supMsgId)){
                _supMsgId = "";
            }
            if(!Objects.equals(supMsgId,_supMsgId)){
                templateMessage = WxMpTemplateMessage.builder()
                        .toUser(_supMsgId)
                        .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectCheckDetection.getProjectId())));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.JPYSSP.getName()));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectCheckDetection.getWitnessUserName()+"审批"));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
                templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectCheckDetection.getCreateBy())+"["+this.getMsgDepName(surProjectCheckDetection.getDeptId())+"]"));
                list.add(templateMessage);
            }*/
        }else if(Objects.equals(PublicStateEnum.AUDITINFO_SHTG.getCode(),stateStr)){
            /**
             * 审批通过
             * 通知提交人审核通过
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectCheckDetection.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_checkDetection/list/index?barProId="+surProjectCheckDetection.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectCheckDetection.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.QYFSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectCheckDetection.getWitnessUserName()+"审批通过"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectCheckDetection.getCreateBy())+"["+this.getMsgDepName(surProjectCheckDetection.getDeptId())+"]"));
            list.add(templateMessage);
        }else if(Objects.equals(PublicStateEnum.AUDITINFO_SHBH.getCode(),stateStr)){
            /**
             * 审批驳回
             * 通知提交人审核驳回
             */
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(this.getMsgId(surProjectCheckDetection.getCreateBy()))
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/project_checkDetection/list/index?barProId="+surProjectCheckDetection.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", this.getMsgProName(surProjectCheckDetection.getProjectId())));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.QYFSSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", surProjectCheckDetection.getWitnessUserName()+"审批驳回"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", this.getMsgName(surProjectCheckDetection.getCreateBy())+"["+this.getMsgDepName(surProjectCheckDetection.getDeptId())+"]"));
            list.add(templateMessage);
        }
        this.send(list,MessageTypeEnum.QYFSSP.getCode()+stateStr);
    }

    /**
     * 劳资投诉时推送信息
     * @param flowLabourInfo
     */
    @Async
    public void send(FlowLabourInfo flowLabourInfo){
        List<WxMpTemplateMessage> list = new ArrayList<>();
        String stateStr = flowLabourInfo.getApproveStatus();
        if(Objects.equals("10",stateStr) || Objects.equals("21",stateStr)){
            /**
             * 项目经理审批
             */
            String supMsgId = this.getMsgProOrgUsers(flowLabourInfo.getProjectId(),flowLabourInfo.getDeptId());
            //模板数据
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(supMsgId)
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/flow_labour/list/index?barProId="+flowLabourInfo.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", flowLabourInfo.getProjectName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.LZYJSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", Objects.equals("10",stateStr)?"待项目经理处理":"甲代驳回，待项目经理处理"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            String subDeptName = flowLabourInfo.getSubDeptName().length()<14?flowLabourInfo.getSubDeptName():flowLabourInfo.getSubDeptName().substring(0,13);
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", flowLabourInfo.getLaborName()+"["+subDeptName+"]"));
            list.add(templateMessage);
        }else if(Objects.equals("20",stateStr) || Objects.equals("31",stateStr)){
            /**
             * 审批通过
             * 通知甲代审批
             */
            String supMsgId = this.getMsgProMagUsers(flowLabourInfo.getProjectId());
            //模板数据
            WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                    .toUser(supMsgId)
                    .miniProgram(new WxMpTemplateMessage.MiniProgram(WechatAccountConfig.getWxAppId(), "/pageage/flow_labour/list/index?barProId="+flowLabourInfo.getProjectId()))
                    .templateId(TemplateMessageEnum.APPLY_DEFAULT.getId()).build();
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing14", flowLabourInfo.getProjectName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing1", MessageTypeEnum.LZYJSP.getName()));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing2", Objects.equals("20",stateStr)?"待甲方代表审批":"甲代驳回，待甲方代表审批"));
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("time4", DateUtils.getTime()));
            String subDeptName = flowLabourInfo.getSubDeptName().length()<14?flowLabourInfo.getSubDeptName():flowLabourInfo.getSubDeptName().substring(0,13);
            templateMessage.addWxMpTemplateData(new WxMpTemplateData("thing10", flowLabourInfo.getLaborName()+"["+subDeptName+"]"));
            list.add(templateMessage);
        }else if(Objects.equals("30",stateStr)){
            /**
             * 审批通过
             * 通知集团公司
             */
        }
        this.send(list,MessageTypeEnum.QYFSSP.getCode()+stateStr);
    }

    @Autowired
    private RedisCache redisCache;

    /**
     * 查询项目监理
     * @param proId
     * @return
     */
    private String getMsgProSupUsers(Long proId){
        List<SysUserOpenid> list = redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_P_SUP +proId);
        if(list!=null){
            List<String> strs = list.stream().map(SysUserOpenid :: getMsgOpenId).collect(Collectors.toList());
            return String.join(",",strs);
        }else{
            list = sysUserOpenidMapper.findMsgProSupUsers(proId);
            if(StringUtils.isNotEmpty(list)){
                //设置30分钟有效期
                redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_P_SUP +proId,list,30, TimeUnit.MINUTES);
                List<String> strs = list.stream().map(SysUserOpenid :: getMsgOpenId).collect(Collectors.toList());
                return String.join(",",strs);
            }else{
                return null;
            }
        }
    }

    /**
     * 查询项目经理
     * @param proId
     * @return
     */
    private String getMsgProOrgUsers(Long proId,Long deptId){
        List<SysUserOpenid> list = redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_P_ORG +proId);
        if(list!=null){
            List<String> strs = list.stream().map(SysUserOpenid :: getMsgOpenId).collect(Collectors.toList());
            return String.join(",",strs);
        }else{
            list = sysUserOpenidMapper.findMsgProOrgUsers(proId,deptId);
            if(StringUtils.isNotEmpty(list)){
                //设置30分钟有效期
                redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_P_ORG +proId,list,30, TimeUnit.MINUTES);
                List<String> strs = list.stream().map(SysUserOpenid :: getMsgOpenId).collect(Collectors.toList());
                return String.join(",",strs);
            }else{
                return null;
            }
        }
    }

    /**
     * 查询项目甲代
     * @param proId
     * @return
     */
    private String getMsgProMagUsers(Long proId){
        List<SysUserOpenid> list = redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_P_MAG +proId);
        if(list!=null){
            List<String> strs = list.stream().map(SysUserOpenid :: getMsgOpenId).collect(Collectors.toList());
            return String.join(",",strs);
        }else{
            list = sysUserOpenidMapper.findMsgProMagUsers(proId);
            if(StringUtils.isNotEmpty(list)){
                //设置30分钟有效期
                redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_P_MAG +proId,list,30, TimeUnit.MINUTES);
                List<String> strs = list.stream().map(SysUserOpenid :: getMsgOpenId).collect(Collectors.toList());
                return String.join(",",strs);
            }else{
                return null;
            }
        }
    }

    /**
     * 查询单位名称
     * @param depId
     * @return
     */
    private String getMsgDepName(Long depId){
        String name = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_DNAME +depId));
        if(StringUtils.isNotEmpty(name)){
            return name;
        }else{
            SysDept sysDept = sysDeptMapper.selectDeptById(depId);
            //项目名称截取&&超过20字符微信限制并抛出异常
            String depName = sysDept.getDeptName();
            if(depName.length()>13){
                depName = sysDept.getDeptName().substring(0,13);
            }
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_DNAME +depId,depName,30, TimeUnit.MINUTES);
            return depName;
        }
    }

    /**
     * 查询项目名称
     * @param proId
     * @return
     */
    private String getMsgProName(Long proId){
        String name = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_PNAME +proId));
        if(StringUtils.isNotEmpty(name)){
            return name;
        }else{
            SurProject surProject = surProjectMapper.selectSurProjectById(proId);
            //项目名称截取&&超过20字符微信限制并抛出异常
            String proName = surProject.getProjectName();
            if(proName.length()>20){
                proName = surProject.getProjectName().substring(0,20);
            }
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_PNAME +proId,proName,30, TimeUnit.MINUTES);
            return proName;
        }
    }

    /**
     * 查询微信用户名称
     * @param userName
     * @return
     */
    private String getMsgName(String userName){
        String name = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_UNAME +userName));
        if(StringUtils.isNotEmpty(name)){
            return name;
        }else{
            SysUser sysUser = sysUserMapper.selectUserByUserName(userName);
            name = sysUser!=null?sysUser.getNickName():"";
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_UNAME +userName,name,30, TimeUnit.MINUTES);
            return name;
        }
    }

    /**
     * 查询微信用户列表
     * @param userName
     * @return
     */
    private String getMsgId(String userName){
        String openIds = Convert.toStr(redisCache.getCacheObject(CacheConstants.WX_MPMESSAGE_OPENID +userName));
        if(StringUtils.isNotEmpty(openIds)){
            return openIds;
        }else{
            List<SysUserOpenid> list = sysUserOpenidMapper.findSysUserOpenidsByUser(userName);
            if(StringUtils.isNotEmpty(list)){
                List<SysUserOpenid> ids = list.stream().filter(u -> StringUtils.isNotBlank(u.getMsgOpenId())).collect(Collectors.toList());
                if(StringUtils.isNotEmpty(ids)){
                    List<String> strs = ids.stream().map(SysUserOpenid :: getMsgOpenId).collect(Collectors.toList());
                    openIds = String.join(",",strs);
                }
            }
            //设置30分钟有效期
            redisCache.setCacheObject(CacheConstants.WX_MPMESSAGE_OPENID +userName,openIds,30, TimeUnit.MINUTES);
            return openIds;
        }
    }

    /**
     * 模板消息开关
     */
    private boolean wxSwitch = false;

    /**
     * 推送模板消息
     * @param list
     */
    private void send(List<WxMpTemplateMessage> list,String messageType){
        try {
            wxSwitch =  Convert.toBool(configService.selectConfigByKey("sys.wx.message"),false);
            log.info("微信公众号消息准备就绪...{}...{}...{}",wxSwitch,list.size(),messageType);
            if(wxSwitch && StringUtils.isNotEmpty(list)){
                for(WxMpTemplateMessage message:list){
                    if(StringUtils.isNotEmpty(message.getToUser())){
                        String[] toUsers = message.getToUser().split(",");
                        for(String toUser:toUsers){
                            //判断短时间内是否已发送相同类型的消息
                            String key = CacheConstants.WX_MPMESSAGE_KEY +toUser+"-"+messageType;
                            if(Convert.toBool(redisCache.getCacheObject(key),true)){
                                //多个登录账号时批量发送
                                message.setToUser(toUser);
                                wxMpService.getTemplateMsgService().sendTemplateMsg(message);
                                //5分钟内不推送相同类型的消息
                                log.info("微信公众号消息发送成功...{}",key);
                                redisCache.setCacheObject(key,false,5, TimeUnit.MINUTES);
                            }
                        }
                    }
                }
            }
        }catch (Exception e){
            log.info("出错了...{}",e.getMessage());
            try {
                JSONObject jsonObject = JSONObject.parseObject(e.getMessage());
                if(Objects.equals(jsonObject.getString("errcode"),"40164")){
                    String ip = jsonObject.getString("errmsg").split("ipv6")[0].split(" ")[2];
                    WxMpTemplateMessage templateMessage = WxMpTemplateMessage.builder()
                            .toUser("oM5rN6Wb8UyBLuTAFNGjnZCeQs1U")
                            .templateId(TemplateMessageEnum.SERVER_ERROR.getId())
                            .build();
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("character_string7", "IP>"+ip));
                    templateMessage.addWxMpTemplateData(new WxMpTemplateData("time6", DateUtils.dateTimeNow()));
                    wxMpService.getTemplateMsgService().sendTemplateMsg(templateMessage);
                }
            }catch (Exception ex){
                ex.printStackTrace();
            }
        }
    }

}
